/**
 * @public
 * @enum
 */
export declare const MIGProfileType: {
    readonly MIG_1G_10GB: "mig-1g.10gb";
    readonly MIG_1G_18GB: "mig-1g.18gb";
    readonly MIG_1G_20GB: "mig-1g.20gb";
    readonly MIG_1G_23GB: "mig-1g.23gb";
    readonly MIG_1G_35GB: "mig-1g.35gb";
    readonly MIG_1G_45GB: "mig-1g.45gb";
    readonly MIG_1G_47GB: "mig-1g.47gb";
    readonly MIG_1G_5GB: "mig-1g.5gb";
    readonly MIG_2G_10GB: "mig-2g.10gb";
    readonly MIG_2G_20GB: "mig-2g.20gb";
    readonly MIG_2G_35GB: "mig-2g.35gb";
    readonly MIG_2G_45GB: "mig-2g.45gb";
    readonly MIG_2G_47GB: "mig-2g.47gb";
    readonly MIG_3G_20GB: "mig-3g.20gb";
    readonly MIG_3G_40GB: "mig-3g.40gb";
    readonly MIG_3G_71GB: "mig-3g.71gb";
    readonly MIG_3G_90GB: "mig-3g.90gb";
    readonly MIG_3G_93GB: "mig-3g.93gb";
    readonly MIG_4G_20GB: "mig-4g.20gb";
    readonly MIG_4G_40GB: "mig-4g.40gb";
    readonly MIG_4G_71GB: "mig-4g.71gb";
    readonly MIG_4G_90GB: "mig-4g.90gb";
    readonly MIG_4G_93GB: "mig-4g.93gb";
    readonly MIG_7G_141GB: "mig-7g.141gb";
    readonly MIG_7G_180GB: "mig-7g.180gb";
    readonly MIG_7G_186GB: "mig-7g.186gb";
    readonly MIG_7G_40GB: "mig-7g.40gb";
    readonly MIG_7G_80GB: "mig-7g.80gb";
};
/**
 * @public
 */
export type MIGProfileType = (typeof MIGProfileType)[keyof typeof MIGProfileType];
/**
 * @public
 * @enum
 */
export declare const ClusterInstanceType: {
    readonly ML_C5N_18XLARGE: "ml.c5n.18xlarge";
    readonly ML_C5N_2XLARGE: "ml.c5n.2xlarge";
    readonly ML_C5N_4XLARGE: "ml.c5n.4xlarge";
    readonly ML_C5N_9XLARGE: "ml.c5n.9xlarge";
    readonly ML_C5N_LARGE: "ml.c5n.large";
    readonly ML_C5_12XLARGE: "ml.c5.12xlarge";
    readonly ML_C5_18XLARGE: "ml.c5.18xlarge";
    readonly ML_C5_24XLARGE: "ml.c5.24xlarge";
    readonly ML_C5_2XLARGE: "ml.c5.2xlarge";
    readonly ML_C5_4XLARGE: "ml.c5.4xlarge";
    readonly ML_C5_9XLARGE: "ml.c5.9xlarge";
    readonly ML_C5_LARGE: "ml.c5.large";
    readonly ML_C5_XLARGE: "ml.c5.xlarge";
    readonly ML_C6I_12XLARGE: "ml.c6i.12xlarge";
    readonly ML_C6I_16XLARGE: "ml.c6i.16xlarge";
    readonly ML_C6I_24XLARGE: "ml.c6i.24xlarge";
    readonly ML_C6I_2XLARGE: "ml.c6i.2xlarge";
    readonly ML_C6I_32XLARGE: "ml.c6i.32xlarge";
    readonly ML_C6I_4XLARGE: "ml.c6i.4xlarge";
    readonly ML_C6I_8XLARGE: "ml.c6i.8xlarge";
    readonly ML_C6I_LARGE: "ml.c6i.large";
    readonly ML_C6I_XLARGE: "ml.c6i.xlarge";
    readonly ML_G5_12XLARGE: "ml.g5.12xlarge";
    readonly ML_G5_16XLARGE: "ml.g5.16xlarge";
    readonly ML_G5_24XLARGE: "ml.g5.24xlarge";
    readonly ML_G5_2XLARGE: "ml.g5.2xlarge";
    readonly ML_G5_48XLARGE: "ml.g5.48xlarge";
    readonly ML_G5_4XLARGE: "ml.g5.4xlarge";
    readonly ML_G5_8XLARGE: "ml.g5.8xlarge";
    readonly ML_G5_XLARGE: "ml.g5.xlarge";
    readonly ML_G6E_12XLARGE: "ml.g6e.12xlarge";
    readonly ML_G6E_16XLARGE: "ml.g6e.16xlarge";
    readonly ML_G6E_24XLARGE: "ml.g6e.24xlarge";
    readonly ML_G6E_2XLARGE: "ml.g6e.2xlarge";
    readonly ML_G6E_48XLARGE: "ml.g6e.48xlarge";
    readonly ML_G6E_4XLARGE: "ml.g6e.4xlarge";
    readonly ML_G6E_8XLARGE: "ml.g6e.8xlarge";
    readonly ML_G6E_XLARGE: "ml.g6e.xlarge";
    readonly ML_G6_12XLARGE: "ml.g6.12xlarge";
    readonly ML_G6_16XLARGE: "ml.g6.16xlarge";
    readonly ML_G6_24XLARGE: "ml.g6.24xlarge";
    readonly ML_G6_2XLARGE: "ml.g6.2xlarge";
    readonly ML_G6_48XLARGE: "ml.g6.48xlarge";
    readonly ML_G6_4XLARGE: "ml.g6.4xlarge";
    readonly ML_G6_8XLARGE: "ml.g6.8xlarge";
    readonly ML_G6_XLARGE: "ml.g6.xlarge";
    readonly ML_GR6_4XLARGE: "ml.gr6.4xlarge";
    readonly ML_GR6_8XLARGE: "ml.gr6.8xlarge";
    readonly ML_I3EN_12XLARGE: "ml.i3en.12xlarge";
    readonly ML_I3EN_24XLARGE: "ml.i3en.24xlarge";
    readonly ML_I3EN_2XLARGE: "ml.i3en.2xlarge";
    readonly ML_I3EN_3XLARGE: "ml.i3en.3xlarge";
    readonly ML_I3EN_6XLARGE: "ml.i3en.6xlarge";
    readonly ML_I3EN_LARGE: "ml.i3en.large";
    readonly ML_I3EN_XLARGE: "ml.i3en.xlarge";
    readonly ML_M5_12XLARGE: "ml.m5.12xlarge";
    readonly ML_M5_16XLARGE: "ml.m5.16xlarge";
    readonly ML_M5_24XLARGE: "ml.m5.24xlarge";
    readonly ML_M5_2XLARGE: "ml.m5.2xlarge";
    readonly ML_M5_4XLARGE: "ml.m5.4xlarge";
    readonly ML_M5_8XLARGE: "ml.m5.8xlarge";
    readonly ML_M5_LARGE: "ml.m5.large";
    readonly ML_M5_XLARGE: "ml.m5.xlarge";
    readonly ML_M6I_12XLARGE: "ml.m6i.12xlarge";
    readonly ML_M6I_16XLARGE: "ml.m6i.16xlarge";
    readonly ML_M6I_24XLARGE: "ml.m6i.24xlarge";
    readonly ML_M6I_2XLARGE: "ml.m6i.2xlarge";
    readonly ML_M6I_32XLARGE: "ml.m6i.32xlarge";
    readonly ML_M6I_4XLARGE: "ml.m6i.4xlarge";
    readonly ML_M6I_8XLARGE: "ml.m6i.8xlarge";
    readonly ML_M6I_LARGE: "ml.m6i.large";
    readonly ML_M6I_XLARGE: "ml.m6i.xlarge";
    readonly ML_M7I_12XLARGE: "ml.m7i.12xlarge";
    readonly ML_M7I_16XLARGE: "ml.m7i.16xlarge";
    readonly ML_M7I_24XLARGE: "ml.m7i.24xlarge";
    readonly ML_M7I_2XLARGE: "ml.m7i.2xlarge";
    readonly ML_M7I_48XLARGE: "ml.m7i.48xlarge";
    readonly ML_M7I_4XLARGE: "ml.m7i.4xlarge";
    readonly ML_M7I_8XLARGE: "ml.m7i.8xlarge";
    readonly ML_M7I_LARGE: "ml.m7i.large";
    readonly ML_M7I_XLARGE: "ml.m7i.xlarge";
    readonly ML_P4DE_24XLARGE: "ml.p4de.24xlarge";
    readonly ML_P4D_24XLARGE: "ml.p4d.24xlarge";
    readonly ML_P5EN_48XLARGE: "ml.p5en.48xlarge";
    readonly ML_P5E_48XLARGE: "ml.p5e.48xlarge";
    readonly ML_P5_48XLARGE: "ml.p5.48xlarge";
    readonly ML_P5_4XLARGE: "ml.p5.4xlarge";
    readonly ML_P6E_GB200_36XLARGE: "ml.p6e-gb200.36xlarge";
    readonly ML_P6_B200_48XLARGE: "ml.p6-b200.48xlarge";
    readonly ML_P6_B300_48XLARGE: "ml.p6-b300.48xlarge";
    readonly ML_R6I_12XLARGE: "ml.r6i.12xlarge";
    readonly ML_R6I_16XLARGE: "ml.r6i.16xlarge";
    readonly ML_R6I_24XLARGE: "ml.r6i.24xlarge";
    readonly ML_R6I_2XLARGE: "ml.r6i.2xlarge";
    readonly ML_R6I_32XLARGE: "ml.r6i.32xlarge";
    readonly ML_R6I_4XLARGE: "ml.r6i.4xlarge";
    readonly ML_R6I_8XLARGE: "ml.r6i.8xlarge";
    readonly ML_R6I_LARGE: "ml.r6i.large";
    readonly ML_R6I_XLARGE: "ml.r6i.xlarge";
    readonly ML_R7I_12XLARGE: "ml.r7i.12xlarge";
    readonly ML_R7I_16XLARGE: "ml.r7i.16xlarge";
    readonly ML_R7I_24XLARGE: "ml.r7i.24xlarge";
    readonly ML_R7I_2XLARGE: "ml.r7i.2xlarge";
    readonly ML_R7I_48XLARGE: "ml.r7i.48xlarge";
    readonly ML_R7I_4XLARGE: "ml.r7i.4xlarge";
    readonly ML_R7I_8XLARGE: "ml.r7i.8xlarge";
    readonly ML_R7I_LARGE: "ml.r7i.large";
    readonly ML_R7I_XLARGE: "ml.r7i.xlarge";
    readonly ML_T3_2XLARGE: "ml.t3.2xlarge";
    readonly ML_T3_LARGE: "ml.t3.large";
    readonly ML_T3_MEDIUM: "ml.t3.medium";
    readonly ML_T3_XLARGE: "ml.t3.xlarge";
    readonly ML_TRN1N_32XLARGE: "ml.trn1n.32xlarge";
    readonly ML_TRN1_32XLARGE: "ml.trn1.32xlarge";
    readonly ML_TRN2_3XLARGE: "ml.trn2.3xlarge";
    readonly ML_TRN2_48XLARGE: "ml.trn2.48xlarge";
};
/**
 * @public
 */
export type ClusterInstanceType = (typeof ClusterInstanceType)[keyof typeof ClusterInstanceType];
/**
 * @public
 * @enum
 */
export declare const AccountDefaultStatus: {
    readonly DISABLED: "DISABLED";
    readonly ENABLED: "ENABLED";
};
/**
 * @public
 */
export type AccountDefaultStatus = (typeof AccountDefaultStatus)[keyof typeof AccountDefaultStatus];
/**
 * @public
 * @enum
 */
export declare const ActionStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
    readonly UNKNOWN: "Unknown";
};
/**
 * @public
 */
export type ActionStatus = (typeof ActionStatus)[keyof typeof ActionStatus];
/**
 * @public
 * @enum
 */
export declare const ActivationState: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type ActivationState = (typeof ActivationState)[keyof typeof ActivationState];
/**
 * @public
 * @enum
 */
export declare const ActiveClusterOperationName: {
    readonly SCALING: "Scaling";
};
/**
 * @public
 */
export type ActiveClusterOperationName = (typeof ActiveClusterOperationName)[keyof typeof ActiveClusterOperationName];
/**
 * @public
 * @enum
 */
export declare const AssociationEdgeType: {
    readonly ASSOCIATED_WITH: "AssociatedWith";
    readonly CONTRIBUTED_TO: "ContributedTo";
    readonly DERIVED_FROM: "DerivedFrom";
    readonly PRODUCED: "Produced";
    readonly SAME_AS: "SameAs";
};
/**
 * @public
 */
export type AssociationEdgeType = (typeof AssociationEdgeType)[keyof typeof AssociationEdgeType];
/**
 * @public
 * @enum
 */
export declare const CompressionType: {
    readonly GZIP: "Gzip";
    readonly NONE: "None";
};
/**
 * @public
 */
export type CompressionType = (typeof CompressionType)[keyof typeof CompressionType];
/**
 * @public
 * @enum
 */
export declare const AdditionalS3DataSourceDataType: {
    readonly S3OBJECT: "S3Object";
    readonly S3PREFIX: "S3Prefix";
};
/**
 * @public
 */
export type AdditionalS3DataSourceDataType = (typeof AdditionalS3DataSourceDataType)[keyof typeof AdditionalS3DataSourceDataType];
/**
 * @public
 * @enum
 */
export declare const ModelCompressionType: {
    readonly Gzip: "Gzip";
    readonly None: "None";
};
/**
 * @public
 */
export type ModelCompressionType = (typeof ModelCompressionType)[keyof typeof ModelCompressionType];
/**
 * @public
 * @enum
 */
export declare const S3ModelDataType: {
    readonly S3Object: "S3Object";
    readonly S3Prefix: "S3Prefix";
};
/**
 * @public
 */
export type S3ModelDataType = (typeof S3ModelDataType)[keyof typeof S3ModelDataType];
/**
 * @public
 * @enum
 */
export declare const ProductionVariantInstanceType: {
    readonly ML_C4_2XLARGE: "ml.c4.2xlarge";
    readonly ML_C4_4XLARGE: "ml.c4.4xlarge";
    readonly ML_C4_8XLARGE: "ml.c4.8xlarge";
    readonly ML_C4_LARGE: "ml.c4.large";
    readonly ML_C4_XLARGE: "ml.c4.xlarge";
    readonly ML_C5D_18XLARGE: "ml.c5d.18xlarge";
    readonly ML_C5D_2XLARGE: "ml.c5d.2xlarge";
    readonly ML_C5D_4XLARGE: "ml.c5d.4xlarge";
    readonly ML_C5D_9XLARGE: "ml.c5d.9xlarge";
    readonly ML_C5D_LARGE: "ml.c5d.large";
    readonly ML_C5D_XLARGE: "ml.c5d.xlarge";
    readonly ML_C5_18XLARGE: "ml.c5.18xlarge";
    readonly ML_C5_2XLARGE: "ml.c5.2xlarge";
    readonly ML_C5_4XLARGE: "ml.c5.4xlarge";
    readonly ML_C5_9XLARGE: "ml.c5.9xlarge";
    readonly ML_C5_LARGE: "ml.c5.large";
    readonly ML_C5_XLARGE: "ml.c5.xlarge";
    readonly ML_C6GD_12XLARGE: "ml.c6gd.12xlarge";
    readonly ML_C6GD_16XLARGE: "ml.c6gd.16xlarge";
    readonly ML_C6GD_2XLARGE: "ml.c6gd.2xlarge";
    readonly ML_C6GD_4XLARGE: "ml.c6gd.4xlarge";
    readonly ML_C6GD_8XLARGE: "ml.c6gd.8xlarge";
    readonly ML_C6GD_LARGE: "ml.c6gd.large";
    readonly ML_C6GD_XLARGE: "ml.c6gd.xlarge";
    readonly ML_C6GN_12XLARGE: "ml.c6gn.12xlarge";
    readonly ML_C6GN_16XLARGE: "ml.c6gn.16xlarge";
    readonly ML_C6GN_2XLARGE: "ml.c6gn.2xlarge";
    readonly ML_C6GN_4XLARGE: "ml.c6gn.4xlarge";
    readonly ML_C6GN_8XLARGE: "ml.c6gn.8xlarge";
    readonly ML_C6GN_LARGE: "ml.c6gn.large";
    readonly ML_C6GN_XLARGE: "ml.c6gn.xlarge";
    readonly ML_C6G_12XLARGE: "ml.c6g.12xlarge";
    readonly ML_C6G_16XLARGE: "ml.c6g.16xlarge";
    readonly ML_C6G_2XLARGE: "ml.c6g.2xlarge";
    readonly ML_C6G_4XLARGE: "ml.c6g.4xlarge";
    readonly ML_C6G_8XLARGE: "ml.c6g.8xlarge";
    readonly ML_C6G_LARGE: "ml.c6g.large";
    readonly ML_C6G_XLARGE: "ml.c6g.xlarge";
    readonly ML_C6IN_12XLARGE: "ml.c6in.12xlarge";
    readonly ML_C6IN_16XLARGE: "ml.c6in.16xlarge";
    readonly ML_C6IN_24XLARGE: "ml.c6in.24xlarge";
    readonly ML_C6IN_2XLARGE: "ml.c6in.2xlarge";
    readonly ML_C6IN_32XLARGE: "ml.c6in.32xlarge";
    readonly ML_C6IN_4XLARGE: "ml.c6in.4xlarge";
    readonly ML_C6IN_8XLARGE: "ml.c6in.8xlarge";
    readonly ML_C6IN_LARGE: "ml.c6in.large";
    readonly ML_C6IN_XLARGE: "ml.c6in.xlarge";
    readonly ML_C6I_12XLARGE: "ml.c6i.12xlarge";
    readonly ML_C6I_16XLARGE: "ml.c6i.16xlarge";
    readonly ML_C6I_24XLARGE: "ml.c6i.24xlarge";
    readonly ML_C6I_2XLARGE: "ml.c6i.2xlarge";
    readonly ML_C6I_32XLARGE: "ml.c6i.32xlarge";
    readonly ML_C6I_4XLARGE: "ml.c6i.4xlarge";
    readonly ML_C6I_8XLARGE: "ml.c6i.8xlarge";
    readonly ML_C6I_LARGE: "ml.c6i.large";
    readonly ML_C6I_XLARGE: "ml.c6i.xlarge";
    readonly ML_C7G_12XLARGE: "ml.c7g.12xlarge";
    readonly ML_C7G_16XLARGE: "ml.c7g.16xlarge";
    readonly ML_C7G_2XLARGE: "ml.c7g.2xlarge";
    readonly ML_C7G_4XLARGE: "ml.c7g.4xlarge";
    readonly ML_C7G_8XLARGE: "ml.c7g.8xlarge";
    readonly ML_C7G_LARGE: "ml.c7g.large";
    readonly ML_C7G_XLARGE: "ml.c7g.xlarge";
    readonly ML_C7I_12XLARGE: "ml.c7i.12xlarge";
    readonly ML_C7I_16XLARGE: "ml.c7i.16xlarge";
    readonly ML_C7I_24XLARGE: "ml.c7i.24xlarge";
    readonly ML_C7I_2XLARGE: "ml.c7i.2xlarge";
    readonly ML_C7I_48XLARGE: "ml.c7i.48xlarge";
    readonly ML_C7I_4XLARGE: "ml.c7i.4xlarge";
    readonly ML_C7I_8XLARGE: "ml.c7i.8xlarge";
    readonly ML_C7I_LARGE: "ml.c7i.large";
    readonly ML_C7I_XLARGE: "ml.c7i.xlarge";
    readonly ML_C8G_12XLARGE: "ml.c8g.12xlarge";
    readonly ML_C8G_16XLARGE: "ml.c8g.16xlarge";
    readonly ML_C8G_24XLARGE: "ml.c8g.24xlarge";
    readonly ML_C8G_2XLARGE: "ml.c8g.2xlarge";
    readonly ML_C8G_48XLARGE: "ml.c8g.48xlarge";
    readonly ML_C8G_4XLARGE: "ml.c8g.4xlarge";
    readonly ML_C8G_8XLARGE: "ml.c8g.8xlarge";
    readonly ML_C8G_LARGE: "ml.c8g.large";
    readonly ML_C8G_MEDIUM: "ml.c8g.medium";
    readonly ML_C8G_XLARGE: "ml.c8g.xlarge";
    readonly ML_DL1_24XLARGE: "ml.dl1.24xlarge";
    readonly ML_G4DN_12XLARGE: "ml.g4dn.12xlarge";
    readonly ML_G4DN_16XLARGE: "ml.g4dn.16xlarge";
    readonly ML_G4DN_2XLARGE: "ml.g4dn.2xlarge";
    readonly ML_G4DN_4XLARGE: "ml.g4dn.4xlarge";
    readonly ML_G4DN_8XLARGE: "ml.g4dn.8xlarge";
    readonly ML_G4DN_XLARGE: "ml.g4dn.xlarge";
    readonly ML_G5_12XLARGE: "ml.g5.12xlarge";
    readonly ML_G5_16XLARGE: "ml.g5.16xlarge";
    readonly ML_G5_24XLARGE: "ml.g5.24xlarge";
    readonly ML_G5_2XLARGE: "ml.g5.2xlarge";
    readonly ML_G5_48XLARGE: "ml.g5.48xlarge";
    readonly ML_G5_4XLARGE: "ml.g5.4xlarge";
    readonly ML_G5_8XLARGE: "ml.g5.8xlarge";
    readonly ML_G5_XLARGE: "ml.g5.xlarge";
    readonly ML_G6E_12XLARGE: "ml.g6e.12xlarge";
    readonly ML_G6E_16XLARGE: "ml.g6e.16xlarge";
    readonly ML_G6E_24XLARGE: "ml.g6e.24xlarge";
    readonly ML_G6E_2XLARGE: "ml.g6e.2xlarge";
    readonly ML_G6E_48XLARGE: "ml.g6e.48xlarge";
    readonly ML_G6E_4XLARGE: "ml.g6e.4xlarge";
    readonly ML_G6E_8XLARGE: "ml.g6e.8xlarge";
    readonly ML_G6E_XLARGE: "ml.g6e.xlarge";
    readonly ML_G6_12XLARGE: "ml.g6.12xlarge";
    readonly ML_G6_16XLARGE: "ml.g6.16xlarge";
    readonly ML_G6_24XLARGE: "ml.g6.24xlarge";
    readonly ML_G6_2XLARGE: "ml.g6.2xlarge";
    readonly ML_G6_48XLARGE: "ml.g6.48xlarge";
    readonly ML_G6_4XLARGE: "ml.g6.4xlarge";
    readonly ML_G6_8XLARGE: "ml.g6.8xlarge";
    readonly ML_G6_XLARGE: "ml.g6.xlarge";
    readonly ML_INF1_24XLARGE: "ml.inf1.24xlarge";
    readonly ML_INF1_2XLARGE: "ml.inf1.2xlarge";
    readonly ML_INF1_6XLARGE: "ml.inf1.6xlarge";
    readonly ML_INF1_XLARGE: "ml.inf1.xlarge";
    readonly ML_INF2_24XLARGE: "ml.inf2.24xlarge";
    readonly ML_INF2_48XLARGE: "ml.inf2.48xlarge";
    readonly ML_INF2_8XLARGE: "ml.inf2.8xlarge";
    readonly ML_INF2_XLARGE: "ml.inf2.xlarge";
    readonly ML_M4_10XLARGE: "ml.m4.10xlarge";
    readonly ML_M4_16XLARGE: "ml.m4.16xlarge";
    readonly ML_M4_2XLARGE: "ml.m4.2xlarge";
    readonly ML_M4_4XLARGE: "ml.m4.4xlarge";
    readonly ML_M4_XLARGE: "ml.m4.xlarge";
    readonly ML_M5D_12XLARGE: "ml.m5d.12xlarge";
    readonly ML_M5D_24XLARGE: "ml.m5d.24xlarge";
    readonly ML_M5D_2XLARGE: "ml.m5d.2xlarge";
    readonly ML_M5D_4XLARGE: "ml.m5d.4xlarge";
    readonly ML_M5D_LARGE: "ml.m5d.large";
    readonly ML_M5D_XLARGE: "ml.m5d.xlarge";
    readonly ML_M5_12XLARGE: "ml.m5.12xlarge";
    readonly ML_M5_24XLARGE: "ml.m5.24xlarge";
    readonly ML_M5_2XLARGE: "ml.m5.2xlarge";
    readonly ML_M5_4XLARGE: "ml.m5.4xlarge";
    readonly ML_M5_LARGE: "ml.m5.large";
    readonly ML_M5_XLARGE: "ml.m5.xlarge";
    readonly ML_M6GD_12XLARGE: "ml.m6gd.12xlarge";
    readonly ML_M6GD_16XLARGE: "ml.m6gd.16xlarge";
    readonly ML_M6GD_2XLARGE: "ml.m6gd.2xlarge";
    readonly ML_M6GD_4XLARGE: "ml.m6gd.4xlarge";
    readonly ML_M6GD_8XLARGE: "ml.m6gd.8xlarge";
    readonly ML_M6GD_LARGE: "ml.m6gd.large";
    readonly ML_M6GD_XLARGE: "ml.m6gd.xlarge";
    readonly ML_M6G_12XLARGE: "ml.m6g.12xlarge";
    readonly ML_M6G_16XLARGE: "ml.m6g.16xlarge";
    readonly ML_M6G_2XLARGE: "ml.m6g.2xlarge";
    readonly ML_M6G_4XLARGE: "ml.m6g.4xlarge";
    readonly ML_M6G_8XLARGE: "ml.m6g.8xlarge";
    readonly ML_M6G_LARGE: "ml.m6g.large";
    readonly ML_M6G_XLARGE: "ml.m6g.xlarge";
    readonly ML_M6I_12XLARGE: "ml.m6i.12xlarge";
    readonly ML_M6I_16XLARGE: "ml.m6i.16xlarge";
    readonly ML_M6I_24XLARGE: "ml.m6i.24xlarge";
    readonly ML_M6I_2XLARGE: "ml.m6i.2xlarge";
    readonly ML_M6I_32XLARGE: "ml.m6i.32xlarge";
    readonly ML_M6I_4XLARGE: "ml.m6i.4xlarge";
    readonly ML_M6I_8XLARGE: "ml.m6i.8xlarge";
    readonly ML_M6I_LARGE: "ml.m6i.large";
    readonly ML_M6I_XLARGE: "ml.m6i.xlarge";
    readonly ML_M7I_12XLARGE: "ml.m7i.12xlarge";
    readonly ML_M7I_16XLARGE: "ml.m7i.16xlarge";
    readonly ML_M7I_24XLARGE: "ml.m7i.24xlarge";
    readonly ML_M7I_2XLARGE: "ml.m7i.2xlarge";
    readonly ML_M7I_48XLARGE: "ml.m7i.48xlarge";
    readonly ML_M7I_4XLARGE: "ml.m7i.4xlarge";
    readonly ML_M7I_8XLARGE: "ml.m7i.8xlarge";
    readonly ML_M7I_LARGE: "ml.m7i.large";
    readonly ML_M7I_XLARGE: "ml.m7i.xlarge";
    readonly ML_M8G_12XLARGE: "ml.m8g.12xlarge";
    readonly ML_M8G_16XLARGE: "ml.m8g.16xlarge";
    readonly ML_M8G_24XLARGE: "ml.m8g.24xlarge";
    readonly ML_M8G_2XLARGE: "ml.m8g.2xlarge";
    readonly ML_M8G_48XLARGE: "ml.m8g.48xlarge";
    readonly ML_M8G_4XLARGE: "ml.m8g.4xlarge";
    readonly ML_M8G_8XLARGE: "ml.m8g.8xlarge";
    readonly ML_M8G_LARGE: "ml.m8g.large";
    readonly ML_M8G_MEDIUM: "ml.m8g.medium";
    readonly ML_M8G_XLARGE: "ml.m8g.xlarge";
    readonly ML_P2_16XLARGE: "ml.p2.16xlarge";
    readonly ML_P2_8XLARGE: "ml.p2.8xlarge";
    readonly ML_P2_XLARGE: "ml.p2.xlarge";
    readonly ML_P3_16XLARGE: "ml.p3.16xlarge";
    readonly ML_P3_2XLARGE: "ml.p3.2xlarge";
    readonly ML_P3_8XLARGE: "ml.p3.8xlarge";
    readonly ML_P4DE_24XLARGE: "ml.p4de.24xlarge";
    readonly ML_P4D_24XLARGE: "ml.p4d.24xlarge";
    readonly ML_P5EN_48XLARGE: "ml.p5en.48xlarge";
    readonly ML_P5E_48XLARGE: "ml.p5e.48xlarge";
    readonly ML_P5_48XLARGE: "ml.p5.48xlarge";
    readonly ML_P5_4XLARGE: "ml.p5.4xlarge";
    readonly ML_P6E_GB200_36XLARGE: "ml.p6e-gb200.36xlarge";
    readonly ML_P6_B200_48XLARGE: "ml.p6-b200.48xlarge";
    readonly ML_R5D_12XLARGE: "ml.r5d.12xlarge";
    readonly ML_R5D_24XLARGE: "ml.r5d.24xlarge";
    readonly ML_R5D_2XLARGE: "ml.r5d.2xlarge";
    readonly ML_R5D_4XLARGE: "ml.r5d.4xlarge";
    readonly ML_R5D_LARGE: "ml.r5d.large";
    readonly ML_R5D_XLARGE: "ml.r5d.xlarge";
    readonly ML_R5_12XLARGE: "ml.r5.12xlarge";
    readonly ML_R5_24XLARGE: "ml.r5.24xlarge";
    readonly ML_R5_2XLARGE: "ml.r5.2xlarge";
    readonly ML_R5_4XLARGE: "ml.r5.4xlarge";
    readonly ML_R5_LARGE: "ml.r5.large";
    readonly ML_R5_XLARGE: "ml.r5.xlarge";
    readonly ML_R6GD_12XLARGE: "ml.r6gd.12xlarge";
    readonly ML_R6GD_16XLARGE: "ml.r6gd.16xlarge";
    readonly ML_R6GD_2XLARGE: "ml.r6gd.2xlarge";
    readonly ML_R6GD_4XLARGE: "ml.r6gd.4xlarge";
    readonly ML_R6GD_8XLARGE: "ml.r6gd.8xlarge";
    readonly ML_R6GD_LARGE: "ml.r6gd.large";
    readonly ML_R6GD_XLARGE: "ml.r6gd.xlarge";
    readonly ML_R6G_12XLARGE: "ml.r6g.12xlarge";
    readonly ML_R6G_16XLARGE: "ml.r6g.16xlarge";
    readonly ML_R6G_2XLARGE: "ml.r6g.2xlarge";
    readonly ML_R6G_4XLARGE: "ml.r6g.4xlarge";
    readonly ML_R6G_8XLARGE: "ml.r6g.8xlarge";
    readonly ML_R6G_LARGE: "ml.r6g.large";
    readonly ML_R6G_XLARGE: "ml.r6g.xlarge";
    readonly ML_R6I_12XLARGE: "ml.r6i.12xlarge";
    readonly ML_R6I_16XLARGE: "ml.r6i.16xlarge";
    readonly ML_R6I_24XLARGE: "ml.r6i.24xlarge";
    readonly ML_R6I_2XLARGE: "ml.r6i.2xlarge";
    readonly ML_R6I_32XLARGE: "ml.r6i.32xlarge";
    readonly ML_R6I_4XLARGE: "ml.r6i.4xlarge";
    readonly ML_R6I_8XLARGE: "ml.r6i.8xlarge";
    readonly ML_R6I_LARGE: "ml.r6i.large";
    readonly ML_R6I_XLARGE: "ml.r6i.xlarge";
    readonly ML_R7GD_12XLARGE: "ml.r7gd.12xlarge";
    readonly ML_R7GD_16XLARGE: "ml.r7gd.16xlarge";
    readonly ML_R7GD_2XLARGE: "ml.r7gd.2xlarge";
    readonly ML_R7GD_4XLARGE: "ml.r7gd.4xlarge";
    readonly ML_R7GD_8XLARGE: "ml.r7gd.8xlarge";
    readonly ML_R7GD_LARGE: "ml.r7gd.large";
    readonly ML_R7GD_MEDIUM: "ml.r7gd.medium";
    readonly ML_R7GD_XLARGE: "ml.r7gd.xlarge";
    readonly ML_R7I_12XLARGE: "ml.r7i.12xlarge";
    readonly ML_R7I_16XLARGE: "ml.r7i.16xlarge";
    readonly ML_R7I_24XLARGE: "ml.r7i.24xlarge";
    readonly ML_R7I_2XLARGE: "ml.r7i.2xlarge";
    readonly ML_R7I_48XLARGE: "ml.r7i.48xlarge";
    readonly ML_R7I_4XLARGE: "ml.r7i.4xlarge";
    readonly ML_R7I_8XLARGE: "ml.r7i.8xlarge";
    readonly ML_R7I_LARGE: "ml.r7i.large";
    readonly ML_R7I_XLARGE: "ml.r7i.xlarge";
    readonly ML_R8G_12XLARGE: "ml.r8g.12xlarge";
    readonly ML_R8G_16XLARGE: "ml.r8g.16xlarge";
    readonly ML_R8G_24XLARGE: "ml.r8g.24xlarge";
    readonly ML_R8G_2XLARGE: "ml.r8g.2xlarge";
    readonly ML_R8G_48XLARGE: "ml.r8g.48xlarge";
    readonly ML_R8G_4XLARGE: "ml.r8g.4xlarge";
    readonly ML_R8G_8XLARGE: "ml.r8g.8xlarge";
    readonly ML_R8G_LARGE: "ml.r8g.large";
    readonly ML_R8G_MEDIUM: "ml.r8g.medium";
    readonly ML_R8G_XLARGE: "ml.r8g.xlarge";
    readonly ML_T2_2XLARGE: "ml.t2.2xlarge";
    readonly ML_T2_LARGE: "ml.t2.large";
    readonly ML_T2_MEDIUM: "ml.t2.medium";
    readonly ML_T2_XLARGE: "ml.t2.xlarge";
    readonly ML_TRN1N_32XLARGE: "ml.trn1n.32xlarge";
    readonly ML_TRN1_2XLARGE: "ml.trn1.2xlarge";
    readonly ML_TRN1_32XLARGE: "ml.trn1.32xlarge";
    readonly ML_TRN2_48XLARGE: "ml.trn2.48xlarge";
};
/**
 * @public
 */
export type ProductionVariantInstanceType = (typeof ProductionVariantInstanceType)[keyof typeof ProductionVariantInstanceType];
/**
 * @public
 * @enum
 */
export declare const TransformInstanceType: {
    readonly ML_C4_2XLARGE: "ml.c4.2xlarge";
    readonly ML_C4_4XLARGE: "ml.c4.4xlarge";
    readonly ML_C4_8XLARGE: "ml.c4.8xlarge";
    readonly ML_C4_XLARGE: "ml.c4.xlarge";
    readonly ML_C5_18XLARGE: "ml.c5.18xlarge";
    readonly ML_C5_2XLARGE: "ml.c5.2xlarge";
    readonly ML_C5_4XLARGE: "ml.c5.4xlarge";
    readonly ML_C5_9XLARGE: "ml.c5.9xlarge";
    readonly ML_C5_XLARGE: "ml.c5.xlarge";
    readonly ML_C6I_12XLARGE: "ml.c6i.12xlarge";
    readonly ML_C6I_16XLARGE: "ml.c6i.16xlarge";
    readonly ML_C6I_24XLARGE: "ml.c6i.24xlarge";
    readonly ML_C6I_2XLARGE: "ml.c6i.2xlarge";
    readonly ML_C6I_32XLARGE: "ml.c6i.32xlarge";
    readonly ML_C6I_4XLARGE: "ml.c6i.4xlarge";
    readonly ML_C6I_8XLARGE: "ml.c6i.8xlarge";
    readonly ML_C6I_LARGE: "ml.c6i.large";
    readonly ML_C6I_XLARGE: "ml.c6i.xlarge";
    readonly ML_C7I_12XLARGE: "ml.c7i.12xlarge";
    readonly ML_C7I_16XLARGE: "ml.c7i.16xlarge";
    readonly ML_C7I_24XLARGE: "ml.c7i.24xlarge";
    readonly ML_C7I_2XLARGE: "ml.c7i.2xlarge";
    readonly ML_C7I_48XLARGE: "ml.c7i.48xlarge";
    readonly ML_C7I_4XLARGE: "ml.c7i.4xlarge";
    readonly ML_C7I_8XLARGE: "ml.c7i.8xlarge";
    readonly ML_C7I_LARGE: "ml.c7i.large";
    readonly ML_C7I_XLARGE: "ml.c7i.xlarge";
    readonly ML_G4DN_12XLARGE: "ml.g4dn.12xlarge";
    readonly ML_G4DN_16XLARGE: "ml.g4dn.16xlarge";
    readonly ML_G4DN_2XLARGE: "ml.g4dn.2xlarge";
    readonly ML_G4DN_4XLARGE: "ml.g4dn.4xlarge";
    readonly ML_G4DN_8XLARGE: "ml.g4dn.8xlarge";
    readonly ML_G4DN_XLARGE: "ml.g4dn.xlarge";
    readonly ML_G5_12XLARGE: "ml.g5.12xlarge";
    readonly ML_G5_16XLARGE: "ml.g5.16xlarge";
    readonly ML_G5_24XLARGE: "ml.g5.24xlarge";
    readonly ML_G5_2XLARGE: "ml.g5.2xlarge";
    readonly ML_G5_48XLARGE: "ml.g5.48xlarge";
    readonly ML_G5_4XLARGE: "ml.g5.4xlarge";
    readonly ML_G5_8XLARGE: "ml.g5.8xlarge";
    readonly ML_G5_XLARGE: "ml.g5.xlarge";
    readonly ML_G6_12XLARGE: "ml.g6.12xlarge";
    readonly ML_G6_16XLARGE: "ml.g6.16xlarge";
    readonly ML_G6_24XLARGE: "ml.g6.24xlarge";
    readonly ML_G6_2XLARGE: "ml.g6.2xlarge";
    readonly ML_G6_48XLARGE: "ml.g6.48xlarge";
    readonly ML_G6_4XLARGE: "ml.g6.4xlarge";
    readonly ML_G6_8XLARGE: "ml.g6.8xlarge";
    readonly ML_G6_XLARGE: "ml.g6.xlarge";
    readonly ML_INF2_24XLARGE: "ml.inf2.24xlarge";
    readonly ML_INF2_48XLARGE: "ml.inf2.48xlarge";
    readonly ML_INF2_8XLARGE: "ml.inf2.8xlarge";
    readonly ML_INF2_XLARGE: "ml.inf2.xlarge";
    readonly ML_M4_10XLARGE: "ml.m4.10xlarge";
    readonly ML_M4_16XLARGE: "ml.m4.16xlarge";
    readonly ML_M4_2XLARGE: "ml.m4.2xlarge";
    readonly ML_M4_4XLARGE: "ml.m4.4xlarge";
    readonly ML_M4_XLARGE: "ml.m4.xlarge";
    readonly ML_M5_12XLARGE: "ml.m5.12xlarge";
    readonly ML_M5_24XLARGE: "ml.m5.24xlarge";
    readonly ML_M5_2XLARGE: "ml.m5.2xlarge";
    readonly ML_M5_4XLARGE: "ml.m5.4xlarge";
    readonly ML_M5_LARGE: "ml.m5.large";
    readonly ML_M5_XLARGE: "ml.m5.xlarge";
    readonly ML_M6I_12XLARGE: "ml.m6i.12xlarge";
    readonly ML_M6I_16XLARGE: "ml.m6i.16xlarge";
    readonly ML_M6I_24XLARGE: "ml.m6i.24xlarge";
    readonly ML_M6I_2XLARGE: "ml.m6i.2xlarge";
    readonly ML_M6I_32XLARGE: "ml.m6i.32xlarge";
    readonly ML_M6I_4XLARGE: "ml.m6i.4xlarge";
    readonly ML_M6I_8XLARGE: "ml.m6i.8xlarge";
    readonly ML_M6I_LARGE: "ml.m6i.large";
    readonly ML_M6I_XLARGE: "ml.m6i.xlarge";
    readonly ML_M7I_12XLARGE: "ml.m7i.12xlarge";
    readonly ML_M7I_16XLARGE: "ml.m7i.16xlarge";
    readonly ML_M7I_24XLARGE: "ml.m7i.24xlarge";
    readonly ML_M7I_2XLARGE: "ml.m7i.2xlarge";
    readonly ML_M7I_48XLARGE: "ml.m7i.48xlarge";
    readonly ML_M7I_4XLARGE: "ml.m7i.4xlarge";
    readonly ML_M7I_8XLARGE: "ml.m7i.8xlarge";
    readonly ML_M7I_LARGE: "ml.m7i.large";
    readonly ML_M7I_XLARGE: "ml.m7i.xlarge";
    readonly ML_P2_16XLARGE: "ml.p2.16xlarge";
    readonly ML_P2_8XLARGE: "ml.p2.8xlarge";
    readonly ML_P2_XLARGE: "ml.p2.xlarge";
    readonly ML_P3_16XLARGE: "ml.p3.16xlarge";
    readonly ML_P3_2XLARGE: "ml.p3.2xlarge";
    readonly ML_P3_8XLARGE: "ml.p3.8xlarge";
    readonly ML_R6I_12XLARGE: "ml.r6i.12xlarge";
    readonly ML_R6I_16XLARGE: "ml.r6i.16xlarge";
    readonly ML_R6I_24XLARGE: "ml.r6i.24xlarge";
    readonly ML_R6I_2XLARGE: "ml.r6i.2xlarge";
    readonly ML_R6I_32XLARGE: "ml.r6i.32xlarge";
    readonly ML_R6I_4XLARGE: "ml.r6i.4xlarge";
    readonly ML_R6I_8XLARGE: "ml.r6i.8xlarge";
    readonly ML_R6I_LARGE: "ml.r6i.large";
    readonly ML_R6I_XLARGE: "ml.r6i.xlarge";
    readonly ML_R7I_12XLARGE: "ml.r7i.12xlarge";
    readonly ML_R7I_16XLARGE: "ml.r7i.16xlarge";
    readonly ML_R7I_24XLARGE: "ml.r7i.24xlarge";
    readonly ML_R7I_2XLARGE: "ml.r7i.2xlarge";
    readonly ML_R7I_48XLARGE: "ml.r7i.48xlarge";
    readonly ML_R7I_4XLARGE: "ml.r7i.4xlarge";
    readonly ML_R7I_8XLARGE: "ml.r7i.8xlarge";
    readonly ML_R7I_LARGE: "ml.r7i.large";
    readonly ML_R7I_XLARGE: "ml.r7i.xlarge";
    readonly ML_TRN1_2XLARGE: "ml.trn1.2xlarge";
    readonly ML_TRN1_32XLARGE: "ml.trn1.32xlarge";
};
/**
 * @public
 */
export type TransformInstanceType = (typeof TransformInstanceType)[keyof typeof TransformInstanceType];
/**
 * @public
 * @enum
 */
export declare const AggregationTransformationValue: {
    readonly Avg: "avg";
    readonly First: "first";
    readonly Max: "max";
    readonly Min: "min";
    readonly Sum: "sum";
};
/**
 * @public
 */
export type AggregationTransformationValue = (typeof AggregationTransformationValue)[keyof typeof AggregationTransformationValue];
/**
 * @public
 * @enum
 */
export declare const AlgorithmSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type AlgorithmSortBy = (typeof AlgorithmSortBy)[keyof typeof AlgorithmSortBy];
/**
 * @public
 * @enum
 */
export declare const TrainingRepositoryAccessMode: {
    readonly PLATFORM: "Platform";
    readonly VPC: "Vpc";
};
/**
 * @public
 */
export type TrainingRepositoryAccessMode = (typeof TrainingRepositoryAccessMode)[keyof typeof TrainingRepositoryAccessMode];
/**
 * @public
 * @enum
 */
export declare const TrainingInputMode: {
    readonly FASTFILE: "FastFile";
    readonly FILE: "File";
    readonly PIPE: "Pipe";
};
/**
 * @public
 */
export type TrainingInputMode = (typeof TrainingInputMode)[keyof typeof TrainingInputMode];
/**
 * @public
 * @enum
 */
export declare const AlgorithmStatus: {
    readonly COMPLETED: "Completed";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly PENDING: "Pending";
};
/**
 * @public
 */
export type AlgorithmStatus = (typeof AlgorithmStatus)[keyof typeof AlgorithmStatus];
/**
 * @public
 * @enum
 */
export declare const DetailedAlgorithmStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly NOT_STARTED: "NotStarted";
};
/**
 * @public
 */
export type DetailedAlgorithmStatus = (typeof DetailedAlgorithmStatus)[keyof typeof DetailedAlgorithmStatus];
/**
 * @public
 * @enum
 */
export declare const FileSystemAccessMode: {
    readonly RO: "ro";
    readonly RW: "rw";
};
/**
 * @public
 */
export type FileSystemAccessMode = (typeof FileSystemAccessMode)[keyof typeof FileSystemAccessMode];
/**
 * @public
 * @enum
 */
export declare const FileSystemType: {
    readonly EFS: "EFS";
    readonly FSXLUSTRE: "FSxLustre";
};
/**
 * @public
 */
export type FileSystemType = (typeof FileSystemType)[keyof typeof FileSystemType];
/**
 * @public
 * @enum
 */
export declare const S3DataDistribution: {
    readonly FULLY_REPLICATED: "FullyReplicated";
    readonly SHARDED_BY_S3_KEY: "ShardedByS3Key";
};
/**
 * @public
 */
export type S3DataDistribution = (typeof S3DataDistribution)[keyof typeof S3DataDistribution];
/**
 * @public
 * @enum
 */
export declare const S3DataType: {
    readonly AUGMENTED_MANIFEST_FILE: "AugmentedManifestFile";
    readonly CONVERSE: "Converse";
    readonly MANIFEST_FILE: "ManifestFile";
    readonly S3_PREFIX: "S3Prefix";
};
/**
 * @public
 */
export type S3DataType = (typeof S3DataType)[keyof typeof S3DataType];
/**
 * @public
 * @enum
 */
export declare const RecordWrapper: {
    readonly NONE: "None";
    readonly RECORDIO: "RecordIO";
};
/**
 * @public
 */
export type RecordWrapper = (typeof RecordWrapper)[keyof typeof RecordWrapper];
/**
 * @public
 * @enum
 */
export declare const OutputCompressionType: {
    readonly GZIP: "GZIP";
    readonly NONE: "NONE";
};
/**
 * @public
 */
export type OutputCompressionType = (typeof OutputCompressionType)[keyof typeof OutputCompressionType];
/**
 * @public
 * @enum
 */
export declare const TrainingInstanceType: {
    readonly ML_C4_2XLARGE: "ml.c4.2xlarge";
    readonly ML_C4_4XLARGE: "ml.c4.4xlarge";
    readonly ML_C4_8XLARGE: "ml.c4.8xlarge";
    readonly ML_C4_XLARGE: "ml.c4.xlarge";
    readonly ML_C5N_18XLARGE: "ml.c5n.18xlarge";
    readonly ML_C5N_2XLARGE: "ml.c5n.2xlarge";
    readonly ML_C5N_4XLARGE: "ml.c5n.4xlarge";
    readonly ML_C5N_9XLARGE: "ml.c5n.9xlarge";
    readonly ML_C5N_XLARGE: "ml.c5n.xlarge";
    readonly ML_C5_18XLARGE: "ml.c5.18xlarge";
    readonly ML_C5_2XLARGE: "ml.c5.2xlarge";
    readonly ML_C5_4XLARGE: "ml.c5.4xlarge";
    readonly ML_C5_9XLARGE: "ml.c5.9xlarge";
    readonly ML_C5_XLARGE: "ml.c5.xlarge";
    readonly ML_C6I_12XLARGE: "ml.c6i.12xlarge";
    readonly ML_C6I_16XLARGE: "ml.c6i.16xlarge";
    readonly ML_C6I_24XLARGE: "ml.c6i.24xlarge";
    readonly ML_C6I_2XLARGE: "ml.c6i.2xlarge";
    readonly ML_C6I_32XLARGE: "ml.c6i.32xlarge";
    readonly ML_C6I_4XLARGE: "ml.c6i.4xlarge";
    readonly ML_C6I_8XLARGE: "ml.c6i.8xlarge";
    readonly ML_C6I_XLARGE: "ml.c6i.xlarge";
    readonly ML_C7I_12XLARGE: "ml.c7i.12xlarge";
    readonly ML_C7I_16XLARGE: "ml.c7i.16xlarge";
    readonly ML_C7I_24XLARGE: "ml.c7i.24xlarge";
    readonly ML_C7I_2XLARGE: "ml.c7i.2xlarge";
    readonly ML_C7I_48XLARGE: "ml.c7i.48xlarge";
    readonly ML_C7I_4XLARGE: "ml.c7i.4xlarge";
    readonly ML_C7I_8XLARGE: "ml.c7i.8xlarge";
    readonly ML_C7I_LARGE: "ml.c7i.large";
    readonly ML_C7I_XLARGE: "ml.c7i.xlarge";
    readonly ML_G4DN_12XLARGE: "ml.g4dn.12xlarge";
    readonly ML_G4DN_16XLARGE: "ml.g4dn.16xlarge";
    readonly ML_G4DN_2XLARGE: "ml.g4dn.2xlarge";
    readonly ML_G4DN_4XLARGE: "ml.g4dn.4xlarge";
    readonly ML_G4DN_8XLARGE: "ml.g4dn.8xlarge";
    readonly ML_G4DN_XLARGE: "ml.g4dn.xlarge";
    readonly ML_G5_12XLARGE: "ml.g5.12xlarge";
    readonly ML_G5_16XLARGE: "ml.g5.16xlarge";
    readonly ML_G5_24XLARGE: "ml.g5.24xlarge";
    readonly ML_G5_2XLARGE: "ml.g5.2xlarge";
    readonly ML_G5_48XLARGE: "ml.g5.48xlarge";
    readonly ML_G5_4XLARGE: "ml.g5.4xlarge";
    readonly ML_G5_8XLARGE: "ml.g5.8xlarge";
    readonly ML_G5_XLARGE: "ml.g5.xlarge";
    readonly ML_G6E_12XLARGE: "ml.g6e.12xlarge";
    readonly ML_G6E_16XLARGE: "ml.g6e.16xlarge";
    readonly ML_G6E_24XLARGE: "ml.g6e.24xlarge";
    readonly ML_G6E_2XLARGE: "ml.g6e.2xlarge";
    readonly ML_G6E_48XLARGE: "ml.g6e.48xlarge";
    readonly ML_G6E_4XLARGE: "ml.g6e.4xlarge";
    readonly ML_G6E_8XLARGE: "ml.g6e.8xlarge";
    readonly ML_G6E_XLARGE: "ml.g6e.xlarge";
    readonly ML_G6_12XLARGE: "ml.g6.12xlarge";
    readonly ML_G6_16XLARGE: "ml.g6.16xlarge";
    readonly ML_G6_24XLARGE: "ml.g6.24xlarge";
    readonly ML_G6_2XLARGE: "ml.g6.2xlarge";
    readonly ML_G6_48XLARGE: "ml.g6.48xlarge";
    readonly ML_G6_4XLARGE: "ml.g6.4xlarge";
    readonly ML_G6_8XLARGE: "ml.g6.8xlarge";
    readonly ML_G6_XLARGE: "ml.g6.xlarge";
    readonly ML_G7E_12XLARGE: "ml.g7e.12xlarge";
    readonly ML_G7E_24XLARGE: "ml.g7e.24xlarge";
    readonly ML_G7E_2XLARGE: "ml.g7e.2xlarge";
    readonly ML_G7E_48XLARGE: "ml.g7e.48xlarge";
    readonly ML_G7E_4XLARGE: "ml.g7e.4xlarge";
    readonly ML_G7E_8XLARGE: "ml.g7e.8xlarge";
    readonly ML_M4_10XLARGE: "ml.m4.10xlarge";
    readonly ML_M4_16XLARGE: "ml.m4.16xlarge";
    readonly ML_M4_2XLARGE: "ml.m4.2xlarge";
    readonly ML_M4_4XLARGE: "ml.m4.4xlarge";
    readonly ML_M4_XLARGE: "ml.m4.xlarge";
    readonly ML_M5_12XLARGE: "ml.m5.12xlarge";
    readonly ML_M5_24XLARGE: "ml.m5.24xlarge";
    readonly ML_M5_2XLARGE: "ml.m5.2xlarge";
    readonly ML_M5_4XLARGE: "ml.m5.4xlarge";
    readonly ML_M5_LARGE: "ml.m5.large";
    readonly ML_M5_XLARGE: "ml.m5.xlarge";
    readonly ML_M6I_12XLARGE: "ml.m6i.12xlarge";
    readonly ML_M6I_16XLARGE: "ml.m6i.16xlarge";
    readonly ML_M6I_24XLARGE: "ml.m6i.24xlarge";
    readonly ML_M6I_2XLARGE: "ml.m6i.2xlarge";
    readonly ML_M6I_32XLARGE: "ml.m6i.32xlarge";
    readonly ML_M6I_4XLARGE: "ml.m6i.4xlarge";
    readonly ML_M6I_8XLARGE: "ml.m6i.8xlarge";
    readonly ML_M6I_LARGE: "ml.m6i.large";
    readonly ML_M6I_XLARGE: "ml.m6i.xlarge";
    readonly ML_M7I_12XLARGE: "ml.m7i.12xlarge";
    readonly ML_M7I_16XLARGE: "ml.m7i.16xlarge";
    readonly ML_M7I_24XLARGE: "ml.m7i.24xlarge";
    readonly ML_M7I_2XLARGE: "ml.m7i.2xlarge";
    readonly ML_M7I_48XLARGE: "ml.m7i.48xlarge";
    readonly ML_M7I_4XLARGE: "ml.m7i.4xlarge";
    readonly ML_M7I_8XLARGE: "ml.m7i.8xlarge";
    readonly ML_M7I_LARGE: "ml.m7i.large";
    readonly ML_M7I_XLARGE: "ml.m7i.xlarge";
    readonly ML_P2_16XLARGE: "ml.p2.16xlarge";
    readonly ML_P2_8XLARGE: "ml.p2.8xlarge";
    readonly ML_P2_XLARGE: "ml.p2.xlarge";
    readonly ML_P3DN_24XLARGE: "ml.p3dn.24xlarge";
    readonly ML_P3_16XLARGE: "ml.p3.16xlarge";
    readonly ML_P3_2XLARGE: "ml.p3.2xlarge";
    readonly ML_P3_8XLARGE: "ml.p3.8xlarge";
    readonly ML_P4DE_24XLARGE: "ml.p4de.24xlarge";
    readonly ML_P4D_24XLARGE: "ml.p4d.24xlarge";
    readonly ML_P5EN_48XLARGE: "ml.p5en.48xlarge";
    readonly ML_P5E_48XLARGE: "ml.p5e.48xlarge";
    readonly ML_P5_48XLARGE: "ml.p5.48xlarge";
    readonly ML_P5_4XLARGE: "ml.p5.4xlarge";
    readonly ML_P6E_GB200_36XLARGE: "ml.p6e-gb200.36xlarge";
    readonly ML_P6_B200_48XLARGE: "ml.p6-b200.48xlarge";
    readonly ML_P6_B300_48XLARGE: "ml.p6-b300.48xlarge";
    readonly ML_R5D_12XLARGE: "ml.r5d.12xlarge";
    readonly ML_R5D_16XLARGE: "ml.r5d.16xlarge";
    readonly ML_R5D_24XLARGE: "ml.r5d.24xlarge";
    readonly ML_R5D_2XLARGE: "ml.r5d.2xlarge";
    readonly ML_R5D_4XLARGE: "ml.r5d.4xlarge";
    readonly ML_R5D_8XLARGE: "ml.r5d.8xlarge";
    readonly ML_R5D_LARGE: "ml.r5d.large";
    readonly ML_R5D_XLARGE: "ml.r5d.xlarge";
    readonly ML_R5_12XLARGE: "ml.r5.12xlarge";
    readonly ML_R5_16XLARGE: "ml.r5.16xlarge";
    readonly ML_R5_24XLARGE: "ml.r5.24xlarge";
    readonly ML_R5_2XLARGE: "ml.r5.2xlarge";
    readonly ML_R5_4XLARGE: "ml.r5.4xlarge";
    readonly ML_R5_8XLARGE: "ml.r5.8xlarge";
    readonly ML_R5_LARGE: "ml.r5.large";
    readonly ML_R5_XLARGE: "ml.r5.xlarge";
    readonly ML_R7I_12XLARGE: "ml.r7i.12xlarge";
    readonly ML_R7I_16XLARGE: "ml.r7i.16xlarge";
    readonly ML_R7I_24XLARGE: "ml.r7i.24xlarge";
    readonly ML_R7I_2XLARGE: "ml.r7i.2xlarge";
    readonly ML_R7I_48XLARGE: "ml.r7i.48xlarge";
    readonly ML_R7I_4XLARGE: "ml.r7i.4xlarge";
    readonly ML_R7I_8XLARGE: "ml.r7i.8xlarge";
    readonly ML_R7I_LARGE: "ml.r7i.large";
    readonly ML_R7I_XLARGE: "ml.r7i.xlarge";
    readonly ML_T3_2XLARGE: "ml.t3.2xlarge";
    readonly ML_T3_LARGE: "ml.t3.large";
    readonly ML_T3_MEDIUM: "ml.t3.medium";
    readonly ML_T3_XLARGE: "ml.t3.xlarge";
    readonly ML_TRN1N_32XLARGE: "ml.trn1n.32xlarge";
    readonly ML_TRN1_2XLARGE: "ml.trn1.2xlarge";
    readonly ML_TRN1_32XLARGE: "ml.trn1.32xlarge";
    readonly ML_TRN2_48XLARGE: "ml.trn2.48xlarge";
};
/**
 * @public
 */
export type TrainingInstanceType = (typeof TrainingInstanceType)[keyof typeof TrainingInstanceType];
/**
 * @public
 * @enum
 */
export declare const BatchStrategy: {
    readonly MULTI_RECORD: "MultiRecord";
    readonly SINGLE_RECORD: "SingleRecord";
};
/**
 * @public
 */
export type BatchStrategy = (typeof BatchStrategy)[keyof typeof BatchStrategy];
/**
 * @public
 * @enum
 */
export declare const SplitType: {
    readonly LINE: "Line";
    readonly NONE: "None";
    readonly RECORDIO: "RecordIO";
    readonly TFRECORD: "TFRecord";
};
/**
 * @public
 */
export type SplitType = (typeof SplitType)[keyof typeof SplitType];
/**
 * @public
 * @enum
 */
export declare const AssemblyType: {
    readonly LINE: "Line";
    readonly NONE: "None";
};
/**
 * @public
 */
export type AssemblyType = (typeof AssemblyType)[keyof typeof AssemblyType];
/**
 * @public
 * @enum
 */
export declare const FeatureStatus: {
    readonly Disabled: "DISABLED";
    readonly Enabled: "ENABLED";
};
/**
 * @public
 */
export type FeatureStatus = (typeof FeatureStatus)[keyof typeof FeatureStatus];
/**
 * @public
 * @enum
 */
export declare const AppType: {
    readonly Canvas: "Canvas";
    readonly CodeEditor: "CodeEditor";
    readonly DetailedProfiler: "DetailedProfiler";
    readonly JupyterLab: "JupyterLab";
    readonly JupyterServer: "JupyterServer";
    readonly KernelGateway: "KernelGateway";
    readonly RSessionGateway: "RSessionGateway";
    readonly RStudioServerPro: "RStudioServerPro";
    readonly TensorBoard: "TensorBoard";
};
/**
 * @public
 */
export type AppType = (typeof AppType)[keyof typeof AppType];
/**
 * @public
 * @enum
 */
export declare const AppInstanceType: {
    readonly ML_C5_12XLARGE: "ml.c5.12xlarge";
    readonly ML_C5_18XLARGE: "ml.c5.18xlarge";
    readonly ML_C5_24XLARGE: "ml.c5.24xlarge";
    readonly ML_C5_2XLARGE: "ml.c5.2xlarge";
    readonly ML_C5_4XLARGE: "ml.c5.4xlarge";
    readonly ML_C5_9XLARGE: "ml.c5.9xlarge";
    readonly ML_C5_LARGE: "ml.c5.large";
    readonly ML_C5_XLARGE: "ml.c5.xlarge";
    readonly ML_C6ID_12XLARGE: "ml.c6id.12xlarge";
    readonly ML_C6ID_16XLARGE: "ml.c6id.16xlarge";
    readonly ML_C6ID_24XLARGE: "ml.c6id.24xlarge";
    readonly ML_C6ID_2XLARGE: "ml.c6id.2xlarge";
    readonly ML_C6ID_32XLARGE: "ml.c6id.32xlarge";
    readonly ML_C6ID_4XLARGE: "ml.c6id.4xlarge";
    readonly ML_C6ID_8XLARGE: "ml.c6id.8xlarge";
    readonly ML_C6ID_LARGE: "ml.c6id.large";
    readonly ML_C6ID_XLARGE: "ml.c6id.xlarge";
    readonly ML_C6I_12XLARGE: "ml.c6i.12xlarge";
    readonly ML_C6I_16XLARGE: "ml.c6i.16xlarge";
    readonly ML_C6I_24XLARGE: "ml.c6i.24xlarge";
    readonly ML_C6I_2XLARGE: "ml.c6i.2xlarge";
    readonly ML_C6I_32XLARGE: "ml.c6i.32xlarge";
    readonly ML_C6I_4XLARGE: "ml.c6i.4xlarge";
    readonly ML_C6I_8XLARGE: "ml.c6i.8xlarge";
    readonly ML_C6I_LARGE: "ml.c6i.large";
    readonly ML_C6I_XLARGE: "ml.c6i.xlarge";
    readonly ML_C7I_12XLARGE: "ml.c7i.12xlarge";
    readonly ML_C7I_16XLARGE: "ml.c7i.16xlarge";
    readonly ML_C7I_24XLARGE: "ml.c7i.24xlarge";
    readonly ML_C7I_2XLARGE: "ml.c7i.2xlarge";
    readonly ML_C7I_48XLARGE: "ml.c7i.48xlarge";
    readonly ML_C7I_4XLARGE: "ml.c7i.4xlarge";
    readonly ML_C7I_8XLARGE: "ml.c7i.8xlarge";
    readonly ML_C7I_LARGE: "ml.c7i.large";
    readonly ML_C7I_XLARGE: "ml.c7i.xlarge";
    readonly ML_G4DN_12XLARGE: "ml.g4dn.12xlarge";
    readonly ML_G4DN_16XLARGE: "ml.g4dn.16xlarge";
    readonly ML_G4DN_2XLARGE: "ml.g4dn.2xlarge";
    readonly ML_G4DN_4XLARGE: "ml.g4dn.4xlarge";
    readonly ML_G4DN_8XLARGE: "ml.g4dn.8xlarge";
    readonly ML_G4DN_XLARGE: "ml.g4dn.xlarge";
    readonly ML_G5_12XLARGE: "ml.g5.12xlarge";
    readonly ML_G5_16XLARGE: "ml.g5.16xlarge";
    readonly ML_G5_24XLARGE: "ml.g5.24xlarge";
    readonly ML_G5_2XLARGE: "ml.g5.2xlarge";
    readonly ML_G5_48XLARGE: "ml.g5.48xlarge";
    readonly ML_G5_4XLARGE: "ml.g5.4xlarge";
    readonly ML_G5_8XLARGE: "ml.g5.8xlarge";
    readonly ML_G5_XLARGE: "ml.g5.xlarge";
    readonly ML_G6E_12XLARGE: "ml.g6e.12xlarge";
    readonly ML_G6E_16XLARGE: "ml.g6e.16xlarge";
    readonly ML_G6E_24XLARGE: "ml.g6e.24xlarge";
    readonly ML_G6E_2XLARGE: "ml.g6e.2xlarge";
    readonly ML_G6E_48XLARGE: "ml.g6e.48xlarge";
    readonly ML_G6E_4XLARGE: "ml.g6e.4xlarge";
    readonly ML_G6E_8XLARGE: "ml.g6e.8xlarge";
    readonly ML_G6E_XLARGE: "ml.g6e.xlarge";
    readonly ML_G6_12XLARGE: "ml.g6.12xlarge";
    readonly ML_G6_16XLARGE: "ml.g6.16xlarge";
    readonly ML_G6_24XLARGE: "ml.g6.24xlarge";
    readonly ML_G6_2XLARGE: "ml.g6.2xlarge";
    readonly ML_G6_48XLARGE: "ml.g6.48xlarge";
    readonly ML_G6_4XLARGE: "ml.g6.4xlarge";
    readonly ML_G6_8XLARGE: "ml.g6.8xlarge";
    readonly ML_G6_XLARGE: "ml.g6.xlarge";
    readonly ML_GEOSPATIAL_INTERACTIVE: "ml.geospatial.interactive";
    readonly ML_M5D_12XLARGE: "ml.m5d.12xlarge";
    readonly ML_M5D_16XLARGE: "ml.m5d.16xlarge";
    readonly ML_M5D_24XLARGE: "ml.m5d.24xlarge";
    readonly ML_M5D_2XLARGE: "ml.m5d.2xlarge";
    readonly ML_M5D_4XLARGE: "ml.m5d.4xlarge";
    readonly ML_M5D_8XLARGE: "ml.m5d.8xlarge";
    readonly ML_M5D_LARGE: "ml.m5d.large";
    readonly ML_M5D_XLARGE: "ml.m5d.xlarge";
    readonly ML_M5_12XLARGE: "ml.m5.12xlarge";
    readonly ML_M5_16XLARGE: "ml.m5.16xlarge";
    readonly ML_M5_24XLARGE: "ml.m5.24xlarge";
    readonly ML_M5_2XLARGE: "ml.m5.2xlarge";
    readonly ML_M5_4XLARGE: "ml.m5.4xlarge";
    readonly ML_M5_8XLARGE: "ml.m5.8xlarge";
    readonly ML_M5_LARGE: "ml.m5.large";
    readonly ML_M5_XLARGE: "ml.m5.xlarge";
    readonly ML_M6ID_12XLARGE: "ml.m6id.12xlarge";
    readonly ML_M6ID_16XLARGE: "ml.m6id.16xlarge";
    readonly ML_M6ID_24XLARGE: "ml.m6id.24xlarge";
    readonly ML_M6ID_2XLARGE: "ml.m6id.2xlarge";
    readonly ML_M6ID_32XLARGE: "ml.m6id.32xlarge";
    readonly ML_M6ID_4XLARGE: "ml.m6id.4xlarge";
    readonly ML_M6ID_8XLARGE: "ml.m6id.8xlarge";
    readonly ML_M6ID_LARGE: "ml.m6id.large";
    readonly ML_M6ID_XLARGE: "ml.m6id.xlarge";
    readonly ML_M6I_12XLARGE: "ml.m6i.12xlarge";
    readonly ML_M6I_16XLARGE: "ml.m6i.16xlarge";
    readonly ML_M6I_24XLARGE: "ml.m6i.24xlarge";
    readonly ML_M6I_2XLARGE: "ml.m6i.2xlarge";
    readonly ML_M6I_32XLARGE: "ml.m6i.32xlarge";
    readonly ML_M6I_4XLARGE: "ml.m6i.4xlarge";
    readonly ML_M6I_8XLARGE: "ml.m6i.8xlarge";
    readonly ML_M6I_LARGE: "ml.m6i.large";
    readonly ML_M6I_XLARGE: "ml.m6i.xlarge";
    readonly ML_M7I_12XLARGE: "ml.m7i.12xlarge";
    readonly ML_M7I_16XLARGE: "ml.m7i.16xlarge";
    readonly ML_M7I_24XLARGE: "ml.m7i.24xlarge";
    readonly ML_M7I_2XLARGE: "ml.m7i.2xlarge";
    readonly ML_M7I_48XLARGE: "ml.m7i.48xlarge";
    readonly ML_M7I_4XLARGE: "ml.m7i.4xlarge";
    readonly ML_M7I_8XLARGE: "ml.m7i.8xlarge";
    readonly ML_M7I_LARGE: "ml.m7i.large";
    readonly ML_M7I_XLARGE: "ml.m7i.xlarge";
    readonly ML_P3DN_24XLARGE: "ml.p3dn.24xlarge";
    readonly ML_P3_16XLARGE: "ml.p3.16xlarge";
    readonly ML_P3_2XLARGE: "ml.p3.2xlarge";
    readonly ML_P3_8XLARGE: "ml.p3.8xlarge";
    readonly ML_P4DE_24XLARGE: "ml.p4de.24xlarge";
    readonly ML_P4D_24XLARGE: "ml.p4d.24xlarge";
    readonly ML_P5EN_48XLARGE: "ml.p5en.48xlarge";
    readonly ML_P5_48XLARGE: "ml.p5.48xlarge";
    readonly ML_P6_B200_48XLARGE: "ml.p6-b200.48xlarge";
    readonly ML_R5_12XLARGE: "ml.r5.12xlarge";
    readonly ML_R5_16XLARGE: "ml.r5.16xlarge";
    readonly ML_R5_24XLARGE: "ml.r5.24xlarge";
    readonly ML_R5_2XLARGE: "ml.r5.2xlarge";
    readonly ML_R5_4XLARGE: "ml.r5.4xlarge";
    readonly ML_R5_8XLARGE: "ml.r5.8xlarge";
    readonly ML_R5_LARGE: "ml.r5.large";
    readonly ML_R5_XLARGE: "ml.r5.xlarge";
    readonly ML_R6ID_12XLARGE: "ml.r6id.12xlarge";
    readonly ML_R6ID_16XLARGE: "ml.r6id.16xlarge";
    readonly ML_R6ID_24XLARGE: "ml.r6id.24xlarge";
    readonly ML_R6ID_2XLARGE: "ml.r6id.2xlarge";
    readonly ML_R6ID_32XLARGE: "ml.r6id.32xlarge";
    readonly ML_R6ID_4XLARGE: "ml.r6id.4xlarge";
    readonly ML_R6ID_8XLARGE: "ml.r6id.8xlarge";
    readonly ML_R6ID_LARGE: "ml.r6id.large";
    readonly ML_R6ID_XLARGE: "ml.r6id.xlarge";
    readonly ML_R6I_12XLARGE: "ml.r6i.12xlarge";
    readonly ML_R6I_16XLARGE: "ml.r6i.16xlarge";
    readonly ML_R6I_24XLARGE: "ml.r6i.24xlarge";
    readonly ML_R6I_2XLARGE: "ml.r6i.2xlarge";
    readonly ML_R6I_32XLARGE: "ml.r6i.32xlarge";
    readonly ML_R6I_4XLARGE: "ml.r6i.4xlarge";
    readonly ML_R6I_8XLARGE: "ml.r6i.8xlarge";
    readonly ML_R6I_LARGE: "ml.r6i.large";
    readonly ML_R6I_XLARGE: "ml.r6i.xlarge";
    readonly ML_R7I_12XLARGE: "ml.r7i.12xlarge";
    readonly ML_R7I_16XLARGE: "ml.r7i.16xlarge";
    readonly ML_R7I_24XLARGE: "ml.r7i.24xlarge";
    readonly ML_R7I_2XLARGE: "ml.r7i.2xlarge";
    readonly ML_R7I_48XLARGE: "ml.r7i.48xlarge";
    readonly ML_R7I_4XLARGE: "ml.r7i.4xlarge";
    readonly ML_R7I_8XLARGE: "ml.r7i.8xlarge";
    readonly ML_R7I_LARGE: "ml.r7i.large";
    readonly ML_R7I_XLARGE: "ml.r7i.xlarge";
    readonly ML_T3_2XLARGE: "ml.t3.2xlarge";
    readonly ML_T3_LARGE: "ml.t3.large";
    readonly ML_T3_MEDIUM: "ml.t3.medium";
    readonly ML_T3_MICRO: "ml.t3.micro";
    readonly ML_T3_SMALL: "ml.t3.small";
    readonly ML_T3_XLARGE: "ml.t3.xlarge";
    readonly ML_TRN1N_32XLARGE: "ml.trn1n.32xlarge";
    readonly ML_TRN1_2XLARGE: "ml.trn1.2xlarge";
    readonly ML_TRN1_32XLARGE: "ml.trn1.32xlarge";
    readonly SYSTEM: "system";
};
/**
 * @public
 */
export type AppInstanceType = (typeof AppInstanceType)[keyof typeof AppInstanceType];
/**
 * @public
 * @enum
 */
export declare const AppStatus: {
    readonly Deleted: "Deleted";
    readonly Deleting: "Deleting";
    readonly Failed: "Failed";
    readonly InService: "InService";
    readonly Pending: "Pending";
};
/**
 * @public
 */
export type AppStatus = (typeof AppStatus)[keyof typeof AppStatus];
/**
 * @public
 * @enum
 */
export declare const AppImageConfigSortKey: {
    readonly CreationTime: "CreationTime";
    readonly LastModifiedTime: "LastModifiedTime";
    readonly Name: "Name";
};
/**
 * @public
 */
export type AppImageConfigSortKey = (typeof AppImageConfigSortKey)[keyof typeof AppImageConfigSortKey];
/**
 * @public
 * @enum
 */
export declare const LifecycleManagement: {
    readonly Disabled: "DISABLED";
    readonly Enabled: "ENABLED";
};
/**
 * @public
 */
export type LifecycleManagement = (typeof LifecycleManagement)[keyof typeof LifecycleManagement];
/**
 * @public
 * @enum
 */
export declare const AppNetworkAccessType: {
    readonly PublicInternetOnly: "PublicInternetOnly";
    readonly VpcOnly: "VpcOnly";
};
/**
 * @public
 */
export type AppNetworkAccessType = (typeof AppNetworkAccessType)[keyof typeof AppNetworkAccessType];
/**
 * @public
 * @enum
 */
export declare const AppSecurityGroupManagement: {
    readonly Customer: "Customer";
    readonly Service: "Service";
};
/**
 * @public
 */
export type AppSecurityGroupManagement = (typeof AppSecurityGroupManagement)[keyof typeof AppSecurityGroupManagement];
/**
 * @public
 * @enum
 */
export declare const AppSortKey: {
    readonly CreationTime: "CreationTime";
};
/**
 * @public
 */
export type AppSortKey = (typeof AppSortKey)[keyof typeof AppSortKey];
/**
 * @public
 * @enum
 */
export declare const ArtifactSourceIdType: {
    readonly CUSTOM: "Custom";
    readonly MD5_HASH: "MD5Hash";
    readonly S3_ETAG: "S3ETag";
    readonly S3_VERSION: "S3Version";
};
/**
 * @public
 */
export type ArtifactSourceIdType = (typeof ArtifactSourceIdType)[keyof typeof ArtifactSourceIdType];
/**
 * @public
 * @enum
 */
export declare const AsyncNotificationTopicTypes: {
    readonly ERROR_NOTIFICATION_TOPIC: "ERROR_NOTIFICATION_TOPIC";
    readonly SUCCESS_NOTIFICATION_TOPIC: "SUCCESS_NOTIFICATION_TOPIC";
};
/**
 * @public
 */
export type AsyncNotificationTopicTypes = (typeof AsyncNotificationTopicTypes)[keyof typeof AsyncNotificationTopicTypes];
/**
 * @public
 * @enum
 */
export declare const AthenaResultCompressionType: {
    readonly GZIP: "GZIP";
    readonly SNAPPY: "SNAPPY";
    readonly ZLIB: "ZLIB";
};
/**
 * @public
 */
export type AthenaResultCompressionType = (typeof AthenaResultCompressionType)[keyof typeof AthenaResultCompressionType];
/**
 * @public
 * @enum
 */
export declare const AthenaResultFormat: {
    readonly AVRO: "AVRO";
    readonly JSON: "JSON";
    readonly ORC: "ORC";
    readonly PARQUET: "PARQUET";
    readonly TEXTFILE: "TEXTFILE";
};
/**
 * @public
 */
export type AthenaResultFormat = (typeof AthenaResultFormat)[keyof typeof AthenaResultFormat];
/**
 * @public
 * @enum
 */
export declare const VolumeAttachmentStatus: {
    readonly ATTACHED: "attached";
    readonly ATTACHING: "attaching";
    readonly BUSY: "busy";
    readonly DETACHED: "detached";
    readonly DETACHING: "detaching";
};
/**
 * @public
 */
export type VolumeAttachmentStatus = (typeof VolumeAttachmentStatus)[keyof typeof VolumeAttachmentStatus];
/**
 * @public
 * @enum
 */
export declare const AuthMode: {
    readonly IAM: "IAM";
    readonly SSO: "SSO";
};
/**
 * @public
 */
export type AuthMode = (typeof AuthMode)[keyof typeof AuthMode];
/**
 * @public
 * @enum
 */
export declare const AutoMLAlgorithm: {
    readonly ARIMA: "arima";
    readonly CATBOOST: "catboost";
    readonly CNN_QR: "cnn-qr";
    readonly DEEPAR: "deepar";
    readonly ETS: "ets";
    readonly EXTRA_TREES: "extra-trees";
    readonly FASTAI: "fastai";
    readonly LIGHTGBM: "lightgbm";
    readonly LINEAR_LEARNER: "linear-learner";
    readonly MLP: "mlp";
    readonly NN_TORCH: "nn-torch";
    readonly NPTS: "npts";
    readonly PROPHET: "prophet";
    readonly RANDOMFOREST: "randomforest";
    readonly XGBOOST: "xgboost";
};
/**
 * @public
 */
export type AutoMLAlgorithm = (typeof AutoMLAlgorithm)[keyof typeof AutoMLAlgorithm];
/**
 * @public
 * @enum
 */
export declare const AutoMLMetricEnum: {
    readonly ACCURACY: "Accuracy";
    readonly AUC: "AUC";
    readonly AVERAGE_WEIGHTED_QUANTILE_LOSS: "AverageWeightedQuantileLoss";
    readonly BALANCED_ACCURACY: "BalancedAccuracy";
    readonly F1: "F1";
    readonly F1_MACRO: "F1macro";
    readonly MAE: "MAE";
    readonly MAPE: "MAPE";
    readonly MASE: "MASE";
    readonly MSE: "MSE";
    readonly PRECISION: "Precision";
    readonly PRECISION_MACRO: "PrecisionMacro";
    readonly R2: "R2";
    readonly RECALL: "Recall";
    readonly RECALL_MACRO: "RecallMacro";
    readonly RMSE: "RMSE";
    readonly WAPE: "WAPE";
};
/**
 * @public
 */
export type AutoMLMetricEnum = (typeof AutoMLMetricEnum)[keyof typeof AutoMLMetricEnum];
/**
 * @public
 * @enum
 */
export declare const MetricSetSource: {
    readonly TEST: "Test";
    readonly TRAIN: "Train";
    readonly VALIDATION: "Validation";
};
/**
 * @public
 */
export type MetricSetSource = (typeof MetricSetSource)[keyof typeof MetricSetSource];
/**
 * @public
 * @enum
 */
export declare const AutoMLMetricExtendedEnum: {
    readonly ACCURACY: "Accuracy";
    readonly AUC: "AUC";
    readonly AVERAGE_WEIGHTED_QUANTILE_LOSS: "AverageWeightedQuantileLoss";
    readonly BALANCED_ACCURACY: "BalancedAccuracy";
    readonly F1: "F1";
    readonly F1_MACRO: "F1macro";
    readonly INFERENCE_LATENCY: "InferenceLatency";
    readonly LogLoss: "LogLoss";
    readonly MAE: "MAE";
    readonly MAPE: "MAPE";
    readonly MASE: "MASE";
    readonly MSE: "MSE";
    readonly PERPLEXITY: "Perplexity";
    readonly PRECISION: "Precision";
    readonly PRECISION_MACRO: "PrecisionMacro";
    readonly R2: "R2";
    readonly RECALL: "Recall";
    readonly RECALL_MACRO: "RecallMacro";
    readonly RMSE: "RMSE";
    readonly ROUGE1: "Rouge1";
    readonly ROUGE2: "Rouge2";
    readonly ROUGEL: "RougeL";
    readonly ROUGEL_SUM: "RougeLSum";
    readonly TRAINING_LOSS: "TrainingLoss";
    readonly VALIDATION_LOSS: "ValidationLoss";
    readonly WAPE: "WAPE";
};
/**
 * @public
 */
export type AutoMLMetricExtendedEnum = (typeof AutoMLMetricExtendedEnum)[keyof typeof AutoMLMetricExtendedEnum];
/**
 * @public
 * @enum
 */
export declare const CandidateStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type CandidateStatus = (typeof CandidateStatus)[keyof typeof CandidateStatus];
/**
 * @public
 * @enum
 */
export declare const CandidateStepType: {
    readonly PROCESSING: "AWS::SageMaker::ProcessingJob";
    readonly TRAINING: "AWS::SageMaker::TrainingJob";
    readonly TRANSFORM: "AWS::SageMaker::TransformJob";
};
/**
 * @public
 */
export type CandidateStepType = (typeof CandidateStepType)[keyof typeof CandidateStepType];
/**
 * @public
 * @enum
 */
export declare const AutoMLJobObjectiveType: {
    readonly MAXIMIZE: "Maximize";
    readonly MINIMIZE: "Minimize";
};
/**
 * @public
 */
export type AutoMLJobObjectiveType = (typeof AutoMLJobObjectiveType)[keyof typeof AutoMLJobObjectiveType];
/**
 * @public
 * @enum
 */
export declare const AutoMLProcessingUnit: {
    readonly CPU: "CPU";
    readonly GPU: "GPU";
};
/**
 * @public
 */
export type AutoMLProcessingUnit = (typeof AutoMLProcessingUnit)[keyof typeof AutoMLProcessingUnit];
/**
 * @public
 * @enum
 */
export declare const ObjectiveStatus: {
    readonly Failed: "Failed";
    readonly Pending: "Pending";
    readonly Succeeded: "Succeeded";
};
/**
 * @public
 */
export type ObjectiveStatus = (typeof ObjectiveStatus)[keyof typeof ObjectiveStatus];
/**
 * @public
 * @enum
 */
export declare const AutoMLChannelType: {
    readonly TRAINING: "training";
    readonly VALIDATION: "validation";
};
/**
 * @public
 */
export type AutoMLChannelType = (typeof AutoMLChannelType)[keyof typeof AutoMLChannelType];
/**
 * @public
 * @enum
 */
export declare const AutoMLS3DataType: {
    readonly AUGMENTED_MANIFEST_FILE: "AugmentedManifestFile";
    readonly MANIFEST_FILE: "ManifestFile";
    readonly S3_PREFIX: "S3Prefix";
};
/**
 * @public
 */
export type AutoMLS3DataType = (typeof AutoMLS3DataType)[keyof typeof AutoMLS3DataType];
/**
 * @public
 * @enum
 */
export declare const AutoMLMode: {
    readonly AUTO: "AUTO";
    readonly ENSEMBLING: "ENSEMBLING";
    readonly HYPERPARAMETER_TUNING: "HYPERPARAMETER_TUNING";
};
/**
 * @public
 */
export type AutoMLMode = (typeof AutoMLMode)[keyof typeof AutoMLMode];
/**
 * @public
 * @enum
 */
export declare const AutoMLJobSecondaryStatus: {
    readonly ANALYZING_DATA: "AnalyzingData";
    readonly CANDIDATE_DEFINITIONS_GENERATED: "CandidateDefinitionsGenerated";
    readonly COMPLETED: "Completed";
    readonly DEPLOYING_MODEL: "DeployingModel";
    readonly EXPLAINABILITY_ERROR: "ExplainabilityError";
    readonly FAILED: "Failed";
    readonly FEATURE_ENGINEERING: "FeatureEngineering";
    readonly GENERATING_EXPLAINABILITY_REPORT: "GeneratingExplainabilityReport";
    readonly GENERATING_MODEL_INSIGHTS_REPORT: "GeneratingModelInsightsReport";
    readonly MAX_AUTO_ML_JOB_RUNTIME_REACHED: "MaxAutoMLJobRuntimeReached";
    readonly MAX_CANDIDATES_REACHED: "MaxCandidatesReached";
    readonly MODEL_DEPLOYMENT_ERROR: "ModelDeploymentError";
    readonly MODEL_INSIGHTS_ERROR: "ModelInsightsError";
    readonly MODEL_TUNING: "ModelTuning";
    readonly PRE_TRAINING: "PreTraining";
    readonly STARTING: "Starting";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
    readonly TRAINING_MODELS: "TrainingModels";
};
/**
 * @public
 */
export type AutoMLJobSecondaryStatus = (typeof AutoMLJobSecondaryStatus)[keyof typeof AutoMLJobSecondaryStatus];
/**
 * @public
 * @enum
 */
export declare const AutoMLJobStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type AutoMLJobStatus = (typeof AutoMLJobStatus)[keyof typeof AutoMLJobStatus];
/**
 * @public
 * @enum
 */
export declare const ProblemType: {
    readonly BINARY_CLASSIFICATION: "BinaryClassification";
    readonly MULTICLASS_CLASSIFICATION: "MulticlassClassification";
    readonly REGRESSION: "Regression";
};
/**
 * @public
 */
export type ProblemType = (typeof ProblemType)[keyof typeof ProblemType];
/**
 * @public
 * @enum
 */
export declare const FillingType: {
    readonly Backfill: "backfill";
    readonly BackfillValue: "backfill_value";
    readonly Frontfill: "frontfill";
    readonly FrontfillValue: "frontfill_value";
    readonly Futurefill: "futurefill";
    readonly FuturefillValue: "futurefill_value";
    readonly Middlefill: "middlefill";
    readonly MiddlefillValue: "middlefill_value";
};
/**
 * @public
 */
export type FillingType = (typeof FillingType)[keyof typeof FillingType];
/**
 * @public
 * @enum
 */
export declare const AutoMLProblemTypeConfigName: {
    readonly IMAGE_CLASSIFICATION: "ImageClassification";
    readonly TABULAR: "Tabular";
    readonly TEXT_CLASSIFICATION: "TextClassification";
    readonly TEXT_GENERATION: "TextGeneration";
    readonly TIMESERIES_FORECASTING: "TimeSeriesForecasting";
};
/**
 * @public
 */
export type AutoMLProblemTypeConfigName = (typeof AutoMLProblemTypeConfigName)[keyof typeof AutoMLProblemTypeConfigName];
/**
 * @public
 * @enum
 */
export declare const AutoMLSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type AutoMLSortBy = (typeof AutoMLSortBy)[keyof typeof AutoMLSortBy];
/**
 * @public
 * @enum
 */
export declare const AutoMLSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type AutoMLSortOrder = (typeof AutoMLSortOrder)[keyof typeof AutoMLSortOrder];
/**
 * @public
 * @enum
 */
export declare const AutoMountHomeEFS: {
    readonly DEFAULT_AS_DOMAIN: "DefaultAsDomain";
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type AutoMountHomeEFS = (typeof AutoMountHomeEFS)[keyof typeof AutoMountHomeEFS];
/**
 * @public
 * @enum
 */
export declare const AutotuneMode: {
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type AutotuneMode = (typeof AutotuneMode)[keyof typeof AutotuneMode];
/**
 * @public
 * @enum
 */
export declare const AwsManagedHumanLoopRequestSource: {
    readonly REKOGNITION_DETECT_MODERATION_LABELS_IMAGE_V3: "AWS/Rekognition/DetectModerationLabels/Image/V3";
    readonly TEXTRACT_ANALYZE_DOCUMENT_FORMS_V1: "AWS/Textract/AnalyzeDocument/Forms/V1";
};
/**
 * @public
 */
export type AwsManagedHumanLoopRequestSource = (typeof AwsManagedHumanLoopRequestSource)[keyof typeof AwsManagedHumanLoopRequestSource];
/**
 * @public
 * @enum
 */
export declare const BatchAddClusterNodesErrorCode: {
    readonly INSTANCE_GROUP_NOT_FOUND: "InstanceGroupNotFound";
    readonly INVALID_INSTANCE_GROUP_STATUS: "InvalidInstanceGroupStatus";
};
/**
 * @public
 */
export type BatchAddClusterNodesErrorCode = (typeof BatchAddClusterNodesErrorCode)[keyof typeof BatchAddClusterNodesErrorCode];
/**
 * @public
 * @enum
 */
export declare const ClusterInstanceStatus: {
    readonly DEEP_HEALTH_CHECK_IN_PROGRESS: "DeepHealthCheckInProgress";
    readonly FAILURE: "Failure";
    readonly NOT_FOUND: "NotFound";
    readonly PENDING: "Pending";
    readonly RUNNING: "Running";
    readonly SHUTTING_DOWN: "ShuttingDown";
    readonly SYSTEM_UPDATING: "SystemUpdating";
};
/**
 * @public
 */
export type ClusterInstanceStatus = (typeof ClusterInstanceStatus)[keyof typeof ClusterInstanceStatus];
/**
 * @public
 * @enum
 */
export declare const BatchDeleteClusterNodesErrorCode: {
    readonly INVALID_NODE_STATUS: "InvalidNodeStatus";
    readonly NODE_ID_IN_USE: "NodeIdInUse";
    readonly NODE_ID_NOT_FOUND: "NodeIdNotFound";
};
/**
 * @public
 */
export type BatchDeleteClusterNodesErrorCode = (typeof BatchDeleteClusterNodesErrorCode)[keyof typeof BatchDeleteClusterNodesErrorCode];
/**
 * @public
 * @enum
 */
export declare const ModelApprovalStatus: {
    readonly APPROVED: "Approved";
    readonly PENDING_MANUAL_APPROVAL: "PendingManualApproval";
    readonly REJECTED: "Rejected";
};
/**
 * @public
 */
export type ModelApprovalStatus = (typeof ModelApprovalStatus)[keyof typeof ModelApprovalStatus];
/**
 * @public
 * @enum
 */
export declare const ModelPackageRegistrationType: {
    readonly LOGGED: "Logged";
    readonly REGISTERED: "Registered";
};
/**
 * @public
 */
export type ModelPackageRegistrationType = (typeof ModelPackageRegistrationType)[keyof typeof ModelPackageRegistrationType];
/**
 * @public
 * @enum
 */
export declare const ModelPackageStatus: {
    readonly COMPLETED: "Completed";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly PENDING: "Pending";
};
/**
 * @public
 */
export type ModelPackageStatus = (typeof ModelPackageStatus)[keyof typeof ModelPackageStatus];
/**
 * @public
 * @enum
 */
export declare const BatchRebootClusterNodesErrorCode: {
    readonly INSTANCE_ID_IN_USE: "InstanceIdInUse";
    readonly INSTANCE_ID_NOT_FOUND: "InstanceIdNotFound";
    readonly INTERNAL_SERVER_ERROR: "InternalServerError";
    readonly INVALID_INSTANCE_STATUS: "InvalidInstanceStatus";
};
/**
 * @public
 */
export type BatchRebootClusterNodesErrorCode = (typeof BatchRebootClusterNodesErrorCode)[keyof typeof BatchRebootClusterNodesErrorCode];
/**
 * @public
 * @enum
 */
export declare const BatchReplaceClusterNodesErrorCode: {
    readonly INSTANCE_ID_IN_USE: "InstanceIdInUse";
    readonly INSTANCE_ID_NOT_FOUND: "InstanceIdNotFound";
    readonly INTERNAL_SERVER_ERROR: "InternalServerError";
    readonly INVALID_INSTANCE_STATUS: "InvalidInstanceStatus";
};
/**
 * @public
 */
export type BatchReplaceClusterNodesErrorCode = (typeof BatchReplaceClusterNodesErrorCode)[keyof typeof BatchReplaceClusterNodesErrorCode];
/**
 * @public
 * @enum
 */
export declare const ProcessingS3DataDistributionType: {
    readonly FULLYREPLICATED: "FullyReplicated";
    readonly SHARDEDBYS3KEY: "ShardedByS3Key";
};
/**
 * @public
 */
export type ProcessingS3DataDistributionType = (typeof ProcessingS3DataDistributionType)[keyof typeof ProcessingS3DataDistributionType];
/**
 * @public
 * @enum
 */
export declare const ProcessingS3InputMode: {
    readonly FILE: "File";
    readonly PIPE: "Pipe";
};
/**
 * @public
 */
export type ProcessingS3InputMode = (typeof ProcessingS3InputMode)[keyof typeof ProcessingS3InputMode];
/**
 * @public
 * @enum
 */
export declare const CapacitySizeType: {
    readonly CAPACITY_PERCENT: "CAPACITY_PERCENT";
    readonly INSTANCE_COUNT: "INSTANCE_COUNT";
};
/**
 * @public
 */
export type CapacitySizeType = (typeof CapacitySizeType)[keyof typeof CapacitySizeType];
/**
 * @public
 * @enum
 */
export declare const TrafficRoutingConfigType: {
    readonly ALL_AT_ONCE: "ALL_AT_ONCE";
    readonly CANARY: "CANARY";
    readonly LINEAR: "LINEAR";
};
/**
 * @public
 */
export type TrafficRoutingConfigType = (typeof TrafficRoutingConfigType)[keyof typeof TrafficRoutingConfigType];
/**
 * @public
 * @enum
 */
export declare const BooleanOperator: {
    readonly AND: "And";
    readonly OR: "Or";
};
/**
 * @public
 */
export type BooleanOperator = (typeof BooleanOperator)[keyof typeof BooleanOperator];
/**
 * @public
 * @enum
 */
export declare const CandidateSortBy: {
    readonly CreationTime: "CreationTime";
    readonly FinalObjectiveMetricValue: "FinalObjectiveMetricValue";
    readonly Status: "Status";
};
/**
 * @public
 */
export type CandidateSortBy = (typeof CandidateSortBy)[keyof typeof CandidateSortBy];
/**
 * @public
 * @enum
 */
export declare const DataSourceName: {
    readonly SalesforceGenie: "SalesforceGenie";
    readonly Snowflake: "Snowflake";
};
/**
 * @public
 */
export type DataSourceName = (typeof DataSourceName)[keyof typeof DataSourceName];
/**
 * @public
 * @enum
 */
export declare const CapacityReservationType: {
    readonly CRG: "CRG";
    readonly ODCR: "ODCR";
};
/**
 * @public
 */
export type CapacityReservationType = (typeof CapacityReservationType)[keyof typeof CapacityReservationType];
/**
 * @public
 * @enum
 */
export declare const CapacityReservationPreference: {
    readonly CAPACITY_RESERVATIONS_ONLY: "capacity-reservations-only";
};
/**
 * @public
 */
export type CapacityReservationPreference = (typeof CapacityReservationPreference)[keyof typeof CapacityReservationPreference];
/**
 * @public
 * @enum
 */
export declare const NodeUnavailabilityType: {
    readonly CAPACITY_PERCENTAGE: "CAPACITY_PERCENTAGE";
    readonly INSTANCE_COUNT: "INSTANCE_COUNT";
};
/**
 * @public
 */
export type NodeUnavailabilityType = (typeof NodeUnavailabilityType)[keyof typeof NodeUnavailabilityType];
/**
 * @public
 * @enum
 */
export declare const CaptureMode: {
    readonly INPUT: "Input";
    readonly INPUT_AND_OUTPUT: "InputAndOutput";
    readonly OUTPUT: "Output";
};
/**
 * @public
 */
export type CaptureMode = (typeof CaptureMode)[keyof typeof CaptureMode];
/**
 * @public
 * @enum
 */
export declare const CaptureStatus: {
    readonly STARTED: "Started";
    readonly STOPPED: "Stopped";
};
/**
 * @public
 */
export type CaptureStatus = (typeof CaptureStatus)[keyof typeof CaptureStatus];
/**
 * @public
 * @enum
 */
export declare const ClarifyFeatureType: {
    readonly CATEGORICAL: "categorical";
    readonly NUMERICAL: "numerical";
    readonly TEXT: "text";
};
/**
 * @public
 */
export type ClarifyFeatureType = (typeof ClarifyFeatureType)[keyof typeof ClarifyFeatureType];
/**
 * @public
 * @enum
 */
export declare const ClarifyTextGranularity: {
    readonly PARAGRAPH: "paragraph";
    readonly SENTENCE: "sentence";
    readonly TOKEN: "token";
};
/**
 * @public
 */
export type ClarifyTextGranularity = (typeof ClarifyTextGranularity)[keyof typeof ClarifyTextGranularity];
/**
 * @public
 * @enum
 */
export declare const ClarifyTextLanguage: {
    readonly AFRIKAANS: "af";
    readonly ALBANIAN: "sq";
    readonly ARABIC: "ar";
    readonly ARMENIAN: "hy";
    readonly BASQUE: "eu";
    readonly BENGALI: "bn";
    readonly BULGARIAN: "bg";
    readonly CATALAN: "ca";
    readonly CHINESE: "zh";
    readonly CROATIAN: "hr";
    readonly CZECH: "cs";
    readonly DANISH: "da";
    readonly DUTCH: "nl";
    readonly ENGLISH: "en";
    readonly ESTONIAN: "et";
    readonly FINNISH: "fi";
    readonly FRENCH: "fr";
    readonly GERMAN: "de";
    readonly GREEK: "el";
    readonly GUJARATI: "gu";
    readonly HEBREW: "he";
    readonly HINDI: "hi";
    readonly HUNGARIAN: "hu";
    readonly ICELANDIC: "is";
    readonly INDONESIAN: "id";
    readonly IRISH: "ga";
    readonly ITALIAN: "it";
    readonly KANNADA: "kn";
    readonly KYRGYZ: "ky";
    readonly LATVIAN: "lv";
    readonly LIGURIAN: "lij";
    readonly LITHUANIAN: "lt";
    readonly LUXEMBOURGISH: "lb";
    readonly MACEDONIAN: "mk";
    readonly MALAYALAM: "ml";
    readonly MARATHI: "mr";
    readonly MULTI_LANGUAGE: "xx";
    readonly NEPALI: "ne";
    readonly NORWEGIAN_BOKMAL: "nb";
    readonly PERSIAN: "fa";
    readonly POLISH: "pl";
    readonly PORTUGUESE: "pt";
    readonly ROMANIAN: "ro";
    readonly RUSSIAN: "ru";
    readonly SANSKRIT: "sa";
    readonly SERBIAN: "sr";
    readonly SETSWANA: "tn";
    readonly SINHALA: "si";
    readonly SLOVAK: "sk";
    readonly SLOVENIAN: "sl";
    readonly SPANISH: "es";
    readonly SWEDISH: "sv";
    readonly TAGALOG: "tl";
    readonly TAMIL: "ta";
    readonly TATAR: "tt";
    readonly TELUGU: "te";
    readonly TURKISH: "tr";
    readonly UKRAINIAN: "uk";
    readonly URDU: "ur";
    readonly YORUBA: "yo";
};
/**
 * @public
 */
export type ClarifyTextLanguage = (typeof ClarifyTextLanguage)[keyof typeof ClarifyTextLanguage];
/**
 * @public
 * @enum
 */
export declare const ClusterAutoScalerType: {
    readonly KARPENTER: "Karpenter";
};
/**
 * @public
 */
export type ClusterAutoScalerType = (typeof ClusterAutoScalerType)[keyof typeof ClusterAutoScalerType];
/**
 * @public
 * @enum
 */
export declare const ClusterAutoScalingMode: {
    readonly DISABLE: "Disable";
    readonly ENABLE: "Enable";
};
/**
 * @public
 */
export type ClusterAutoScalingMode = (typeof ClusterAutoScalingMode)[keyof typeof ClusterAutoScalingMode];
/**
 * @public
 * @enum
 */
export declare const ClusterAutoScalingStatus: {
    readonly CREATING: "Creating";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly INSERVICE: "InService";
};
/**
 * @public
 */
export type ClusterAutoScalingStatus = (typeof ClusterAutoScalingStatus)[keyof typeof ClusterAutoScalingStatus];
/**
 * @public
 * @enum
 */
export declare const ClusterCapacityType: {
    readonly ON_DEMAND: "OnDemand";
    readonly SPOT: "Spot";
};
/**
 * @public
 */
export type ClusterCapacityType = (typeof ClusterCapacityType)[keyof typeof ClusterCapacityType];
/**
 * @public
 * @enum
 */
export declare const ClusterConfigMode: {
    readonly DISABLE: "Disable";
    readonly ENABLE: "Enable";
};
/**
 * @public
 */
export type ClusterConfigMode = (typeof ClusterConfigMode)[keyof typeof ClusterConfigMode];
/**
 * @public
 * @enum
 */
export declare const ClusterEventResourceType: {
    readonly CLUSTER: "Cluster";
    readonly INSTANCE: "Instance";
    readonly INSTANCE_GROUP: "InstanceGroup";
};
/**
 * @public
 */
export type ClusterEventResourceType = (typeof ClusterEventResourceType)[keyof typeof ClusterEventResourceType];
/**
 * @public
 * @enum
 */
export declare const ClusterKubernetesTaintEffect: {
    readonly NO_EXECUTE: "NoExecute";
    readonly NO_SCHEDULE: "NoSchedule";
    readonly PREFER_NO_SCHEDULE: "PreferNoSchedule";
};
/**
 * @public
 */
export type ClusterKubernetesTaintEffect = (typeof ClusterKubernetesTaintEffect)[keyof typeof ClusterKubernetesTaintEffect];
/**
 * @public
 * @enum
 */
export declare const DeepHealthCheckType: {
    readonly INSTANCE_CONNECTIVITY: "InstanceConnectivity";
    readonly INSTANCE_STRESS: "InstanceStress";
};
/**
 * @public
 */
export type DeepHealthCheckType = (typeof DeepHealthCheckType)[keyof typeof DeepHealthCheckType];
/**
 * @public
 * @enum
 */
export declare const ClusterSlurmNodeType: {
    readonly COMPUTE: "Compute";
    readonly CONTROLLER: "Controller";
    readonly LOGIN: "Login";
};
/**
 * @public
 */
export type ClusterSlurmNodeType = (typeof ClusterSlurmNodeType)[keyof typeof ClusterSlurmNodeType];
/**
 * @public
 * @enum
 */
export declare const SoftwareUpdateStatus: {
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly PENDING: "Pending";
    readonly ROLLBACK_COMPLETE: "RollbackComplete";
    readonly ROLLBACK_IN_PROGRESS: "RollbackInProgress";
    readonly SUCCEEDED: "Succeeded";
};
/**
 * @public
 */
export type SoftwareUpdateStatus = (typeof SoftwareUpdateStatus)[keyof typeof SoftwareUpdateStatus];
/**
 * @public
 * @enum
 */
export declare const InstanceGroupStatus: {
    readonly CREATING: "Creating";
    readonly DEGRADED: "Degraded";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly INSERVICE: "InService";
    readonly SYSTEMUPDATING: "SystemUpdating";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type InstanceGroupStatus = (typeof InstanceGroupStatus)[keyof typeof InstanceGroupStatus];
/**
 * @public
 * @enum
 */
export declare const ClusterNodeProvisioningMode: {
    readonly CONTINUOUS: "Continuous";
};
/**
 * @public
 */
export type ClusterNodeProvisioningMode = (typeof ClusterNodeProvisioningMode)[keyof typeof ClusterNodeProvisioningMode];
/**
 * @public
 * @enum
 */
export declare const ClusterNodeRecovery: {
    readonly AUTOMATIC: "Automatic";
    readonly NONE: "None";
};
/**
 * @public
 */
export type ClusterNodeRecovery = (typeof ClusterNodeRecovery)[keyof typeof ClusterNodeRecovery];
/**
 * @public
 * @enum
 */
export declare const ClusterSlurmConfigStrategy: {
    readonly MANAGED: "Managed";
    readonly MERGE: "Merge";
    readonly OVERWRITE: "Overwrite";
};
/**
 * @public
 */
export type ClusterSlurmConfigStrategy = (typeof ClusterSlurmConfigStrategy)[keyof typeof ClusterSlurmConfigStrategy];
/**
 * @public
 * @enum
 */
export declare const SchedulerResourceStatus: {
    readonly CREATED: "Created";
    readonly CREATE_FAILED: "CreateFailed";
    readonly CREATE_ROLLBACK_FAILED: "CreateRollbackFailed";
    readonly CREATING: "Creating";
    readonly DELETED: "Deleted";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETE_ROLLBACK_FAILED: "DeleteRollbackFailed";
    readonly DELETING: "Deleting";
    readonly UPDATED: "Updated";
    readonly UPDATE_FAILED: "UpdateFailed";
    readonly UPDATE_ROLLBACK_FAILED: "UpdateRollbackFailed";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type SchedulerResourceStatus = (typeof SchedulerResourceStatus)[keyof typeof SchedulerResourceStatus];
/**
 * @public
 * @enum
 */
export declare const ClusterSortBy: {
    readonly CREATION_TIME: "CREATION_TIME";
    readonly NAME: "NAME";
};
/**
 * @public
 */
export type ClusterSortBy = (typeof ClusterSortBy)[keyof typeof ClusterSortBy];
/**
 * @public
 * @enum
 */
export declare const ClusterStatus: {
    readonly CREATING: "Creating";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly INSERVICE: "InService";
    readonly ROLLINGBACK: "RollingBack";
    readonly SYSTEMUPDATING: "SystemUpdating";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type ClusterStatus = (typeof ClusterStatus)[keyof typeof ClusterStatus];
/**
 * @public
 * @enum
 */
export declare const CodeRepositorySortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly LAST_MODIFIED_TIME: "LastModifiedTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type CodeRepositorySortBy = (typeof CodeRepositorySortBy)[keyof typeof CodeRepositorySortBy];
/**
 * @public
 * @enum
 */
export declare const CodeRepositorySortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type CodeRepositorySortOrder = (typeof CodeRepositorySortOrder)[keyof typeof CodeRepositorySortOrder];
/**
 * @public
 * @enum
 */
export declare const CollectionType: {
    readonly LIST: "List";
    readonly SET: "Set";
    readonly VECTOR: "Vector";
};
/**
 * @public
 */
export type CollectionType = (typeof CollectionType)[keyof typeof CollectionType];
/**
 * @public
 * @enum
 */
export declare const CompilationJobStatus: {
    readonly COMPLETED: "COMPLETED";
    readonly FAILED: "FAILED";
    readonly INPROGRESS: "INPROGRESS";
    readonly STARTING: "STARTING";
    readonly STOPPED: "STOPPED";
    readonly STOPPING: "STOPPING";
};
/**
 * @public
 */
export type CompilationJobStatus = (typeof CompilationJobStatus)[keyof typeof CompilationJobStatus];
/**
 * @public
 * @enum
 */
export declare const TargetDevice: {
    readonly AISAGE: "aisage";
    readonly AMBA_CV2: "amba_cv2";
    readonly AMBA_CV22: "amba_cv22";
    readonly AMBA_CV25: "amba_cv25";
    readonly COREML: "coreml";
    readonly DEEPLENS: "deeplens";
    readonly IMX8MPLUS: "imx8mplus";
    readonly IMX8QM: "imx8qm";
    readonly JACINTO_TDA4VM: "jacinto_tda4vm";
    readonly JETSON_NANO: "jetson_nano";
    readonly JETSON_TX1: "jetson_tx1";
    readonly JETSON_TX2: "jetson_tx2";
    readonly JETSON_XAVIER: "jetson_xavier";
    readonly LAMBDA: "lambda";
    readonly ML_C4: "ml_c4";
    readonly ML_C5: "ml_c5";
    readonly ML_C6G: "ml_c6g";
    readonly ML_EIA2: "ml_eia2";
    readonly ML_G4DN: "ml_g4dn";
    readonly ML_INF1: "ml_inf1";
    readonly ML_INF2: "ml_inf2";
    readonly ML_M4: "ml_m4";
    readonly ML_M5: "ml_m5";
    readonly ML_M6G: "ml_m6g";
    readonly ML_P2: "ml_p2";
    readonly ML_P3: "ml_p3";
    readonly ML_TRN1: "ml_trn1";
    readonly QCS603: "qcs603";
    readonly QCS605: "qcs605";
    readonly RASP3B: "rasp3b";
    readonly RASP4B: "rasp4b";
    readonly RK3288: "rk3288";
    readonly RK3399: "rk3399";
    readonly SBE_C: "sbe_c";
    readonly SITARA_AM57X: "sitara_am57x";
    readonly X86_WIN32: "x86_win32";
    readonly X86_WIN64: "x86_win64";
};
/**
 * @public
 */
export type TargetDevice = (typeof TargetDevice)[keyof typeof TargetDevice];
/**
 * @public
 * @enum
 */
export declare const TargetPlatformAccelerator: {
    readonly INTEL_GRAPHICS: "INTEL_GRAPHICS";
    readonly MALI: "MALI";
    readonly NNA: "NNA";
    readonly NVIDIA: "NVIDIA";
};
/**
 * @public
 */
export type TargetPlatformAccelerator = (typeof TargetPlatformAccelerator)[keyof typeof TargetPlatformAccelerator];
/**
 * @public
 * @enum
 */
export declare const TargetPlatformArch: {
    readonly ARM64: "ARM64";
    readonly ARM_EABI: "ARM_EABI";
    readonly ARM_EABIHF: "ARM_EABIHF";
    readonly X86: "X86";
    readonly X86_64: "X86_64";
};
/**
 * @public
 */
export type TargetPlatformArch = (typeof TargetPlatformArch)[keyof typeof TargetPlatformArch];
/**
 * @public
 * @enum
 */
export declare const TargetPlatformOs: {
    readonly ANDROID: "ANDROID";
    readonly LINUX: "LINUX";
};
/**
 * @public
 */
export type TargetPlatformOs = (typeof TargetPlatformOs)[keyof typeof TargetPlatformOs];
/**
 * @public
 * @enum
 */
export declare const CompleteOnConvergence: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type CompleteOnConvergence = (typeof CompleteOnConvergence)[keyof typeof CompleteOnConvergence];
/**
 * @public
 * @enum
 */
export declare const PreemptTeamTasks: {
    readonly LOWERPRIORITY: "LowerPriority";
    readonly NEVER: "Never";
};
/**
 * @public
 */
export type PreemptTeamTasks = (typeof PreemptTeamTasks)[keyof typeof PreemptTeamTasks];
/**
 * @public
 * @enum
 */
export declare const ResourceSharingStrategy: {
    readonly DONTLEND: "DontLend";
    readonly LEND: "Lend";
    readonly LENDANDBORROW: "LendAndBorrow";
};
/**
 * @public
 */
export type ResourceSharingStrategy = (typeof ResourceSharingStrategy)[keyof typeof ResourceSharingStrategy];
/**
 * @public
 * @enum
 */
export declare const ConditionOutcome: {
    readonly FALSE: "False";
    readonly TRUE: "True";
};
/**
 * @public
 */
export type ConditionOutcome = (typeof ConditionOutcome)[keyof typeof ConditionOutcome];
/**
 * @public
 * @enum
 */
export declare const RepositoryAccessMode: {
    readonly PLATFORM: "Platform";
    readonly VPC: "Vpc";
};
/**
 * @public
 */
export type RepositoryAccessMode = (typeof RepositoryAccessMode)[keyof typeof RepositoryAccessMode];
/**
 * @public
 * @enum
 */
export declare const ContainerMode: {
    readonly MULTI_MODEL: "MultiModel";
    readonly SINGLE_MODEL: "SingleModel";
};
/**
 * @public
 */
export type ContainerMode = (typeof ContainerMode)[keyof typeof ContainerMode];
/**
 * @public
 * @enum
 */
export declare const ModelCacheSetting: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type ModelCacheSetting = (typeof ModelCacheSetting)[keyof typeof ModelCacheSetting];
/**
 * @public
 * @enum
 */
export declare const ContentClassifier: {
    readonly FREE_OF_ADULT_CONTENT: "FreeOfAdultContent";
    readonly FREE_OF_PERSONALLY_IDENTIFIABLE_INFORMATION: "FreeOfPersonallyIdentifiableInformation";
};
/**
 * @public
 */
export type ContentClassifier = (typeof ContentClassifier)[keyof typeof ContentClassifier];
/**
 * @public
 * @enum
 */
export declare const HyperParameterScalingType: {
    readonly AUTO: "Auto";
    readonly LINEAR: "Linear";
    readonly LOGARITHMIC: "Logarithmic";
    readonly REVERSE_LOGARITHMIC: "ReverseLogarithmic";
};
/**
 * @public
 */
export type HyperParameterScalingType = (typeof HyperParameterScalingType)[keyof typeof HyperParameterScalingType];
/**
 * @public
 * @enum
 */
export declare const ParameterType: {
    readonly CATEGORICAL: "Categorical";
    readonly CONTINUOUS: "Continuous";
    readonly FREE_TEXT: "FreeText";
    readonly INTEGER: "Integer";
};
/**
 * @public
 */
export type ParameterType = (typeof ParameterType)[keyof typeof ParameterType];
/**
 * @public
 * @enum
 */
export declare const HyperParameterTuningJobObjectiveType: {
    readonly MAXIMIZE: "Maximize";
    readonly MINIMIZE: "Minimize";
};
/**
 * @public
 */
export type HyperParameterTuningJobObjectiveType = (typeof HyperParameterTuningJobObjectiveType)[keyof typeof HyperParameterTuningJobObjectiveType];
/**
 * @public
 * @enum
 */
export declare const FairShare: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type FairShare = (typeof FairShare)[keyof typeof FairShare];
/**
 * @public
 * @enum
 */
export declare const IdleResourceSharing: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type IdleResourceSharing = (typeof IdleResourceSharing)[keyof typeof IdleResourceSharing];
/**
 * @public
 * @enum
 */
export declare const Framework: {
    readonly DARKNET: "DARKNET";
    readonly KERAS: "KERAS";
    readonly MXNET: "MXNET";
    readonly ONNX: "ONNX";
    readonly PYTORCH: "PYTORCH";
    readonly SKLEARN: "SKLEARN";
    readonly TENSORFLOW: "TENSORFLOW";
    readonly TFLITE: "TFLITE";
    readonly XGBOOST: "XGBOOST";
};
/**
 * @public
 */
export type Framework = (typeof Framework)[keyof typeof Framework];
/**
 * @public
 * @enum
 */
export declare const ProcessingS3UploadMode: {
    readonly CONTINUOUS: "Continuous";
    readonly END_OF_JOB: "EndOfJob";
};
/**
 * @public
 */
export type ProcessingS3UploadMode = (typeof ProcessingS3UploadMode)[keyof typeof ProcessingS3UploadMode];
/**
 * @public
 * @enum
 */
export declare const ProcessingInstanceType: {
    readonly ML_C4_2XLARGE: "ml.c4.2xlarge";
    readonly ML_C4_4XLARGE: "ml.c4.4xlarge";
    readonly ML_C4_8XLARGE: "ml.c4.8xlarge";
    readonly ML_C4_XLARGE: "ml.c4.xlarge";
    readonly ML_C5_18XLARGE: "ml.c5.18xlarge";
    readonly ML_C5_2XLARGE: "ml.c5.2xlarge";
    readonly ML_C5_4XLARGE: "ml.c5.4xlarge";
    readonly ML_C5_9XLARGE: "ml.c5.9xlarge";
    readonly ML_C5_XLARGE: "ml.c5.xlarge";
    readonly ML_C6I_12XLARGE: "ml.c6i.12xlarge";
    readonly ML_C6I_16XLARGE: "ml.c6i.16xlarge";
    readonly ML_C6I_24XLARGE: "ml.c6i.24xlarge";
    readonly ML_C6I_2XLARGE: "ml.c6i.2xlarge";
    readonly ML_C6I_32XLARGE: "ml.c6i.32xlarge";
    readonly ML_C6I_4XLARGE: "ml.c6i.4xlarge";
    readonly ML_C6I_8XLARGE: "ml.c6i.8xlarge";
    readonly ML_C6I_XLARGE: "ml.c6i.xlarge";
    readonly ML_C7I_12XLARGE: "ml.c7i.12xlarge";
    readonly ML_C7I_16XLARGE: "ml.c7i.16xlarge";
    readonly ML_C7I_24XLARGE: "ml.c7i.24xlarge";
    readonly ML_C7I_2XLARGE: "ml.c7i.2xlarge";
    readonly ML_C7I_48XLARGE: "ml.c7i.48xlarge";
    readonly ML_C7I_4XLARGE: "ml.c7i.4xlarge";
    readonly ML_C7I_8XLARGE: "ml.c7i.8xlarge";
    readonly ML_C7I_LARGE: "ml.c7i.large";
    readonly ML_C7I_XLARGE: "ml.c7i.xlarge";
    readonly ML_G4DN_12XLARGE: "ml.g4dn.12xlarge";
    readonly ML_G4DN_16XLARGE: "ml.g4dn.16xlarge";
    readonly ML_G4DN_2XLARGE: "ml.g4dn.2xlarge";
    readonly ML_G4DN_4XLARGE: "ml.g4dn.4xlarge";
    readonly ML_G4DN_8XLARGE: "ml.g4dn.8xlarge";
    readonly ML_G4DN_XLARGE: "ml.g4dn.xlarge";
    readonly ML_G5_12XLARGE: "ml.g5.12xlarge";
    readonly ML_G5_16XLARGE: "ml.g5.16xlarge";
    readonly ML_G5_24XLARGE: "ml.g5.24xlarge";
    readonly ML_G5_2XLARGE: "ml.g5.2xlarge";
    readonly ML_G5_48XLARGE: "ml.g5.48xlarge";
    readonly ML_G5_4XLARGE: "ml.g5.4xlarge";
    readonly ML_G5_8XLARGE: "ml.g5.8xlarge";
    readonly ML_G5_XLARGE: "ml.g5.xlarge";
    readonly ML_G6E_12XLARGE: "ml.g6e.12xlarge";
    readonly ML_G6E_16XLARGE: "ml.g6e.16xlarge";
    readonly ML_G6E_24XLARGE: "ml.g6e.24xlarge";
    readonly ML_G6E_2XLARGE: "ml.g6e.2xlarge";
    readonly ML_G6E_48XLARGE: "ml.g6e.48xlarge";
    readonly ML_G6E_4XLARGE: "ml.g6e.4xlarge";
    readonly ML_G6E_8XLARGE: "ml.g6e.8xlarge";
    readonly ML_G6E_XLARGE: "ml.g6e.xlarge";
    readonly ML_G6_12XLARGE: "ml.g6.12xlarge";
    readonly ML_G6_16XLARGE: "ml.g6.16xlarge";
    readonly ML_G6_24XLARGE: "ml.g6.24xlarge";
    readonly ML_G6_2XLARGE: "ml.g6.2xlarge";
    readonly ML_G6_48XLARGE: "ml.g6.48xlarge";
    readonly ML_G6_4XLARGE: "ml.g6.4xlarge";
    readonly ML_G6_8XLARGE: "ml.g6.8xlarge";
    readonly ML_G6_XLARGE: "ml.g6.xlarge";
    readonly ML_G7E_12XLARGE: "ml.g7e.12xlarge";
    readonly ML_G7E_24XLARGE: "ml.g7e.24xlarge";
    readonly ML_G7E_2XLARGE: "ml.g7e.2xlarge";
    readonly ML_G7E_48XLARGE: "ml.g7e.48xlarge";
    readonly ML_G7E_4XLARGE: "ml.g7e.4xlarge";
    readonly ML_G7E_8XLARGE: "ml.g7e.8xlarge";
    readonly ML_M4_10XLARGE: "ml.m4.10xlarge";
    readonly ML_M4_16XLARGE: "ml.m4.16xlarge";
    readonly ML_M4_2XLARGE: "ml.m4.2xlarge";
    readonly ML_M4_4XLARGE: "ml.m4.4xlarge";
    readonly ML_M4_XLARGE: "ml.m4.xlarge";
    readonly ML_M5_12XLARGE: "ml.m5.12xlarge";
    readonly ML_M5_24XLARGE: "ml.m5.24xlarge";
    readonly ML_M5_2XLARGE: "ml.m5.2xlarge";
    readonly ML_M5_4XLARGE: "ml.m5.4xlarge";
    readonly ML_M5_LARGE: "ml.m5.large";
    readonly ML_M5_XLARGE: "ml.m5.xlarge";
    readonly ML_M6I_12XLARGE: "ml.m6i.12xlarge";
    readonly ML_M6I_16XLARGE: "ml.m6i.16xlarge";
    readonly ML_M6I_24XLARGE: "ml.m6i.24xlarge";
    readonly ML_M6I_2XLARGE: "ml.m6i.2xlarge";
    readonly ML_M6I_32XLARGE: "ml.m6i.32xlarge";
    readonly ML_M6I_4XLARGE: "ml.m6i.4xlarge";
    readonly ML_M6I_8XLARGE: "ml.m6i.8xlarge";
    readonly ML_M6I_LARGE: "ml.m6i.large";
    readonly ML_M6I_XLARGE: "ml.m6i.xlarge";
    readonly ML_M7I_12XLARGE: "ml.m7i.12xlarge";
    readonly ML_M7I_16XLARGE: "ml.m7i.16xlarge";
    readonly ML_M7I_24XLARGE: "ml.m7i.24xlarge";
    readonly ML_M7I_2XLARGE: "ml.m7i.2xlarge";
    readonly ML_M7I_48XLARGE: "ml.m7i.48xlarge";
    readonly ML_M7I_4XLARGE: "ml.m7i.4xlarge";
    readonly ML_M7I_8XLARGE: "ml.m7i.8xlarge";
    readonly ML_M7I_LARGE: "ml.m7i.large";
    readonly ML_M7I_XLARGE: "ml.m7i.xlarge";
    readonly ML_P2_16XLARGE: "ml.p2.16xlarge";
    readonly ML_P2_8XLARGE: "ml.p2.8xlarge";
    readonly ML_P2_XLARGE: "ml.p2.xlarge";
    readonly ML_P3_16XLARGE: "ml.p3.16xlarge";
    readonly ML_P3_2XLARGE: "ml.p3.2xlarge";
    readonly ML_P3_8XLARGE: "ml.p3.8xlarge";
    readonly ML_P5_4XLARGE: "ml.p5.4xlarge";
    readonly ML_R5D_12XLARGE: "ml.r5d.12xlarge";
    readonly ML_R5D_16XLARGE: "ml.r5d.16xlarge";
    readonly ML_R5D_24XLARGE: "ml.r5d.24xlarge";
    readonly ML_R5D_2XLARGE: "ml.r5d.2xlarge";
    readonly ML_R5D_4XLARGE: "ml.r5d.4xlarge";
    readonly ML_R5D_8XLARGE: "ml.r5d.8xlarge";
    readonly ML_R5D_LARGE: "ml.r5d.large";
    readonly ML_R5D_XLARGE: "ml.r5d.xlarge";
    readonly ML_R5_12XLARGE: "ml.r5.12xlarge";
    readonly ML_R5_16XLARGE: "ml.r5.16xlarge";
    readonly ML_R5_24XLARGE: "ml.r5.24xlarge";
    readonly ML_R5_2XLARGE: "ml.r5.2xlarge";
    readonly ML_R5_4XLARGE: "ml.r5.4xlarge";
    readonly ML_R5_8XLARGE: "ml.r5.8xlarge";
    readonly ML_R5_LARGE: "ml.r5.large";
    readonly ML_R5_XLARGE: "ml.r5.xlarge";
    readonly ML_R7I_12XLARGE: "ml.r7i.12xlarge";
    readonly ML_R7I_16XLARGE: "ml.r7i.16xlarge";
    readonly ML_R7I_24XLARGE: "ml.r7i.24xlarge";
    readonly ML_R7I_2XLARGE: "ml.r7i.2xlarge";
    readonly ML_R7I_48XLARGE: "ml.r7i.48xlarge";
    readonly ML_R7I_4XLARGE: "ml.r7i.4xlarge";
    readonly ML_R7I_8XLARGE: "ml.r7i.8xlarge";
    readonly ML_R7I_LARGE: "ml.r7i.large";
    readonly ML_R7I_XLARGE: "ml.r7i.xlarge";
    readonly ML_T3_2XLARGE: "ml.t3.2xlarge";
    readonly ML_T3_LARGE: "ml.t3.large";
    readonly ML_T3_MEDIUM: "ml.t3.medium";
    readonly ML_T3_XLARGE: "ml.t3.xlarge";
};
/**
 * @public
 */
export type ProcessingInstanceType = (typeof ProcessingInstanceType)[keyof typeof ProcessingInstanceType];
/**
 * @public
 * @enum
 */
export declare const EdgePresetDeploymentType: {
    readonly GreengrassV2Component: "GreengrassV2Component";
};
/**
 * @public
 */
export type EdgePresetDeploymentType = (typeof EdgePresetDeploymentType)[keyof typeof EdgePresetDeploymentType];
/**
 * @public
 * @enum
 */
export declare const RStudioServerProAccessStatus: {
    readonly Disabled: "DISABLED";
    readonly Enabled: "ENABLED";
};
/**
 * @public
 */
export type RStudioServerProAccessStatus = (typeof RStudioServerProAccessStatus)[keyof typeof RStudioServerProAccessStatus];
/**
 * @public
 * @enum
 */
export declare const RStudioServerProUserGroup: {
    readonly Admin: "R_STUDIO_ADMIN";
    readonly User: "R_STUDIO_USER";
};
/**
 * @public
 */
export type RStudioServerProUserGroup = (typeof RStudioServerProUserGroup)[keyof typeof RStudioServerProUserGroup];
/**
 * @public
 * @enum
 */
export declare const NotebookOutputOption: {
    readonly Allowed: "Allowed";
    readonly Disabled: "Disabled";
};
/**
 * @public
 */
export type NotebookOutputOption = (typeof NotebookOutputOption)[keyof typeof NotebookOutputOption];
/**
 * @public
 * @enum
 */
export declare const StudioWebPortal: {
    readonly Disabled: "DISABLED";
    readonly Enabled: "ENABLED";
};
/**
 * @public
 */
export type StudioWebPortal = (typeof StudioWebPortal)[keyof typeof StudioWebPortal];
/**
 * @public
 * @enum
 */
export declare const MlTools: {
    readonly AUTO_ML: "AutoMl";
    readonly COMET: "Comet";
    readonly DATASETS: "Datasets";
    readonly DATA_WRANGLER: "DataWrangler";
    readonly DEEPCHECKS_LLM_EVALUATION: "DeepchecksLLMEvaluation";
    readonly EMR_CLUSTERS: "EmrClusters";
    readonly ENDPOINTS: "Endpoints";
    readonly EVALUATORS: "Evaluators";
    readonly EXPERIMENTS: "Experiments";
    readonly FEATURE_STORE: "FeatureStore";
    readonly FIDDLER: "Fiddler";
    readonly HYPER_POD_CLUSTERS: "HyperPodClusters";
    readonly INFERENCE_OPTIMIZATION: "InferenceOptimization";
    readonly INFERENCE_RECOMMENDER: "InferenceRecommender";
    readonly JUMP_START: "JumpStart";
    readonly LAKERA_GUARD: "LakeraGuard";
    readonly MODELS: "Models";
    readonly MODEL_EVALUATION: "ModelEvaluation";
    readonly PERFORMANCE_EVALUATION: "PerformanceEvaluation";
    readonly PIPELINES: "Pipelines";
    readonly PROJECTS: "Projects";
    readonly RUNNING_INSTANCES: "RunningInstances";
    readonly TRAINING: "Training";
};
/**
 * @public
 */
export type MlTools = (typeof MlTools)[keyof typeof MlTools];
/**
 * @public
 * @enum
 */
export declare const SageMakerImageName: {
    readonly sagemaker_distribution: "sagemaker_distribution";
};
/**
 * @public
 */
export type SageMakerImageName = (typeof SageMakerImageName)[keyof typeof SageMakerImageName];
/**
 * @public
 * @enum
 */
export declare const ExecutionRoleIdentityConfig: {
    readonly DISABLED: "DISABLED";
    readonly USER_PROFILE_NAME: "USER_PROFILE_NAME";
};
/**
 * @public
 */
export type ExecutionRoleIdentityConfig = (typeof ExecutionRoleIdentityConfig)[keyof typeof ExecutionRoleIdentityConfig];
/**
 * @public
 * @enum
 */
export declare const IPAddressType: {
    readonly DUALSTACK: "dualstack";
    readonly IPV4: "ipv4";
};
/**
 * @public
 */
export type IPAddressType = (typeof IPAddressType)[keyof typeof IPAddressType];
/**
 * @public
 * @enum
 */
export declare const TagPropagation: {
    readonly DISABLED: "DISABLED";
    readonly ENABLED: "ENABLED";
};
/**
 * @public
 */
export type TagPropagation = (typeof TagPropagation)[keyof typeof TagPropagation];
/**
 * @public
 * @enum
 */
export declare const FailureHandlingPolicy: {
    readonly DoNothing: "DO_NOTHING";
    readonly RollbackOnFailure: "ROLLBACK_ON_FAILURE";
};
/**
 * @public
 */
export type FailureHandlingPolicy = (typeof FailureHandlingPolicy)[keyof typeof FailureHandlingPolicy];
/**
 * @public
 * @enum
 */
export declare const DeviceSubsetType: {
    readonly NameContains: "NAMECONTAINS";
    readonly Percentage: "PERCENTAGE";
    readonly Selection: "SELECTION";
};
/**
 * @public
 */
export type DeviceSubsetType = (typeof DeviceSubsetType)[keyof typeof DeviceSubsetType];
export declare enum MetricPublishFrequencyInSeconds {
    FREQ_10_S = 10,
    FREQ_30_S = 30,
    FREQ_60_S = 60,
    FREQ_120_S = 120,
    FREQ_180_S = 180,
    FREQ_240_S = 240,
    FREQ_300_S = 300
}
/**
 * @public
 * @enum
 */
export declare const ProductionVariantAcceleratorType: {
    readonly ML_EIA1_LARGE: "ml.eia1.large";
    readonly ML_EIA1_MEDIUM: "ml.eia1.medium";
    readonly ML_EIA1_XLARGE: "ml.eia1.xlarge";
    readonly ML_EIA2_LARGE: "ml.eia2.large";
    readonly ML_EIA2_MEDIUM: "ml.eia2.medium";
    readonly ML_EIA2_XLARGE: "ml.eia2.xlarge";
};
/**
 * @public
 */
export type ProductionVariantAcceleratorType = (typeof ProductionVariantAcceleratorType)[keyof typeof ProductionVariantAcceleratorType];
/**
 * @public
 * @enum
 */
export declare const ProductionVariantInferenceAmiVersion: {
    readonly AL2_GPU_2: "al2-ami-sagemaker-inference-gpu-2";
    readonly AL2_GPU_2_1: "al2-ami-sagemaker-inference-gpu-2-1";
    readonly AL2_GPU_3_1: "al2-ami-sagemaker-inference-gpu-3-1";
    readonly AL2_NEURON_2: "al2-ami-sagemaker-inference-neuron-2";
};
/**
 * @public
 */
export type ProductionVariantInferenceAmiVersion = (typeof ProductionVariantInferenceAmiVersion)[keyof typeof ProductionVariantInferenceAmiVersion];
/**
 * @public
 * @enum
 */
export declare const ManagedInstanceScalingStatus: {
    readonly DISABLED: "DISABLED";
    readonly ENABLED: "ENABLED";
};
/**
 * @public
 */
export type ManagedInstanceScalingStatus = (typeof ManagedInstanceScalingStatus)[keyof typeof ManagedInstanceScalingStatus];
/**
 * @public
 * @enum
 */
export declare const RoutingStrategy: {
    readonly LEAST_OUTSTANDING_REQUESTS: "LEAST_OUTSTANDING_REQUESTS";
    readonly RANDOM: "RANDOM";
};
/**
 * @public
 */
export type RoutingStrategy = (typeof RoutingStrategy)[keyof typeof RoutingStrategy];
/**
 * @public
 * @enum
 */
export declare const FeatureType: {
    readonly FRACTIONAL: "Fractional";
    readonly INTEGRAL: "Integral";
    readonly STRING: "String";
};
/**
 * @public
 */
export type FeatureType = (typeof FeatureType)[keyof typeof FeatureType];
/**
 * @public
 * @enum
 */
export declare const TableFormat: {
    readonly DEFAULT: "Default";
    readonly GLUE: "Glue";
    readonly ICEBERG: "Iceberg";
};
/**
 * @public
 */
export type TableFormat = (typeof TableFormat)[keyof typeof TableFormat];
/**
 * @public
 * @enum
 */
export declare const StorageType: {
    readonly IN_MEMORY: "InMemory";
    readonly STANDARD: "Standard";
};
/**
 * @public
 */
export type StorageType = (typeof StorageType)[keyof typeof StorageType];
/**
 * @public
 * @enum
 */
export declare const TtlDurationUnit: {
    readonly DAYS: "Days";
    readonly HOURS: "Hours";
    readonly MINUTES: "Minutes";
    readonly SECONDS: "Seconds";
    readonly WEEKS: "Weeks";
};
/**
 * @public
 */
export type TtlDurationUnit = (typeof TtlDurationUnit)[keyof typeof TtlDurationUnit];
/**
 * @public
 * @enum
 */
export declare const ThroughputMode: {
    readonly ON_DEMAND: "OnDemand";
    readonly PROVISIONED: "Provisioned";
};
/**
 * @public
 */
export type ThroughputMode = (typeof ThroughputMode)[keyof typeof ThroughputMode];
/**
 * @public
 * @enum
 */
export declare const HubContentType: {
    readonly DATA_SET: "DataSet";
    readonly JSON_DOC: "JsonDoc";
    readonly MODEL: "Model";
    readonly MODEL_REFERENCE: "ModelReference";
    readonly NOTEBOOK: "Notebook";
};
/**
 * @public
 */
export type HubContentType = (typeof HubContentType)[keyof typeof HubContentType];
/**
 * @public
 * @enum
 */
export declare const HyperParameterTuningJobStrategyType: {
    readonly BAYESIAN: "Bayesian";
    readonly GRID: "Grid";
    readonly HYPERBAND: "Hyperband";
    readonly RANDOM: "Random";
};
/**
 * @public
 */
export type HyperParameterTuningJobStrategyType = (typeof HyperParameterTuningJobStrategyType)[keyof typeof HyperParameterTuningJobStrategyType];
/**
 * @public
 * @enum
 */
export declare const TrainingJobEarlyStoppingType: {
    readonly AUTO: "Auto";
    readonly OFF: "Off";
};
/**
 * @public
 */
export type TrainingJobEarlyStoppingType = (typeof TrainingJobEarlyStoppingType)[keyof typeof TrainingJobEarlyStoppingType];
/**
 * @public
 * @enum
 */
export declare const HyperParameterTuningAllocationStrategy: {
    readonly PRIORITIZED: "Prioritized";
};
/**
 * @public
 */
export type HyperParameterTuningAllocationStrategy = (typeof HyperParameterTuningAllocationStrategy)[keyof typeof HyperParameterTuningAllocationStrategy];
/**
 * @public
 * @enum
 */
export declare const HyperParameterTuningJobWarmStartType: {
    readonly IDENTICAL_DATA_AND_ALGORITHM: "IdenticalDataAndAlgorithm";
    readonly TRANSFER_LEARNING: "TransferLearning";
};
/**
 * @public
 */
export type HyperParameterTuningJobWarmStartType = (typeof HyperParameterTuningJobWarmStartType)[keyof typeof HyperParameterTuningJobWarmStartType];
/**
 * @public
 * @enum
 */
export declare const JobType: {
    readonly INFERENCE: "INFERENCE";
    readonly NOTEBOOK_KERNEL: "NOTEBOOK_KERNEL";
    readonly TRAINING: "TRAINING";
};
/**
 * @public
 */
export type JobType = (typeof JobType)[keyof typeof JobType];
/**
 * @public
 * @enum
 */
export declare const Processor: {
    readonly CPU: "CPU";
    readonly GPU: "GPU";
};
/**
 * @public
 */
export type Processor = (typeof Processor)[keyof typeof Processor];
/**
 * @public
 * @enum
 */
export declare const VendorGuidance: {
    readonly ARCHIVED: "ARCHIVED";
    readonly NOT_PROVIDED: "NOT_PROVIDED";
    readonly STABLE: "STABLE";
    readonly TO_BE_ARCHIVED: "TO_BE_ARCHIVED";
};
/**
 * @public
 */
export type VendorGuidance = (typeof VendorGuidance)[keyof typeof VendorGuidance];
/**
 * @public
 * @enum
 */
export declare const ModelInfrastructureType: {
    readonly REAL_TIME_INFERENCE: "RealTimeInference";
};
/**
 * @public
 */
export type ModelInfrastructureType = (typeof ModelInfrastructureType)[keyof typeof ModelInfrastructureType];
/**
 * @public
 * @enum
 */
export declare const _InstanceType: {
    readonly ML_C4_2XLARGE: "ml.c4.2xlarge";
    readonly ML_C4_4XLARGE: "ml.c4.4xlarge";
    readonly ML_C4_8XLARGE: "ml.c4.8xlarge";
    readonly ML_C4_XLARGE: "ml.c4.xlarge";
    readonly ML_C5D_18XLARGE: "ml.c5d.18xlarge";
    readonly ML_C5D_2XLARGE: "ml.c5d.2xlarge";
    readonly ML_C5D_4XLARGE: "ml.c5d.4xlarge";
    readonly ML_C5D_9XLARGE: "ml.c5d.9xlarge";
    readonly ML_C5D_XLARGE: "ml.c5d.xlarge";
    readonly ML_C5_18XLARGE: "ml.c5.18xlarge";
    readonly ML_C5_2XLARGE: "ml.c5.2xlarge";
    readonly ML_C5_4XLARGE: "ml.c5.4xlarge";
    readonly ML_C5_9XLARGE: "ml.c5.9xlarge";
    readonly ML_C5_XLARGE: "ml.c5.xlarge";
    readonly ML_C6ID_12XLARGE: "ml.c6id.12xlarge";
    readonly ML_C6ID_16XLARGE: "ml.c6id.16xlarge";
    readonly ML_C6ID_24XLARGE: "ml.c6id.24xlarge";
    readonly ML_C6ID_2XLARGE: "ml.c6id.2xlarge";
    readonly ML_C6ID_32XLARGE: "ml.c6id.32xlarge";
    readonly ML_C6ID_4XLARGE: "ml.c6id.4xlarge";
    readonly ML_C6ID_8XLARGE: "ml.c6id.8xlarge";
    readonly ML_C6ID_LARGE: "ml.c6id.large";
    readonly ML_C6ID_XLARGE: "ml.c6id.xlarge";
    readonly ML_C6I_12XLARGE: "ml.c6i.12xlarge";
    readonly ML_C6I_16XLARGE: "ml.c6i.16xlarge";
    readonly ML_C6I_24XLARGE: "ml.c6i.24xlarge";
    readonly ML_C6I_2XLARGE: "ml.c6i.2xlarge";
    readonly ML_C6I_32XLARGE: "ml.c6i.32xlarge";
    readonly ML_C6I_4XLARGE: "ml.c6i.4xlarge";
    readonly ML_C6I_8XLARGE: "ml.c6i.8xlarge";
    readonly ML_C6I_LARGE: "ml.c6i.large";
    readonly ML_C6I_XLARGE: "ml.c6i.xlarge";
    readonly ML_C7I_12XLARGE: "ml.c7i.12xlarge";
    readonly ML_C7I_16XLARGE: "ml.c7i.16xlarge";
    readonly ML_C7I_24XLARGE: "ml.c7i.24xlarge";
    readonly ML_C7I_2XLARGE: "ml.c7i.2xlarge";
    readonly ML_C7I_48XLARGE: "ml.c7i.48xlarge";
    readonly ML_C7I_4XLARGE: "ml.c7i.4xlarge";
    readonly ML_C7I_8XLARGE: "ml.c7i.8xlarge";
    readonly ML_C7I_LARGE: "ml.c7i.large";
    readonly ML_C7I_XLARGE: "ml.c7i.xlarge";
    readonly ML_G4DN_12XLARGE: "ml.g4dn.12xlarge";
    readonly ML_G4DN_16XLARGE: "ml.g4dn.16xlarge";
    readonly ML_G4DN_2XLARGE: "ml.g4dn.2xlarge";
    readonly ML_G4DN_4XLARGE: "ml.g4dn.4xlarge";
    readonly ML_G4DN_8XLARGE: "ml.g4dn.8xlarge";
    readonly ML_G4DN_XLARGE: "ml.g4dn.xlarge";
    readonly ML_G5_12XLARGE: "ml.g5.12xlarge";
    readonly ML_G5_16XLARGE: "ml.g5.16xlarge";
    readonly ML_G5_24XLARGE: "ml.g5.24xlarge";
    readonly ML_G5_2XLARGE: "ml.g5.2xlarge";
    readonly ML_G5_48XLARGE: "ml.g5.48xlarge";
    readonly ML_G5_4XLARGE: "ml.g5.4xlarge";
    readonly ML_G5_8XLARGE: "ml.g5.8xlarge";
    readonly ML_G5_XLARGE: "ml.g5.xlarge";
    readonly ML_G6_12XLARGE: "ml.g6.12xlarge";
    readonly ML_G6_16XLARGE: "ml.g6.16xlarge";
    readonly ML_G6_24XLARGE: "ml.g6.24xlarge";
    readonly ML_G6_2XLARGE: "ml.g6.2xlarge";
    readonly ML_G6_48XLARGE: "ml.g6.48xlarge";
    readonly ML_G6_4XLARGE: "ml.g6.4xlarge";
    readonly ML_G6_8XLARGE: "ml.g6.8xlarge";
    readonly ML_G6_XLARGE: "ml.g6.xlarge";
    readonly ML_INF1_24XLARGE: "ml.inf1.24xlarge";
    readonly ML_INF1_2XLARGE: "ml.inf1.2xlarge";
    readonly ML_INF1_6XLARGE: "ml.inf1.6xlarge";
    readonly ML_INF1_XLARGE: "ml.inf1.xlarge";
    readonly ML_INF2_24XLARGE: "ml.inf2.24xlarge";
    readonly ML_INF2_48XLARGE: "ml.inf2.48xlarge";
    readonly ML_INF2_8XLARGE: "ml.inf2.8xlarge";
    readonly ML_INF2_XLARGE: "ml.inf2.xlarge";
    readonly ML_M4_10XLARGE: "ml.m4.10xlarge";
    readonly ML_M4_16XLARGE: "ml.m4.16xlarge";
    readonly ML_M4_2XLARGE: "ml.m4.2xlarge";
    readonly ML_M4_4XLARGE: "ml.m4.4xlarge";
    readonly ML_M4_XLARGE: "ml.m4.xlarge";
    readonly ML_M5D_12XLARGE: "ml.m5d.12xlarge";
    readonly ML_M5D_16XLARGE: "ml.m5d.16xlarge";
    readonly ML_M5D_24XLARGE: "ml.m5d.24xlarge";
    readonly ML_M5D_2XLARGE: "ml.m5d.2xlarge";
    readonly ML_M5D_4XLARGE: "ml.m5d.4xlarge";
    readonly ML_M5D_8XLARGE: "ml.m5d.8xlarge";
    readonly ML_M5D_LARGE: "ml.m5d.large";
    readonly ML_M5D_XLARGE: "ml.m5d.xlarge";
    readonly ML_M5_12XLARGE: "ml.m5.12xlarge";
    readonly ML_M5_24XLARGE: "ml.m5.24xlarge";
    readonly ML_M5_2XLARGE: "ml.m5.2xlarge";
    readonly ML_M5_4XLARGE: "ml.m5.4xlarge";
    readonly ML_M5_XLARGE: "ml.m5.xlarge";
    readonly ML_M6ID_12XLARGE: "ml.m6id.12xlarge";
    readonly ML_M6ID_16XLARGE: "ml.m6id.16xlarge";
    readonly ML_M6ID_24XLARGE: "ml.m6id.24xlarge";
    readonly ML_M6ID_2XLARGE: "ml.m6id.2xlarge";
    readonly ML_M6ID_32XLARGE: "ml.m6id.32xlarge";
    readonly ML_M6ID_4XLARGE: "ml.m6id.4xlarge";
    readonly ML_M6ID_8XLARGE: "ml.m6id.8xlarge";
    readonly ML_M6ID_LARGE: "ml.m6id.large";
    readonly ML_M6ID_XLARGE: "ml.m6id.xlarge";
    readonly ML_M6I_12XLARGE: "ml.m6i.12xlarge";
    readonly ML_M6I_16XLARGE: "ml.m6i.16xlarge";
    readonly ML_M6I_24XLARGE: "ml.m6i.24xlarge";
    readonly ML_M6I_2XLARGE: "ml.m6i.2xlarge";
    readonly ML_M6I_32XLARGE: "ml.m6i.32xlarge";
    readonly ML_M6I_4XLARGE: "ml.m6i.4xlarge";
    readonly ML_M6I_8XLARGE: "ml.m6i.8xlarge";
    readonly ML_M6I_LARGE: "ml.m6i.large";
    readonly ML_M6I_XLARGE: "ml.m6i.xlarge";
    readonly ML_M7I_12XLARGE: "ml.m7i.12xlarge";
    readonly ML_M7I_16XLARGE: "ml.m7i.16xlarge";
    readonly ML_M7I_24XLARGE: "ml.m7i.24xlarge";
    readonly ML_M7I_2XLARGE: "ml.m7i.2xlarge";
    readonly ML_M7I_48XLARGE: "ml.m7i.48xlarge";
    readonly ML_M7I_4XLARGE: "ml.m7i.4xlarge";
    readonly ML_M7I_8XLARGE: "ml.m7i.8xlarge";
    readonly ML_M7I_LARGE: "ml.m7i.large";
    readonly ML_M7I_XLARGE: "ml.m7i.xlarge";
    readonly ML_P2_16XLARGE: "ml.p2.16xlarge";
    readonly ML_P2_8XLARGE: "ml.p2.8xlarge";
    readonly ML_P2_XLARGE: "ml.p2.xlarge";
    readonly ML_P3DN_24XLARGE: "ml.p3dn.24xlarge";
    readonly ML_P3_16XLARGE: "ml.p3.16xlarge";
    readonly ML_P3_2XLARGE: "ml.p3.2xlarge";
    readonly ML_P3_8XLARGE: "ml.p3.8xlarge";
    readonly ML_P4DE_24XLARGE: "ml.p4de.24xlarge";
    readonly ML_P4D_24XLARGE: "ml.p4d.24xlarge";
    readonly ML_P5_48XLARGE: "ml.p5.48xlarge";
    readonly ML_P6_B200_48XLARGE: "ml.p6-b200.48xlarge";
    readonly ML_R5_12XLARGE: "ml.r5.12xlarge";
    readonly ML_R5_16XLARGE: "ml.r5.16xlarge";
    readonly ML_R5_24XLARGE: "ml.r5.24xlarge";
    readonly ML_R5_2XLARGE: "ml.r5.2xlarge";
    readonly ML_R5_4XLARGE: "ml.r5.4xlarge";
    readonly ML_R5_8XLARGE: "ml.r5.8xlarge";
    readonly ML_R5_LARGE: "ml.r5.large";
    readonly ML_R5_XLARGE: "ml.r5.xlarge";
    readonly ML_R6ID_12XLARGE: "ml.r6id.12xlarge";
    readonly ML_R6ID_16XLARGE: "ml.r6id.16xlarge";
    readonly ML_R6ID_24XLARGE: "ml.r6id.24xlarge";
    readonly ML_R6ID_2XLARGE: "ml.r6id.2xlarge";
    readonly ML_R6ID_32XLARGE: "ml.r6id.32xlarge";
    readonly ML_R6ID_4XLARGE: "ml.r6id.4xlarge";
    readonly ML_R6ID_8XLARGE: "ml.r6id.8xlarge";
    readonly ML_R6ID_LARGE: "ml.r6id.large";
    readonly ML_R6ID_XLARGE: "ml.r6id.xlarge";
    readonly ML_R6I_12XLARGE: "ml.r6i.12xlarge";
    readonly ML_R6I_16XLARGE: "ml.r6i.16xlarge";
    readonly ML_R6I_24XLARGE: "ml.r6i.24xlarge";
    readonly ML_R6I_2XLARGE: "ml.r6i.2xlarge";
    readonly ML_R6I_32XLARGE: "ml.r6i.32xlarge";
    readonly ML_R6I_4XLARGE: "ml.r6i.4xlarge";
    readonly ML_R6I_8XLARGE: "ml.r6i.8xlarge";
    readonly ML_R6I_LARGE: "ml.r6i.large";
    readonly ML_R6I_XLARGE: "ml.r6i.xlarge";
    readonly ML_R7I_12XLARGE: "ml.r7i.12xlarge";
    readonly ML_R7I_16XLARGE: "ml.r7i.16xlarge";
    readonly ML_R7I_24XLARGE: "ml.r7i.24xlarge";
    readonly ML_R7I_2XLARGE: "ml.r7i.2xlarge";
    readonly ML_R7I_48XLARGE: "ml.r7i.48xlarge";
    readonly ML_R7I_4XLARGE: "ml.r7i.4xlarge";
    readonly ML_R7I_8XLARGE: "ml.r7i.8xlarge";
    readonly ML_R7I_LARGE: "ml.r7i.large";
    readonly ML_R7I_XLARGE: "ml.r7i.xlarge";
    readonly ML_T2_2XLARGE: "ml.t2.2xlarge";
    readonly ML_T2_LARGE: "ml.t2.large";
    readonly ML_T2_MEDIUM: "ml.t2.medium";
    readonly ML_T2_XLARGE: "ml.t2.xlarge";
    readonly ML_T3_2XLARGE: "ml.t3.2xlarge";
    readonly ML_T3_LARGE: "ml.t3.large";
    readonly ML_T3_MEDIUM: "ml.t3.medium";
    readonly ML_T3_XLARGE: "ml.t3.xlarge";
    readonly ML_TRN1N_32XLARGE: "ml.trn1n.32xlarge";
    readonly ML_TRN1_2XLARGE: "ml.trn1.2xlarge";
    readonly ML_TRN1_32XLARGE: "ml.trn1.32xlarge";
};
/**
 * @public
 */
export type _InstanceType = (typeof _InstanceType)[keyof typeof _InstanceType];
/**
 * @public
 * @enum
 */
export declare const InferenceExperimentType: {
    readonly SHADOW_MODE: "ShadowMode";
};
/**
 * @public
 */
export type InferenceExperimentType = (typeof InferenceExperimentType)[keyof typeof InferenceExperimentType];
/**
 * @public
 * @enum
 */
export declare const RecommendationJobSupportedEndpointType: {
    readonly REALTIME: "RealTime";
    readonly SERVERLESS: "Serverless";
};
/**
 * @public
 */
export type RecommendationJobSupportedEndpointType = (typeof RecommendationJobSupportedEndpointType)[keyof typeof RecommendationJobSupportedEndpointType];
/**
 * @public
 * @enum
 */
export declare const TrafficType: {
    readonly PHASES: "PHASES";
    readonly STAIRS: "STAIRS";
};
/**
 * @public
 */
export type TrafficType = (typeof TrafficType)[keyof typeof TrafficType];
/**
 * @public
 * @enum
 */
export declare const RecommendationJobType: {
    readonly ADVANCED: "Advanced";
    readonly DEFAULT: "Default";
};
/**
 * @public
 */
export type RecommendationJobType = (typeof RecommendationJobType)[keyof typeof RecommendationJobType];
/**
 * @public
 * @enum
 */
export declare const FlatInvocations: {
    readonly CONTINUE: "Continue";
    readonly STOP: "Stop";
};
/**
 * @public
 */
export type FlatInvocations = (typeof FlatInvocations)[keyof typeof FlatInvocations];
/**
 * @public
 * @enum
 */
export declare const ModelRegistrationMode: {
    readonly AUTO_MODEL_REGISTRATION_DISABLED: "AutoModelRegistrationDisabled";
    readonly AUTO_MODEL_REGISTRATION_ENABLED: "AutoModelRegistrationEnabled";
};
/**
 * @public
 */
export type ModelRegistrationMode = (typeof ModelRegistrationMode)[keyof typeof ModelRegistrationMode];
/**
 * @public
 * @enum
 */
export declare const TrackingServerSize: {
    readonly L: "Large";
    readonly M: "Medium";
    readonly S: "Small";
};
/**
 * @public
 */
export type TrackingServerSize = (typeof TrackingServerSize)[keyof typeof TrackingServerSize];
/**
 * @public
 * @enum
 */
export declare const InferenceExecutionMode: {
    readonly DIRECT: "Direct";
    readonly SERIAL: "Serial";
};
/**
 * @public
 */
export type InferenceExecutionMode = (typeof InferenceExecutionMode)[keyof typeof InferenceExecutionMode];
/**
 * @public
 * @enum
 */
export declare const ModelCardStatus: {
    readonly APPROVED: "Approved";
    readonly ARCHIVED: "Archived";
    readonly DRAFT: "Draft";
    readonly PENDINGREVIEW: "PendingReview";
};
/**
 * @public
 */
export type ModelCardStatus = (typeof ModelCardStatus)[keyof typeof ModelCardStatus];
/**
 * @public
 * @enum
 */
export declare const SkipModelValidation: {
    readonly ALL: "All";
    readonly NONE: "None";
};
/**
 * @public
 */
export type SkipModelValidation = (typeof SkipModelValidation)[keyof typeof SkipModelValidation];
/**
 * @public
 * @enum
 */
export declare const MonitoringProblemType: {
    readonly BINARY_CLASSIFICATION: "BinaryClassification";
    readonly MULTICLASS_CLASSIFICATION: "MulticlassClassification";
    readonly REGRESSION: "Regression";
};
/**
 * @public
 */
export type MonitoringProblemType = (typeof MonitoringProblemType)[keyof typeof MonitoringProblemType];
/**
 * @public
 * @enum
 */
export declare const MonitoringType: {
    readonly DATA_QUALITY: "DataQuality";
    readonly MODEL_BIAS: "ModelBias";
    readonly MODEL_EXPLAINABILITY: "ModelExplainability";
    readonly MODEL_QUALITY: "ModelQuality";
};
/**
 * @public
 */
export type MonitoringType = (typeof MonitoringType)[keyof typeof MonitoringType];
/**
 * @public
 * @enum
 */
export declare const NotebookInstanceAcceleratorType: {
    readonly ML_EIA1_LARGE: "ml.eia1.large";
    readonly ML_EIA1_MEDIUM: "ml.eia1.medium";
    readonly ML_EIA1_XLARGE: "ml.eia1.xlarge";
    readonly ML_EIA2_LARGE: "ml.eia2.large";
    readonly ML_EIA2_MEDIUM: "ml.eia2.medium";
    readonly ML_EIA2_XLARGE: "ml.eia2.xlarge";
};
/**
 * @public
 */
export type NotebookInstanceAcceleratorType = (typeof NotebookInstanceAcceleratorType)[keyof typeof NotebookInstanceAcceleratorType];
/**
 * @public
 * @enum
 */
export declare const DirectInternetAccess: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type DirectInternetAccess = (typeof DirectInternetAccess)[keyof typeof DirectInternetAccess];
/**
 * @public
 * @enum
 */
export declare const RootAccess: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type RootAccess = (typeof RootAccess)[keyof typeof RootAccess];
/**
 * @public
 * @enum
 */
export declare const OptimizationJobDeploymentInstanceType: {
    readonly ML_G5_12XLARGE: "ml.g5.12xlarge";
    readonly ML_G5_16XLARGE: "ml.g5.16xlarge";
    readonly ML_G5_24XLARGE: "ml.g5.24xlarge";
    readonly ML_G5_2XLARGE: "ml.g5.2xlarge";
    readonly ML_G5_48XLARGE: "ml.g5.48xlarge";
    readonly ML_G5_4XLARGE: "ml.g5.4xlarge";
    readonly ML_G5_8XLARGE: "ml.g5.8xlarge";
    readonly ML_G5_XLARGE: "ml.g5.xlarge";
    readonly ML_G6E_12XLARGE: "ml.g6e.12xlarge";
    readonly ML_G6E_16XLARGE: "ml.g6e.16xlarge";
    readonly ML_G6E_24XLARGE: "ml.g6e.24xlarge";
    readonly ML_G6E_2XLARGE: "ml.g6e.2xlarge";
    readonly ML_G6E_48XLARGE: "ml.g6e.48xlarge";
    readonly ML_G6E_4XLARGE: "ml.g6e.4xlarge";
    readonly ML_G6E_8XLARGE: "ml.g6e.8xlarge";
    readonly ML_G6E_XLARGE: "ml.g6e.xlarge";
    readonly ML_G6_12XLARGE: "ml.g6.12xlarge";
    readonly ML_G6_16XLARGE: "ml.g6.16xlarge";
    readonly ML_G6_24XLARGE: "ml.g6.24xlarge";
    readonly ML_G6_2XLARGE: "ml.g6.2xlarge";
    readonly ML_G6_48XLARGE: "ml.g6.48xlarge";
    readonly ML_G6_4XLARGE: "ml.g6.4xlarge";
    readonly ML_G6_8XLARGE: "ml.g6.8xlarge";
    readonly ML_G6_XLARGE: "ml.g6.xlarge";
    readonly ML_INF2_24XLARGE: "ml.inf2.24xlarge";
    readonly ML_INF2_48XLARGE: "ml.inf2.48xlarge";
    readonly ML_INF2_8XLARGE: "ml.inf2.8xlarge";
    readonly ML_INF2_XLARGE: "ml.inf2.xlarge";
    readonly ML_P4DE_24XLARGE: "ml.p4de.24xlarge";
    readonly ML_P4D_24XLARGE: "ml.p4d.24xlarge";
    readonly ML_P5EN_48XLARGE: "ml.p5en.48xlarge";
    readonly ML_P5E_48XLARGE: "ml.p5e.48xlarge";
    readonly ML_P5_48XLARGE: "ml.p5.48xlarge";
    readonly ML_TRN1N_32XLARGE: "ml.trn1n.32xlarge";
    readonly ML_TRN1_2XLARGE: "ml.trn1.2xlarge";
    readonly ML_TRN1_32XLARGE: "ml.trn1.32xlarge";
};
/**
 * @public
 */
export type OptimizationJobDeploymentInstanceType = (typeof OptimizationJobDeploymentInstanceType)[keyof typeof OptimizationJobDeploymentInstanceType];
/**
 * @public
 * @enum
 */
export declare const ModelSpeculativeDecodingTechnique: {
    readonly EAGLE: "EAGLE";
};
/**
 * @public
 */
export type ModelSpeculativeDecodingTechnique = (typeof ModelSpeculativeDecodingTechnique)[keyof typeof ModelSpeculativeDecodingTechnique];
/**
 * @public
 * @enum
 */
export declare const ModelSpeculativeDecodingS3DataType: {
    readonly ManifestFile: "ManifestFile";
    readonly S3Prefix: "S3Prefix";
};
/**
 * @public
 */
export type ModelSpeculativeDecodingS3DataType = (typeof ModelSpeculativeDecodingS3DataType)[keyof typeof ModelSpeculativeDecodingS3DataType];
/**
 * @public
 * @enum
 */
export declare const PartnerAppAuthType: {
    readonly IAM: "IAM";
};
/**
 * @public
 */
export type PartnerAppAuthType = (typeof PartnerAppAuthType)[keyof typeof PartnerAppAuthType];
/**
 * @public
 * @enum
 */
export declare const PartnerAppType: {
    readonly COMET: "comet";
    readonly DEEPCHECKS_LLM_EVALUATION: "deepchecks-llm-evaluation";
    readonly FIDDLER: "fiddler";
    readonly LAKERA_GUARD: "lakera-guard";
};
/**
 * @public
 */
export type PartnerAppType = (typeof PartnerAppType)[keyof typeof PartnerAppType];
/**
 * @public
 * @enum
 */
export declare const DataDistributionType: {
    readonly FULLYREPLICATED: "FullyReplicated";
    readonly SHARDEDBYS3KEY: "ShardedByS3Key";
};
/**
 * @public
 */
export type DataDistributionType = (typeof DataDistributionType)[keyof typeof DataDistributionType];
/**
 * @public
 * @enum
 */
export declare const InputMode: {
    readonly FILE: "File";
    readonly PIPE: "Pipe";
};
/**
 * @public
 */
export type InputMode = (typeof InputMode)[keyof typeof InputMode];
/**
 * @public
 * @enum
 */
export declare const RedshiftResultCompressionType: {
    readonly BZIP2: "BZIP2";
    readonly GZIP: "GZIP";
    readonly NONE: "None";
    readonly SNAPPY: "SNAPPY";
    readonly ZSTD: "ZSTD";
};
/**
 * @public
 */
export type RedshiftResultCompressionType = (typeof RedshiftResultCompressionType)[keyof typeof RedshiftResultCompressionType];
/**
 * @public
 * @enum
 */
export declare const RedshiftResultFormat: {
    readonly CSV: "CSV";
    readonly PARQUET: "PARQUET";
};
/**
 * @public
 */
export type RedshiftResultFormat = (typeof RedshiftResultFormat)[keyof typeof RedshiftResultFormat];
/**
 * @public
 * @enum
 */
export declare const ProcessingS3CompressionType: {
    readonly GZIP: "Gzip";
    readonly NONE: "None";
};
/**
 * @public
 */
export type ProcessingS3CompressionType = (typeof ProcessingS3CompressionType)[keyof typeof ProcessingS3CompressionType];
/**
 * @public
 * @enum
 */
export declare const ProcessingS3DataType: {
    readonly MANIFEST_FILE: "ManifestFile";
    readonly S3_PREFIX: "S3Prefix";
};
/**
 * @public
 */
export type ProcessingS3DataType = (typeof ProcessingS3DataType)[keyof typeof ProcessingS3DataType];
/**
 * @public
 * @enum
 */
export declare const SharingType: {
    readonly Private: "Private";
    readonly Shared: "Shared";
};
/**
 * @public
 */
export type SharingType = (typeof SharingType)[keyof typeof SharingType];
/**
 * @public
 * @enum
 */
export declare const StudioLifecycleConfigAppType: {
    readonly CodeEditor: "CodeEditor";
    readonly JupyterLab: "JupyterLab";
    readonly JupyterServer: "JupyterServer";
    readonly KernelGateway: "KernelGateway";
};
/**
 * @public
 */
export type StudioLifecycleConfigAppType = (typeof StudioLifecycleConfigAppType)[keyof typeof StudioLifecycleConfigAppType];
/**
 * @public
 * @enum
 */
export declare const CustomizationTechnique: {
    readonly DPO: "DPO";
    readonly RLAIF: "RLAIF";
    readonly RLVR: "RLVR";
    readonly SFT: "SFT";
};
/**
 * @public
 */
export type CustomizationTechnique = (typeof CustomizationTechnique)[keyof typeof CustomizationTechnique];
/**
 * @public
 * @enum
 */
export declare const EvaluationType: {
    readonly BENCHMARK_EVALUATION: "BenchmarkEvaluation";
    readonly CUSTOM_SCORER_EVALUATION: "CustomScorerEvaluation";
    readonly LLMAJ_EVALUATION: "LLMAJEvaluation";
};
/**
 * @public
 */
export type EvaluationType = (typeof EvaluationType)[keyof typeof EvaluationType];
/**
 * @public
 * @enum
 */
export declare const ServerlessJobType: {
    readonly EVALUATION: "Evaluation";
    readonly FINE_TUNING: "FineTuning";
};
/**
 * @public
 */
export type ServerlessJobType = (typeof ServerlessJobType)[keyof typeof ServerlessJobType];
/**
 * @public
 * @enum
 */
export declare const Peft: {
    readonly LORA: "LORA";
};
/**
 * @public
 */
export type Peft = (typeof Peft)[keyof typeof Peft];
/**
 * @public
 * @enum
 */
export declare const JoinSource: {
    readonly INPUT: "Input";
    readonly NONE: "None";
};
/**
 * @public
 */
export type JoinSource = (typeof JoinSource)[keyof typeof JoinSource];
/**
 * @public
 * @enum
 */
export declare const TrialComponentPrimaryStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type TrialComponentPrimaryStatus = (typeof TrialComponentPrimaryStatus)[keyof typeof TrialComponentPrimaryStatus];
/**
 * @public
 * @enum
 */
export declare const WorkforceIpAddressType: {
    readonly dualstack: "dualstack";
    readonly ipv4: "ipv4";
};
/**
 * @public
 */
export type WorkforceIpAddressType = (typeof WorkforceIpAddressType)[keyof typeof WorkforceIpAddressType];
/**
 * @public
 * @enum
 */
export declare const EnabledOrDisabled: {
    readonly Disabled: "Disabled";
    readonly Enabled: "Enabled";
};
/**
 * @public
 */
export type EnabledOrDisabled = (typeof EnabledOrDisabled)[keyof typeof EnabledOrDisabled];
/**
 * @public
 * @enum
 */
export declare const CrossAccountFilterOption: {
    readonly CROSS_ACCOUNT: "CrossAccount";
    readonly SAME_ACCOUNT: "SameAccount";
};
/**
 * @public
 */
export type CrossAccountFilterOption = (typeof CrossAccountFilterOption)[keyof typeof CrossAccountFilterOption];
/**
 * @public
 * @enum
 */
export declare const Statistic: {
    readonly AVERAGE: "Average";
    readonly MAXIMUM: "Maximum";
    readonly MINIMUM: "Minimum";
    readonly SAMPLE_COUNT: "SampleCount";
    readonly SUM: "Sum";
};
/**
 * @public
 */
export type Statistic = (typeof Statistic)[keyof typeof Statistic];
/**
 * @public
 * @enum
 */
export declare const RuleEvaluationStatus: {
    readonly ERROR: "Error";
    readonly IN_PROGRESS: "InProgress";
    readonly ISSUES_FOUND: "IssuesFound";
    readonly NO_ISSUES_FOUND: "NoIssuesFound";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type RuleEvaluationStatus = (typeof RuleEvaluationStatus)[keyof typeof RuleEvaluationStatus];
/**
 * @public
 * @enum
 */
export declare const RetentionType: {
    readonly Delete: "Delete";
    readonly Retain: "Retain";
};
/**
 * @public
 */
export type RetentionType = (typeof RetentionType)[keyof typeof RetentionType];
/**
 * @public
 * @enum
 */
export declare const RecommendationStatus: {
    readonly COMPLETED: "COMPLETED";
    readonly FAILED: "FAILED";
    readonly IN_PROGRESS: "IN_PROGRESS";
    readonly NOT_APPLICABLE: "NOT_APPLICABLE";
};
/**
 * @public
 */
export type RecommendationStatus = (typeof RecommendationStatus)[keyof typeof RecommendationStatus];
/**
 * @public
 * @enum
 */
export declare const StageStatus: {
    readonly Creating: "CREATING";
    readonly Deployed: "DEPLOYED";
    readonly Failed: "FAILED";
    readonly InProgress: "INPROGRESS";
    readonly ReadyToDeploy: "READYTODEPLOY";
    readonly Starting: "STARTING";
    readonly Stopped: "STOPPED";
    readonly Stopping: "STOPPING";
};
/**
 * @public
 */
export type StageStatus = (typeof StageStatus)[keyof typeof StageStatus];
/**
 * @public
 * @enum
 */
export declare const SchedulerConfigComponent: {
    readonly FAIR_SHARE: "FairShare";
    readonly IDLE_RESOURCE_SHARING: "IdleResourceSharing";
    readonly PRIORITY_CLASSES: "PriorityClasses";
};
/**
 * @public
 */
export type SchedulerConfigComponent = (typeof SchedulerConfigComponent)[keyof typeof SchedulerConfigComponent];
/**
 * @public
 * @enum
 */
export declare const DomainStatus: {
    readonly Delete_Failed: "Delete_Failed";
    readonly Deleting: "Deleting";
    readonly Failed: "Failed";
    readonly InService: "InService";
    readonly Pending: "Pending";
    readonly Update_Failed: "Update_Failed";
    readonly Updating: "Updating";
};
/**
 * @public
 */
export type DomainStatus = (typeof DomainStatus)[keyof typeof DomainStatus];
/**
 * @public
 * @enum
 */
export declare const EdgePackagingJobStatus: {
    readonly Completed: "COMPLETED";
    readonly Failed: "FAILED";
    readonly InProgress: "INPROGRESS";
    readonly Starting: "STARTING";
    readonly Stopped: "STOPPED";
    readonly Stopping: "STOPPING";
};
/**
 * @public
 */
export type EdgePackagingJobStatus = (typeof EdgePackagingJobStatus)[keyof typeof EdgePackagingJobStatus];
/**
 * @public
 * @enum
 */
export declare const EdgePresetDeploymentStatus: {
    readonly Completed: "COMPLETED";
    readonly Failed: "FAILED";
};
/**
 * @public
 */
export type EdgePresetDeploymentStatus = (typeof EdgePresetDeploymentStatus)[keyof typeof EdgePresetDeploymentStatus];
/**
 * @public
 * @enum
 */
export declare const EndpointStatus: {
    readonly CREATING: "Creating";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly IN_SERVICE: "InService";
    readonly OUT_OF_SERVICE: "OutOfService";
    readonly ROLLING_BACK: "RollingBack";
    readonly SYSTEM_UPDATING: "SystemUpdating";
    readonly UPDATE_ROLLBACK_FAILED: "UpdateRollbackFailed";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type EndpointStatus = (typeof EndpointStatus)[keyof typeof EndpointStatus];
/**
 * @public
 * @enum
 */
export declare const VariantStatus: {
    readonly ACTIVATING_TRAFFIC: "ActivatingTraffic";
    readonly BAKING: "Baking";
    readonly CREATING: "Creating";
    readonly DELETING: "Deleting";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type VariantStatus = (typeof VariantStatus)[keyof typeof VariantStatus];
/**
 * @public
 * @enum
 */
export declare const FeatureGroupStatus: {
    readonly CREATED: "Created";
    readonly CREATE_FAILED: "CreateFailed";
    readonly CREATING: "Creating";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETING: "Deleting";
};
/**
 * @public
 */
export type FeatureGroupStatus = (typeof FeatureGroupStatus)[keyof typeof FeatureGroupStatus];
/**
 * @public
 * @enum
 */
export declare const LastUpdateStatusValue: {
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly SUCCESSFUL: "Successful";
};
/**
 * @public
 */
export type LastUpdateStatusValue = (typeof LastUpdateStatusValue)[keyof typeof LastUpdateStatusValue];
/**
 * @public
 * @enum
 */
export declare const OfflineStoreStatusValue: {
    readonly ACTIVE: "Active";
    readonly BLOCKED: "Blocked";
    readonly DISABLED: "Disabled";
};
/**
 * @public
 */
export type OfflineStoreStatusValue = (typeof OfflineStoreStatusValue)[keyof typeof OfflineStoreStatusValue];
/**
 * @public
 * @enum
 */
export declare const FlowDefinitionStatus: {
    readonly ACTIVE: "Active";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly INITIALIZING: "Initializing";
};
/**
 * @public
 */
export type FlowDefinitionStatus = (typeof FlowDefinitionStatus)[keyof typeof FlowDefinitionStatus];
/**
 * @public
 * @enum
 */
export declare const HubStatus: {
    readonly CREATE_FAILED: "CreateFailed";
    readonly CREATING: "Creating";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETING: "Deleting";
    readonly IN_SERVICE: "InService";
    readonly UPDATE_FAILED: "UpdateFailed";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type HubStatus = (typeof HubStatus)[keyof typeof HubStatus];
/**
 * @public
 * @enum
 */
export declare const HubContentStatus: {
    readonly AVAILABLE: "Available";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETING: "Deleting";
    readonly IMPORTING: "Importing";
    readonly IMPORT_FAILED: "ImportFailed";
    readonly PENDING_DELETE: "PendingDelete";
    readonly PENDING_IMPORT: "PendingImport";
};
/**
 * @public
 */
export type HubContentStatus = (typeof HubContentStatus)[keyof typeof HubContentStatus];
/**
 * @public
 * @enum
 */
export declare const HubContentSupportStatus: {
    readonly DEPRECATED: "Deprecated";
    readonly RESTRICTED: "Restricted";
    readonly SUPPORTED: "Supported";
};
/**
 * @public
 */
export type HubContentSupportStatus = (typeof HubContentSupportStatus)[keyof typeof HubContentSupportStatus];
/**
 * @public
 * @enum
 */
export declare const HumanTaskUiStatus: {
    readonly ACTIVE: "Active";
    readonly DELETING: "Deleting";
};
/**
 * @public
 */
export type HumanTaskUiStatus = (typeof HumanTaskUiStatus)[keyof typeof HumanTaskUiStatus];
/**
 * @public
 * @enum
 */
export declare const TrainingJobStatus: {
    readonly COMPLETED: "Completed";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type TrainingJobStatus = (typeof TrainingJobStatus)[keyof typeof TrainingJobStatus];
/**
 * @public
 * @enum
 */
export declare const HyperParameterTuningJobStatus: {
    readonly COMPLETED: "Completed";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type HyperParameterTuningJobStatus = (typeof HyperParameterTuningJobStatus)[keyof typeof HyperParameterTuningJobStatus];
/**
 * @public
 * @enum
 */
export declare const ImageStatus: {
    readonly CREATED: "CREATED";
    readonly CREATE_FAILED: "CREATE_FAILED";
    readonly CREATING: "CREATING";
    readonly DELETE_FAILED: "DELETE_FAILED";
    readonly DELETING: "DELETING";
    readonly UPDATE_FAILED: "UPDATE_FAILED";
    readonly UPDATING: "UPDATING";
};
/**
 * @public
 */
export type ImageStatus = (typeof ImageStatus)[keyof typeof ImageStatus];
/**
 * @public
 * @enum
 */
export declare const ImageVersionStatus: {
    readonly CREATED: "CREATED";
    readonly CREATE_FAILED: "CREATE_FAILED";
    readonly CREATING: "CREATING";
    readonly DELETE_FAILED: "DELETE_FAILED";
    readonly DELETING: "DELETING";
};
/**
 * @public
 */
export type ImageVersionStatus = (typeof ImageVersionStatus)[keyof typeof ImageVersionStatus];
/**
 * @public
 * @enum
 */
export declare const InferenceComponentStatus: {
    readonly CREATING: "Creating";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly IN_SERVICE: "InService";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type InferenceComponentStatus = (typeof InferenceComponentStatus)[keyof typeof InferenceComponentStatus];
/**
 * @public
 * @enum
 */
export declare const InferenceComponentCapacitySizeType: {
    readonly CAPACITY_PERCENT: "CAPACITY_PERCENT";
    readonly COPY_COUNT: "COPY_COUNT";
};
/**
 * @public
 */
export type InferenceComponentCapacitySizeType = (typeof InferenceComponentCapacitySizeType)[keyof typeof InferenceComponentCapacitySizeType];
/**
 * @public
 * @enum
 */
export declare const ModelVariantStatus: {
    readonly CREATING: "Creating";
    readonly DELETED: "Deleted";
    readonly DELETING: "Deleting";
    readonly IN_SERVICE: "InService";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type ModelVariantStatus = (typeof ModelVariantStatus)[keyof typeof ModelVariantStatus];
/**
 * @public
 * @enum
 */
export declare const InferenceExperimentStatus: {
    readonly CANCELLED: "Cancelled";
    readonly COMPLETED: "Completed";
    readonly CREATED: "Created";
    readonly CREATING: "Creating";
    readonly RUNNING: "Running";
    readonly STARTING: "Starting";
    readonly STOPPING: "Stopping";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type InferenceExperimentStatus = (typeof InferenceExperimentStatus)[keyof typeof InferenceExperimentStatus];
/**
 * @public
 * @enum
 */
export declare const RecommendationJobStatus: {
    readonly COMPLETED: "COMPLETED";
    readonly DELETED: "DELETED";
    readonly DELETING: "DELETING";
    readonly FAILED: "FAILED";
    readonly IN_PROGRESS: "IN_PROGRESS";
    readonly PENDING: "PENDING";
    readonly STOPPED: "STOPPED";
    readonly STOPPING: "STOPPING";
};
/**
 * @public
 */
export type RecommendationJobStatus = (typeof RecommendationJobStatus)[keyof typeof RecommendationJobStatus];
/**
 * @public
 * @enum
 */
export declare const LabelingJobStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly INITIALIZING: "Initializing";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type LabelingJobStatus = (typeof LabelingJobStatus)[keyof typeof LabelingJobStatus];
/**
 * @public
 * @enum
 */
export declare const MaintenanceStatus: {
    readonly MAINTENANCE_COMPLETE: "MaintenanceComplete";
    readonly MAINTENANCE_FAILED: "MaintenanceFailed";
    readonly MAINTENANCE_IN_PROGRESS: "MaintenanceInProgress";
};
/**
 * @public
 */
export type MaintenanceStatus = (typeof MaintenanceStatus)[keyof typeof MaintenanceStatus];
/**
 * @public
 * @enum
 */
export declare const MlflowAppStatus: {
    readonly CREATED: "Created";
    readonly CREATE_FAILED: "CreateFailed";
    readonly CREATING: "Creating";
    readonly DELETED: "Deleted";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETING: "Deleting";
    readonly UPDATED: "Updated";
    readonly UPDATE_FAILED: "UpdateFailed";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type MlflowAppStatus = (typeof MlflowAppStatus)[keyof typeof MlflowAppStatus];
/**
 * @public
 * @enum
 */
export declare const IsTrackingServerActive: {
    readonly ACTIVE: "Active";
    readonly INACTIVE: "Inactive";
};
/**
 * @public
 */
export type IsTrackingServerActive = (typeof IsTrackingServerActive)[keyof typeof IsTrackingServerActive];
/**
 * @public
 * @enum
 */
export declare const TrackingServerMaintenanceStatus: {
    readonly MAINTENANCE_COMPLETE: "MaintenanceComplete";
    readonly MAINTENANCE_FAILED: "MaintenanceFailed";
    readonly MAINTENANCE_IN_PROGRESS: "MaintenanceInProgress";
};
/**
 * @public
 */
export type TrackingServerMaintenanceStatus = (typeof TrackingServerMaintenanceStatus)[keyof typeof TrackingServerMaintenanceStatus];
/**
 * @public
 * @enum
 */
export declare const TrackingServerStatus: {
    readonly CREATED: "Created";
    readonly CREATE_FAILED: "CreateFailed";
    readonly CREATING: "Creating";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETING: "Deleting";
    readonly MAINTENANCE_COMPLETE: "MaintenanceComplete";
    readonly MAINTENANCE_FAILED: "MaintenanceFailed";
    readonly MAINTENANCE_IN_PROGRESS: "MaintenanceInProgress";
    readonly STARTED: "Started";
    readonly STARTING: "Starting";
    readonly START_FAILED: "StartFailed";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
    readonly STOP_FAILED: "StopFailed";
    readonly UPDATED: "Updated";
    readonly UPDATE_FAILED: "UpdateFailed";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type TrackingServerStatus = (typeof TrackingServerStatus)[keyof typeof TrackingServerStatus];
/**
 * @public
 * @enum
 */
export declare const ModelCardProcessingStatus: {
    readonly CONTENT_DELETED: "ContentDeleted";
    readonly DELETE_COMPLETED: "DeleteCompleted";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETE_INPROGRESS: "DeleteInProgress";
    readonly DELETE_PENDING: "DeletePending";
    readonly EXPORTJOBS_DELETED: "ExportJobsDeleted";
};
/**
 * @public
 */
export type ModelCardProcessingStatus = (typeof ModelCardProcessingStatus)[keyof typeof ModelCardProcessingStatus];
/**
 * @public
 * @enum
 */
export declare const ModelCardExportJobStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
};
/**
 * @public
 */
export type ModelCardExportJobStatus = (typeof ModelCardExportJobStatus)[keyof typeof ModelCardExportJobStatus];
/**
 * @public
 * @enum
 */
export declare const DetailedModelPackageStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly NOT_STARTED: "NotStarted";
};
/**
 * @public
 */
export type DetailedModelPackageStatus = (typeof DetailedModelPackageStatus)[keyof typeof DetailedModelPackageStatus];
/**
 * @public
 * @enum
 */
export declare const ModelPackageGroupStatus: {
    readonly COMPLETED: "Completed";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly PENDING: "Pending";
};
/**
 * @public
 */
export type ModelPackageGroupStatus = (typeof ModelPackageGroupStatus)[keyof typeof ModelPackageGroupStatus];
/**
 * @public
 * @enum
 */
export declare const ExecutionStatus: {
    readonly COMPLETED: "Completed";
    readonly COMPLETED_WITH_VIOLATIONS: "CompletedWithViolations";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly PENDING: "Pending";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type ExecutionStatus = (typeof ExecutionStatus)[keyof typeof ExecutionStatus];
/**
 * @public
 * @enum
 */
export declare const ScheduleStatus: {
    readonly FAILED: "Failed";
    readonly PENDING: "Pending";
    readonly SCHEDULED: "Scheduled";
    readonly STOPPED: "Stopped";
};
/**
 * @public
 */
export type ScheduleStatus = (typeof ScheduleStatus)[keyof typeof ScheduleStatus];
/**
 * @public
 * @enum
 */
export declare const NotebookInstanceStatus: {
    readonly Deleting: "Deleting";
    readonly Failed: "Failed";
    readonly InService: "InService";
    readonly Pending: "Pending";
    readonly Stopped: "Stopped";
    readonly Stopping: "Stopping";
    readonly Updating: "Updating";
};
/**
 * @public
 */
export type NotebookInstanceStatus = (typeof NotebookInstanceStatus)[keyof typeof NotebookInstanceStatus];
/**
 * @public
 * @enum
 */
export declare const OptimizationJobStatus: {
    readonly COMPLETED: "COMPLETED";
    readonly FAILED: "FAILED";
    readonly INPROGRESS: "INPROGRESS";
    readonly STARTING: "STARTING";
    readonly STOPPED: "STOPPED";
    readonly STOPPING: "STOPPING";
};
/**
 * @public
 */
export type OptimizationJobStatus = (typeof OptimizationJobStatus)[keyof typeof OptimizationJobStatus];
/**
 * @public
 * @enum
 */
export declare const PartnerAppStatus: {
    readonly AVAILABLE: "Available";
    readonly CREATING: "Creating";
    readonly DELETED: "Deleted";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly UPDATE_FAILED: "UpdateFailed";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type PartnerAppStatus = (typeof PartnerAppStatus)[keyof typeof PartnerAppStatus];
/**
 * @public
 * @enum
 */
export declare const PipelineStatus: {
    readonly ACTIVE: "Active";
    readonly DELETING: "Deleting";
};
/**
 * @public
 */
export type PipelineStatus = (typeof PipelineStatus)[keyof typeof PipelineStatus];
/**
 * @public
 * @enum
 */
export declare const PipelineExecutionStatus: {
    readonly EXECUTING: "Executing";
    readonly FAILED: "Failed";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
    readonly SUCCEEDED: "Succeeded";
};
/**
 * @public
 */
export type PipelineExecutionStatus = (typeof PipelineExecutionStatus)[keyof typeof PipelineExecutionStatus];
/**
 * @public
 * @enum
 */
export declare const ProcessingJobStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type ProcessingJobStatus = (typeof ProcessingJobStatus)[keyof typeof ProcessingJobStatus];
/**
 * @public
 * @enum
 */
export declare const ProjectStatus: {
    readonly CREATE_COMPLETED: "CreateCompleted";
    readonly CREATE_FAILED: "CreateFailed";
    readonly CREATE_IN_PROGRESS: "CreateInProgress";
    readonly DELETE_COMPLETED: "DeleteCompleted";
    readonly DELETE_FAILED: "DeleteFailed";
    readonly DELETE_IN_PROGRESS: "DeleteInProgress";
    readonly PENDING: "Pending";
    readonly UPDATE_COMPLETED: "UpdateCompleted";
    readonly UPDATE_FAILED: "UpdateFailed";
    readonly UPDATE_IN_PROGRESS: "UpdateInProgress";
};
/**
 * @public
 */
export type ProjectStatus = (typeof ProjectStatus)[keyof typeof ProjectStatus];
/**
 * @public
 * @enum
 */
export declare const ReservedCapacityInstanceType: {
    readonly ML_P4DE_24XLARGE: "ml.p4de.24xlarge";
    readonly ML_P4D_24XLARGE: "ml.p4d.24xlarge";
    readonly ML_P5EN_48XLARGE: "ml.p5en.48xlarge";
    readonly ML_P5E_48XLARGE: "ml.p5e.48xlarge";
    readonly ML_P5_48XLARGE: "ml.p5.48xlarge";
    readonly ML_P5_4XLARGE: "ml.p5.4xlarge";
    readonly ML_P6E_GB200_36XLARGE: "ml.p6e-gb200.36xlarge";
    readonly ML_P6_B200_48XLARGE: "ml.p6-b200.48xlarge";
    readonly ML_P6_B300_48XLARGE: "ml.p6-b300.48xlarge";
    readonly ML_TRN1_32XLARGE: "ml.trn1.32xlarge";
    readonly ML_TRN2_48XLARGE: "ml.trn2.48xlarge";
};
/**
 * @public
 */
export type ReservedCapacityInstanceType = (typeof ReservedCapacityInstanceType)[keyof typeof ReservedCapacityInstanceType];
/**
 * @public
 * @enum
 */
export declare const ReservedCapacityType: {
    readonly INSTANCE: "Instance";
    readonly ULTRASERVER: "UltraServer";
};
/**
 * @public
 */
export type ReservedCapacityType = (typeof ReservedCapacityType)[keyof typeof ReservedCapacityType];
/**
 * @public
 * @enum
 */
export declare const ReservedCapacityStatus: {
    readonly ACTIVE: "Active";
    readonly EXPIRED: "Expired";
    readonly FAILED: "Failed";
    readonly PENDING: "Pending";
    readonly SCHEDULED: "Scheduled";
};
/**
 * @public
 */
export type ReservedCapacityStatus = (typeof ReservedCapacityStatus)[keyof typeof ReservedCapacityStatus];
/**
 * @public
 * @enum
 */
export declare const SpaceStatus: {
    readonly Delete_Failed: "Delete_Failed";
    readonly Deleting: "Deleting";
    readonly Failed: "Failed";
    readonly InService: "InService";
    readonly Pending: "Pending";
    readonly Update_Failed: "Update_Failed";
    readonly Updating: "Updating";
};
/**
 * @public
 */
export type SpaceStatus = (typeof SpaceStatus)[keyof typeof SpaceStatus];
/**
 * @public
 * @enum
 */
export declare const ProfilingStatus: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type ProfilingStatus = (typeof ProfilingStatus)[keyof typeof ProfilingStatus];
/**
 * @public
 * @enum
 */
export declare const SecondaryStatus: {
    readonly COMPLETED: "Completed";
    readonly DOWNLOADING: "Downloading";
    readonly DOWNLOADING_TRAINING_IMAGE: "DownloadingTrainingImage";
    readonly FAILED: "Failed";
    readonly INTERRUPTED: "Interrupted";
    readonly LAUNCHING_ML_INSTANCES: "LaunchingMLInstances";
    readonly MAX_RUNTIME_EXCEEDED: "MaxRuntimeExceeded";
    readonly MAX_WAIT_TIME_EXCEEDED: "MaxWaitTimeExceeded";
    readonly PENDING: "Pending";
    readonly PREPARING_TRAINING_STACK: "PreparingTrainingStack";
    readonly RESTARTING: "Restarting";
    readonly STARTING: "Starting";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
    readonly TRAINING: "Training";
    readonly UPDATING: "Updating";
    readonly UPLOADING: "Uploading";
};
/**
 * @public
 */
export type SecondaryStatus = (typeof SecondaryStatus)[keyof typeof SecondaryStatus];
/**
 * @public
 * @enum
 */
export declare const WarmPoolResourceStatus: {
    readonly AVAILABLE: "Available";
    readonly INUSE: "InUse";
    readonly REUSED: "Reused";
    readonly TERMINATED: "Terminated";
};
/**
 * @public
 */
export type WarmPoolResourceStatus = (typeof WarmPoolResourceStatus)[keyof typeof WarmPoolResourceStatus];
/**
 * @public
 * @enum
 */
export declare const TrainingPlanStatus: {
    readonly ACTIVE: "Active";
    readonly EXPIRED: "Expired";
    readonly FAILED: "Failed";
    readonly PENDING: "Pending";
    readonly SCHEDULED: "Scheduled";
};
/**
 * @public
 */
export type TrainingPlanStatus = (typeof TrainingPlanStatus)[keyof typeof TrainingPlanStatus];
/**
 * @public
 * @enum
 */
export declare const SageMakerResourceName: {
    readonly ENDPOINT: "endpoint";
    readonly HYPERPOD_CLUSTER: "hyperpod-cluster";
    readonly TRAINING_JOB: "training-job";
};
/**
 * @public
 */
export type SageMakerResourceName = (typeof SageMakerResourceName)[keyof typeof SageMakerResourceName];
/**
 * @public
 * @enum
 */
export declare const TransformJobStatus: {
    readonly COMPLETED: "Completed";
    readonly FAILED: "Failed";
    readonly IN_PROGRESS: "InProgress";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
};
/**
 * @public
 */
export type TransformJobStatus = (typeof TransformJobStatus)[keyof typeof TransformJobStatus];
/**
 * @public
 * @enum
 */
export declare const UserProfileStatus: {
    readonly Delete_Failed: "Delete_Failed";
    readonly Deleting: "Deleting";
    readonly Failed: "Failed";
    readonly InService: "InService";
    readonly Pending: "Pending";
    readonly Update_Failed: "Update_Failed";
    readonly Updating: "Updating";
};
/**
 * @public
 */
export type UserProfileStatus = (typeof UserProfileStatus)[keyof typeof UserProfileStatus];
/**
 * @public
 * @enum
 */
export declare const WorkforceStatus: {
    readonly ACTIVE: "Active";
    readonly DELETING: "Deleting";
    readonly FAILED: "Failed";
    readonly INITIALIZING: "Initializing";
    readonly UPDATING: "Updating";
};
/**
 * @public
 */
export type WorkforceStatus = (typeof WorkforceStatus)[keyof typeof WorkforceStatus];
/**
 * @public
 * @enum
 */
export declare const DeviceDeploymentStatus: {
    readonly Deployed: "DEPLOYED";
    readonly Failed: "FAILED";
    readonly InProgress: "INPROGRESS";
    readonly ReadyToDeploy: "READYTODEPLOY";
    readonly Stopped: "STOPPED";
    readonly Stopping: "STOPPING";
};
/**
 * @public
 */
export type DeviceDeploymentStatus = (typeof DeviceDeploymentStatus)[keyof typeof DeviceDeploymentStatus];
/**
 * @public
 * @enum
 */
export declare const Direction: {
    readonly ASCENDANTS: "Ascendants";
    readonly BOTH: "Both";
    readonly DESCENDANTS: "Descendants";
};
/**
 * @public
 */
export type Direction = (typeof Direction)[keyof typeof Direction];
/**
 * @public
 * @enum
 */
export declare const EndpointConfigSortKey: {
    readonly CreationTime: "CreationTime";
    readonly Name: "Name";
};
/**
 * @public
 */
export type EndpointConfigSortKey = (typeof EndpointConfigSortKey)[keyof typeof EndpointConfigSortKey];
/**
 * @public
 * @enum
 */
export declare const EndpointSortKey: {
    readonly CreationTime: "CreationTime";
    readonly Name: "Name";
    readonly Status: "Status";
};
/**
 * @public
 */
export type EndpointSortKey = (typeof EndpointSortKey)[keyof typeof EndpointSortKey];
/**
 * @public
 * @enum
 */
export declare const EventSortBy: {
    readonly EVENT_TIME: "EventTime";
};
/**
 * @public
 */
export type EventSortBy = (typeof EventSortBy)[keyof typeof EventSortBy];
/**
 * @public
 * @enum
 */
export declare const FeatureGroupSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly FEATURE_GROUP_STATUS: "FeatureGroupStatus";
    readonly NAME: "Name";
    readonly OFFLINE_STORE_STATUS: "OfflineStoreStatus";
};
/**
 * @public
 */
export type FeatureGroupSortBy = (typeof FeatureGroupSortBy)[keyof typeof FeatureGroupSortBy];
/**
 * @public
 * @enum
 */
export declare const FeatureGroupSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type FeatureGroupSortOrder = (typeof FeatureGroupSortOrder)[keyof typeof FeatureGroupSortOrder];
/**
 * @public
 * @enum
 */
export declare const Operator: {
    readonly CONTAINS: "Contains";
    readonly EQUALS: "Equals";
    readonly EXISTS: "Exists";
    readonly GREATER_THAN: "GreaterThan";
    readonly GREATER_THAN_OR_EQUAL_TO: "GreaterThanOrEqualTo";
    readonly IN: "In";
    readonly LESS_THAN: "LessThan";
    readonly LESS_THAN_OR_EQUAL_TO: "LessThanOrEqualTo";
    readonly NOT_EQUALS: "NotEquals";
    readonly NOT_EXISTS: "NotExists";
};
/**
 * @public
 */
export type Operator = (typeof Operator)[keyof typeof Operator];
/**
 * @public
 * @enum
 */
export declare const SagemakerServicecatalogStatus: {
    readonly DISABLED: "Disabled";
    readonly ENABLED: "Enabled";
};
/**
 * @public
 */
export type SagemakerServicecatalogStatus = (typeof SagemakerServicecatalogStatus)[keyof typeof SagemakerServicecatalogStatus];
/**
 * @public
 * @enum
 */
export declare const ResourceType: {
    readonly ENDPOINT: "Endpoint";
    readonly EXPERIMENT: "Experiment";
    readonly EXPERIMENT_TRIAL: "ExperimentTrial";
    readonly EXPERIMENT_TRIAL_COMPONENT: "ExperimentTrialComponent";
    readonly FEATURE_GROUP: "FeatureGroup";
    readonly FEATURE_METADATA: "FeatureMetadata";
    readonly HYPER_PARAMETER_TUNING_JOB: "HyperParameterTuningJob";
    readonly IMAGE: "Image";
    readonly IMAGE_VERSION: "ImageVersion";
    readonly MODEL: "Model";
    readonly MODEL_CARD: "ModelCard";
    readonly MODEL_PACKAGE: "ModelPackage";
    readonly MODEL_PACKAGE_GROUP: "ModelPackageGroup";
    readonly PIPELINE: "Pipeline";
    readonly PIPELINE_EXECUTION: "PipelineExecution";
    readonly PIPELINE_VERSION: "PipelineVersion";
    readonly PROJECT: "Project";
    readonly TRAINING_JOB: "TrainingJob";
};
/**
 * @public
 */
export type ResourceType = (typeof ResourceType)[keyof typeof ResourceType];
/**
 * @public
 * @enum
 */
export declare const HubContentSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly HUB_CONTENT_NAME: "HubContentName";
    readonly HUB_CONTENT_STATUS: "HubContentStatus";
};
/**
 * @public
 */
export type HubContentSortBy = (typeof HubContentSortBy)[keyof typeof HubContentSortBy];
/**
 * @public
 * @enum
 */
export declare const HubSortBy: {
    readonly ACCOUNT_ID_OWNER: "AccountIdOwner";
    readonly CREATION_TIME: "CreationTime";
    readonly HUB_NAME: "HubName";
    readonly HUB_STATUS: "HubStatus";
};
/**
 * @public
 */
export type HubSortBy = (typeof HubSortBy)[keyof typeof HubSortBy];
/**
 * @public
 * @enum
 */
export declare const HyperParameterTuningJobSortByOptions: {
    readonly CreationTime: "CreationTime";
    readonly Name: "Name";
    readonly Status: "Status";
};
/**
 * @public
 */
export type HyperParameterTuningJobSortByOptions = (typeof HyperParameterTuningJobSortByOptions)[keyof typeof HyperParameterTuningJobSortByOptions];
/**
 * @public
 * @enum
 */
export declare const ImageSortBy: {
    readonly CREATION_TIME: "CREATION_TIME";
    readonly IMAGE_NAME: "IMAGE_NAME";
    readonly LAST_MODIFIED_TIME: "LAST_MODIFIED_TIME";
};
/**
 * @public
 */
export type ImageSortBy = (typeof ImageSortBy)[keyof typeof ImageSortBy];
/**
 * @public
 * @enum
 */
export declare const ImageSortOrder: {
    readonly ASCENDING: "ASCENDING";
    readonly DESCENDING: "DESCENDING";
};
/**
 * @public
 */
export type ImageSortOrder = (typeof ImageSortOrder)[keyof typeof ImageSortOrder];
/**
 * @public
 * @enum
 */
export declare const ImageVersionSortBy: {
    readonly CREATION_TIME: "CREATION_TIME";
    readonly LAST_MODIFIED_TIME: "LAST_MODIFIED_TIME";
    readonly VERSION: "VERSION";
};
/**
 * @public
 */
export type ImageVersionSortBy = (typeof ImageVersionSortBy)[keyof typeof ImageVersionSortBy];
/**
 * @public
 * @enum
 */
export declare const ImageVersionSortOrder: {
    readonly ASCENDING: "ASCENDING";
    readonly DESCENDING: "DESCENDING";
};
/**
 * @public
 */
export type ImageVersionSortOrder = (typeof ImageVersionSortOrder)[keyof typeof ImageVersionSortOrder];
/**
 * @public
 * @enum
 */
export declare const InferenceComponentSortKey: {
    readonly CreationTime: "CreationTime";
    readonly Name: "Name";
    readonly Status: "Status";
};
/**
 * @public
 */
export type InferenceComponentSortKey = (typeof InferenceComponentSortKey)[keyof typeof InferenceComponentSortKey];
/**
 * @public
 * @enum
 */
export declare const InferenceExperimentStopDesiredState: {
    readonly CANCELLED: "Cancelled";
    readonly COMPLETED: "Completed";
};
/**
 * @public
 */
export type InferenceExperimentStopDesiredState = (typeof InferenceExperimentStopDesiredState)[keyof typeof InferenceExperimentStopDesiredState];
/**
 * @public
 * @enum
 */
export declare const RecommendationStepType: {
    readonly BENCHMARK: "BENCHMARK";
};
/**
 * @public
 */
export type RecommendationStepType = (typeof RecommendationStepType)[keyof typeof RecommendationStepType];
/**
 * @public
 * @enum
 */
export declare const LineageType: {
    readonly ACTION: "Action";
    readonly ARTIFACT: "Artifact";
    readonly CONTEXT: "Context";
    readonly TRIAL_COMPONENT: "TrialComponent";
};
/**
 * @public
 */
export type LineageType = (typeof LineageType)[keyof typeof LineageType];
/**
 * @public
 * @enum
 */
export declare const SortActionsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type SortActionsBy = (typeof SortActionsBy)[keyof typeof SortActionsBy];
/**
 * @public
 * @enum
 */
export declare const SortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type SortOrder = (typeof SortOrder)[keyof typeof SortOrder];
/**
 * @public
 * @enum
 */
export declare const SortArtifactsBy: {
    readonly CREATION_TIME: "CreationTime";
};
/**
 * @public
 */
export type SortArtifactsBy = (typeof SortArtifactsBy)[keyof typeof SortArtifactsBy];
/**
 * @public
 * @enum
 */
export declare const SortAssociationsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly DESTINATION_ARN: "DestinationArn";
    readonly DESTINATION_TYPE: "DestinationType";
    readonly SOURCE_ARN: "SourceArn";
    readonly SOURCE_TYPE: "SourceType";
};
/**
 * @public
 */
export type SortAssociationsBy = (typeof SortAssociationsBy)[keyof typeof SortAssociationsBy];
/**
 * @public
 * @enum
 */
export declare const SortClusterSchedulerConfigBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type SortClusterSchedulerConfigBy = (typeof SortClusterSchedulerConfigBy)[keyof typeof SortClusterSchedulerConfigBy];
/**
 * @public
 * @enum
 */
export declare const ListCompilationJobsSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type ListCompilationJobsSortBy = (typeof ListCompilationJobsSortBy)[keyof typeof ListCompilationJobsSortBy];
/**
 * @public
 * @enum
 */
export declare const SortQuotaBy: {
    readonly CLUSTER_ARN: "ClusterArn";
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type SortQuotaBy = (typeof SortQuotaBy)[keyof typeof SortQuotaBy];
/**
 * @public
 * @enum
 */
export declare const SortContextsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type SortContextsBy = (typeof SortContextsBy)[keyof typeof SortContextsBy];
/**
 * @public
 * @enum
 */
export declare const MonitoringJobDefinitionSortKey: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type MonitoringJobDefinitionSortKey = (typeof MonitoringJobDefinitionSortKey)[keyof typeof MonitoringJobDefinitionSortKey];
/**
 * @public
 * @enum
 */
export declare const ListDeviceFleetsSortBy: {
    readonly CreationTime: "CREATION_TIME";
    readonly LastModifiedTime: "LAST_MODIFIED_TIME";
    readonly Name: "NAME";
};
/**
 * @public
 */
export type ListDeviceFleetsSortBy = (typeof ListDeviceFleetsSortBy)[keyof typeof ListDeviceFleetsSortBy];
/**
 * @public
 * @enum
 */
export declare const ListEdgeDeploymentPlansSortBy: {
    readonly CreationTime: "CREATION_TIME";
    readonly DeviceFleetName: "DEVICE_FLEET_NAME";
    readonly LastModifiedTime: "LAST_MODIFIED_TIME";
    readonly Name: "NAME";
};
/**
 * @public
 */
export type ListEdgeDeploymentPlansSortBy = (typeof ListEdgeDeploymentPlansSortBy)[keyof typeof ListEdgeDeploymentPlansSortBy];
/**
 * @public
 * @enum
 */
export declare const ListEdgePackagingJobsSortBy: {
    readonly CreationTime: "CREATION_TIME";
    readonly EdgePackagingJobStatus: "STATUS";
    readonly LastModifiedTime: "LAST_MODIFIED_TIME";
    readonly ModelName: "MODEL_NAME";
    readonly Name: "NAME";
};
/**
 * @public
 */
export type ListEdgePackagingJobsSortBy = (typeof ListEdgePackagingJobsSortBy)[keyof typeof ListEdgePackagingJobsSortBy];
/**
 * @public
 * @enum
 */
export declare const OrderKey: {
    readonly Ascending: "Ascending";
    readonly Descending: "Descending";
};
/**
 * @public
 */
export type OrderKey = (typeof OrderKey)[keyof typeof OrderKey];
/**
 * @public
 * @enum
 */
export declare const SortExperimentsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type SortExperimentsBy = (typeof SortExperimentsBy)[keyof typeof SortExperimentsBy];
/**
 * @public
 * @enum
 */
export declare const SortInferenceExperimentsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type SortInferenceExperimentsBy = (typeof SortInferenceExperimentsBy)[keyof typeof SortInferenceExperimentsBy];
/**
 * @public
 * @enum
 */
export declare const ListInferenceRecommendationsJobsSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type ListInferenceRecommendationsJobsSortBy = (typeof ListInferenceRecommendationsJobsSortBy)[keyof typeof ListInferenceRecommendationsJobsSortBy];
/**
 * @public
 * @enum
 */
export declare const SortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type SortBy = (typeof SortBy)[keyof typeof SortBy];
/**
 * @public
 * @enum
 */
export declare const ListLabelingJobsForWorkteamSortByOptions: {
    readonly CREATION_TIME: "CreationTime";
};
/**
 * @public
 */
export type ListLabelingJobsForWorkteamSortByOptions = (typeof ListLabelingJobsForWorkteamSortByOptions)[keyof typeof ListLabelingJobsForWorkteamSortByOptions];
/**
 * @public
 * @enum
 */
export declare const SortLineageGroupsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type SortLineageGroupsBy = (typeof SortLineageGroupsBy)[keyof typeof SortLineageGroupsBy];
/**
 * @public
 * @enum
 */
export declare const SortMlflowAppBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type SortMlflowAppBy = (typeof SortMlflowAppBy)[keyof typeof SortMlflowAppBy];
/**
 * @public
 * @enum
 */
export declare const SortTrackingServerBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type SortTrackingServerBy = (typeof SortTrackingServerBy)[keyof typeof SortTrackingServerBy];
/**
 * @public
 * @enum
 */
export declare const ModelCardExportJobSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type ModelCardExportJobSortBy = (typeof ModelCardExportJobSortBy)[keyof typeof ModelCardExportJobSortBy];
/**
 * @public
 * @enum
 */
export declare const ModelCardExportJobSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type ModelCardExportJobSortOrder = (typeof ModelCardExportJobSortOrder)[keyof typeof ModelCardExportJobSortOrder];
/**
 * @public
 * @enum
 */
export declare const ModelCardSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type ModelCardSortBy = (typeof ModelCardSortBy)[keyof typeof ModelCardSortBy];
/**
 * @public
 * @enum
 */
export declare const ModelCardSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type ModelCardSortOrder = (typeof ModelCardSortOrder)[keyof typeof ModelCardSortOrder];
/**
 * @public
 * @enum
 */
export declare const ModelCardVersionSortBy: {
    readonly VERSION: "Version";
};
/**
 * @public
 */
export type ModelCardVersionSortBy = (typeof ModelCardVersionSortBy)[keyof typeof ModelCardVersionSortBy];
/**
 * @public
 * @enum
 */
export declare const ModelMetadataFilterType: {
    readonly DOMAIN: "Domain";
    readonly FRAMEWORK: "Framework";
    readonly FRAMEWORKVERSION: "FrameworkVersion";
    readonly TASK: "Task";
};
/**
 * @public
 */
export type ModelMetadataFilterType = (typeof ModelMetadataFilterType)[keyof typeof ModelMetadataFilterType];
/**
 * @public
 * @enum
 */
export declare const ModelPackageGroupSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type ModelPackageGroupSortBy = (typeof ModelPackageGroupSortBy)[keyof typeof ModelPackageGroupSortBy];
/**
 * @public
 * @enum
 */
export declare const ModelPackageType: {
    readonly BOTH: "Both";
    readonly UNVERSIONED: "Unversioned";
    readonly VERSIONED: "Versioned";
};
/**
 * @public
 */
export type ModelPackageType = (typeof ModelPackageType)[keyof typeof ModelPackageType];
/**
 * @public
 * @enum
 */
export declare const ModelPackageSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type ModelPackageSortBy = (typeof ModelPackageSortBy)[keyof typeof ModelPackageSortBy];
/**
 * @public
 * @enum
 */
export declare const ModelSortKey: {
    readonly CreationTime: "CreationTime";
    readonly Name: "Name";
};
/**
 * @public
 */
export type ModelSortKey = (typeof ModelSortKey)[keyof typeof ModelSortKey];
/**
 * @public
 * @enum
 */
export declare const MonitoringAlertHistorySortKey: {
    readonly CreationTime: "CreationTime";
    readonly Status: "Status";
};
/**
 * @public
 */
export type MonitoringAlertHistorySortKey = (typeof MonitoringAlertHistorySortKey)[keyof typeof MonitoringAlertHistorySortKey];
/**
 * @public
 * @enum
 */
export declare const MonitoringAlertStatus: {
    readonly IN_ALERT: "InAlert";
    readonly OK: "OK";
};
/**
 * @public
 */
export type MonitoringAlertStatus = (typeof MonitoringAlertStatus)[keyof typeof MonitoringAlertStatus];
/**
 * @public
 * @enum
 */
export declare const MonitoringExecutionSortKey: {
    readonly CREATION_TIME: "CreationTime";
    readonly SCHEDULED_TIME: "ScheduledTime";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type MonitoringExecutionSortKey = (typeof MonitoringExecutionSortKey)[keyof typeof MonitoringExecutionSortKey];
/**
 * @public
 * @enum
 */
export declare const MonitoringScheduleSortKey: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type MonitoringScheduleSortKey = (typeof MonitoringScheduleSortKey)[keyof typeof MonitoringScheduleSortKey];
/**
 * @public
 * @enum
 */
export declare const NotebookInstanceLifecycleConfigSortKey: {
    readonly CREATION_TIME: "CreationTime";
    readonly LAST_MODIFIED_TIME: "LastModifiedTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type NotebookInstanceLifecycleConfigSortKey = (typeof NotebookInstanceLifecycleConfigSortKey)[keyof typeof NotebookInstanceLifecycleConfigSortKey];
/**
 * @public
 * @enum
 */
export declare const NotebookInstanceLifecycleConfigSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type NotebookInstanceLifecycleConfigSortOrder = (typeof NotebookInstanceLifecycleConfigSortOrder)[keyof typeof NotebookInstanceLifecycleConfigSortOrder];
/**
 * @public
 * @enum
 */
export declare const NotebookInstanceSortKey: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type NotebookInstanceSortKey = (typeof NotebookInstanceSortKey)[keyof typeof NotebookInstanceSortKey];
/**
 * @public
 * @enum
 */
export declare const NotebookInstanceSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type NotebookInstanceSortOrder = (typeof NotebookInstanceSortOrder)[keyof typeof NotebookInstanceSortOrder];
/**
 * @public
 * @enum
 */
export declare const ListOptimizationJobsSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type ListOptimizationJobsSortBy = (typeof ListOptimizationJobsSortBy)[keyof typeof ListOptimizationJobsSortBy];
/**
 * @public
 * @enum
 */
export declare const SortPipelineExecutionsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly PIPELINE_EXECUTION_ARN: "PipelineExecutionArn";
};
/**
 * @public
 */
export type SortPipelineExecutionsBy = (typeof SortPipelineExecutionsBy)[keyof typeof SortPipelineExecutionsBy];
/**
 * @public
 * @enum
 */
export declare const StepStatus: {
    readonly EXECUTING: "Executing";
    readonly FAILED: "Failed";
    readonly STARTING: "Starting";
    readonly STOPPED: "Stopped";
    readonly STOPPING: "Stopping";
    readonly SUCCEEDED: "Succeeded";
};
/**
 * @public
 */
export type StepStatus = (typeof StepStatus)[keyof typeof StepStatus];
/**
 * @public
 * @enum
 */
export declare const SortPipelinesBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type SortPipelinesBy = (typeof SortPipelinesBy)[keyof typeof SortPipelinesBy];
/**
 * @public
 * @enum
 */
export declare const ProjectSortBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type ProjectSortBy = (typeof ProjectSortBy)[keyof typeof ProjectSortBy];
/**
 * @public
 * @enum
 */
export declare const ProjectSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type ProjectSortOrder = (typeof ProjectSortOrder)[keyof typeof ProjectSortOrder];
/**
 * @public
 * @enum
 */
export declare const ResourceCatalogSortBy: {
    readonly CREATION_TIME: "CreationTime";
};
/**
 * @public
 */
export type ResourceCatalogSortBy = (typeof ResourceCatalogSortBy)[keyof typeof ResourceCatalogSortBy];
/**
 * @public
 * @enum
 */
export declare const ResourceCatalogSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type ResourceCatalogSortOrder = (typeof ResourceCatalogSortOrder)[keyof typeof ResourceCatalogSortOrder];
/**
 * @public
 * @enum
 */
export declare const SpaceSortKey: {
    readonly CreationTime: "CreationTime";
    readonly LastModifiedTime: "LastModifiedTime";
};
/**
 * @public
 */
export type SpaceSortKey = (typeof SpaceSortKey)[keyof typeof SpaceSortKey];
/**
 * @public
 * @enum
 */
export declare const StudioLifecycleConfigSortKey: {
    readonly CreationTime: "CreationTime";
    readonly LastModifiedTime: "LastModifiedTime";
    readonly Name: "Name";
};
/**
 * @public
 */
export type StudioLifecycleConfigSortKey = (typeof StudioLifecycleConfigSortKey)[keyof typeof StudioLifecycleConfigSortKey];
/**
 * @public
 * @enum
 */
export declare const TrainingJobSortByOptions: {
    readonly CreationTime: "CreationTime";
    readonly FinalObjectiveMetricValue: "FinalObjectiveMetricValue";
    readonly Name: "Name";
    readonly Status: "Status";
};
/**
 * @public
 */
export type TrainingJobSortByOptions = (typeof TrainingJobSortByOptions)[keyof typeof TrainingJobSortByOptions];
/**
 * @public
 * @enum
 */
export declare const TrainingPlanFilterName: {
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type TrainingPlanFilterName = (typeof TrainingPlanFilterName)[keyof typeof TrainingPlanFilterName];
/**
 * @public
 * @enum
 */
export declare const TrainingPlanSortBy: {
    readonly NAME: "TrainingPlanName";
    readonly START_TIME: "StartTime";
    readonly STATUS: "Status";
};
/**
 * @public
 */
export type TrainingPlanSortBy = (typeof TrainingPlanSortBy)[keyof typeof TrainingPlanSortBy];
/**
 * @public
 * @enum
 */
export declare const TrainingPlanSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type TrainingPlanSortOrder = (typeof TrainingPlanSortOrder)[keyof typeof TrainingPlanSortOrder];
/**
 * @public
 * @enum
 */
export declare const SortTrialComponentsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type SortTrialComponentsBy = (typeof SortTrialComponentsBy)[keyof typeof SortTrialComponentsBy];
/**
 * @public
 * @enum
 */
export declare const SortTrialsBy: {
    readonly CREATION_TIME: "CreationTime";
    readonly NAME: "Name";
};
/**
 * @public
 */
export type SortTrialsBy = (typeof SortTrialsBy)[keyof typeof SortTrialsBy];
/**
 * @public
 * @enum
 */
export declare const UltraServerHealthStatus: {
    readonly IMPAIRED: "Impaired";
    readonly INSUFFICIENT_DATA: "Insufficient-Data";
    readonly OK: "OK";
};
/**
 * @public
 */
export type UltraServerHealthStatus = (typeof UltraServerHealthStatus)[keyof typeof UltraServerHealthStatus];
/**
 * @public
 * @enum
 */
export declare const UserProfileSortKey: {
    readonly CreationTime: "CreationTime";
    readonly LastModifiedTime: "LastModifiedTime";
};
/**
 * @public
 */
export type UserProfileSortKey = (typeof UserProfileSortKey)[keyof typeof UserProfileSortKey];
/**
 * @public
 * @enum
 */
export declare const ListWorkforcesSortByOptions: {
    readonly CreateDate: "CreateDate";
    readonly Name: "Name";
};
/**
 * @public
 */
export type ListWorkforcesSortByOptions = (typeof ListWorkforcesSortByOptions)[keyof typeof ListWorkforcesSortByOptions];
/**
 * @public
 * @enum
 */
export declare const ListWorkteamsSortByOptions: {
    readonly CreateDate: "CreateDate";
    readonly Name: "Name";
};
/**
 * @public
 */
export type ListWorkteamsSortByOptions = (typeof ListWorkteamsSortByOptions)[keyof typeof ListWorkteamsSortByOptions];
/**
 * @public
 * @enum
 */
export declare const ModelVariantAction: {
    readonly PROMOTE: "Promote";
    readonly REMOVE: "Remove";
    readonly RETAIN: "Retain";
};
/**
 * @public
 */
export type ModelVariantAction = (typeof ModelVariantAction)[keyof typeof ModelVariantAction];
/**
 * @public
 * @enum
 */
export declare const Relation: {
    readonly EQUAL_TO: "EqualTo";
    readonly GREATER_THAN_OR_EQUAL_TO: "GreaterThanOrEqualTo";
};
/**
 * @public
 */
export type Relation = (typeof Relation)[keyof typeof Relation];
/**
 * @public
 * @enum
 */
export declare const SearchSortOrder: {
    readonly ASCENDING: "Ascending";
    readonly DESCENDING: "Descending";
};
/**
 * @public
 */
export type SearchSortOrder = (typeof SearchSortOrder)[keyof typeof SearchSortOrder];
/**
 * @public
 * @enum
 */
export declare const VariantPropertyType: {
    readonly DataCaptureConfig: "DataCaptureConfig";
    readonly DesiredInstanceCount: "DesiredInstanceCount";
    readonly DesiredWeight: "DesiredWeight";
};
/**
 * @public
 */
export type VariantPropertyType = (typeof VariantPropertyType)[keyof typeof VariantPropertyType];
